
.intel_syntax noprefix

.global process_branch

.extern GetOverrideAssume
.extern GetCurrOffset
.extern GetSymOfssize
.extern segm_override
.extern set_frame
.extern SegOverride
.extern optable_idx
.extern CreateFixup
.extern OutputByte
.extern asmerr
.extern Parse_Pass


.SECTION .text
	.ALIGN	16

$_001:	push	rsi
	push	rbx
	push	rbp
	mov	rbp, rsp
	sub	rsp, 32
	mov	rsi, rcx
	mov	ebx, edx
	cmp	dword ptr [Parse_Pass+rip], 1
	jnz	$_002
	mov	ecx, 6003
	call	asmerr@PLT
$_002:	mov	al, byte ptr [rsi+0x9]
	test	ebx, ebx
	jz	$_006
	test	byte ptr [rsi+0x1], 0x20
	jz	$_004
	mov	ebx, 8
	test	al, al
	jz	$_003
	mov	ebx, 6
$_003:	jmp	$_005

$_004:	mov	ebx, 5
	test	al, al
	jz	$_005
	mov	ebx, 7
$_005:	jmp	$_007

$_006:	mov	ebx, 3
	test	al, al
	jz	$_007
	mov	ebx, 5
$_007:	mov	rdx, qword ptr [rsi+0x68]
	movzx	eax, byte ptr [rdx+0x6]
	xor	eax, 0x01
	mov	ecx, eax
	call	OutputByte@PLT
	mov	ecx, ebx
	call	OutputByte@PLT
	mov	dword ptr [rsi+0x14], 629
	mov	eax, 629
	lea	r11, [optable_idx+rip]
	movzx	eax, word ptr [r11+rax*2-0x4E8]
	lea	rax, [r12+rax*8+0x2740]
	mov	qword ptr [rsi+0x68], rax
	leave
	pop	rbx
	pop	rsi
	ret

$_008:
	mov	qword ptr [rsp+0x8], rcx
	push	rbp
	mov	rbp, rsp
	sub	rsp, 32
	cmp	dword ptr [Parse_Pass+rip], 1
	jnz	$_009
	mov	ecx, 7003
	call	asmerr@PLT
$_009:	mov	ecx, 14
	call	OutputByte@PLT
	mov	rcx, qword ptr [rbp+0x10]
	mov	byte ptr [rcx+0x8], 129
	leave
	ret

process_branch:
	mov	qword ptr [rsp+0x10], rdx
	push	rsi
	push	rdi
	push	rbx
	push	rbp
	mov	rbp, rsp
	sub	rsp, 72
	mov	rsi, rcx
	mov	rbx, r8
	cmp	dword ptr [rbp+0x30], 0
	jz	$_010
	mov	ecx, 2070
	call	asmerr@PLT
	jmp	$_122

$_010:	test	byte ptr [rbx+0x40], 0x02
	jz	$_011
	cmp	dword ptr [rbx+0x38], 317
	jz	$_011
	mov	al, byte ptr [rbx+0x44]
	mov	byte ptr [rsi+0x8], al
$_011:	cmp	qword ptr [rbx+0x30], 0
	jz	$_013
	xor	edx, edx
	mov	rcx, rbx
	call	segm_override@PLT
	mov	rcx, qword ptr [rbx+0x50]
	mov	rax, qword ptr [SegOverride+rip]
	test	rax, rax
	jz	$_013
	test	rcx, rcx
	jz	$_013
	cmp	qword ptr [rcx+0x40], 0
	jz	$_013
	mov	rdx, qword ptr [rcx+0x40]
	mov	rdx, qword ptr [rdx+0x78]
	mov	rdx, qword ptr [rdx]
	cmp	rax, qword ptr [rcx+0x40]
	jz	$_012
	cmp	rax, rdx
	jz	$_012
	mov	rdx, qword ptr [rcx+0x8]
	mov	ecx, 2074
	call	asmerr@PLT
	jmp	$_122

$_012:	mov	rcx, qword ptr [r14+0x38]
	mov	rdx, qword ptr [rcx+0x78]
	mov	rdx, qword ptr [rdx]
	cmp	rax, rcx
	jz	$_013
	cmp	rax, rdx
	jz	$_013
	mov	byte ptr [rsi+0x8], 130
$_013:	mov	eax, dword ptr [rbx]
	mov	dword ptr [rsi+0x30], eax
	mov	dword ptr [rsi+0x34], 0
	mov	rdi, qword ptr [rbx+0x50]
	test	rdi, rdi
	jnz	$_014
	mov	ecx, 2076
	call	asmerr@PLT
	jmp	$_122

$_014:	movzx	eax, byte ptr [rdi+0x1D]
	mov	dword ptr [rbp-0x10], eax
	call	GetCurrOffset@PLT
	mov	dword ptr [rbp-0x4], eax
	cmp	dword ptr [rbp-0x10], 2
	jnz	$_015
	test	byte ptr [rdi+0x4B], 0x02
	jz	$_015
	mov	dword ptr [rbp-0x10], 0
$_015:	cmp	dword ptr [rbp-0x10], 1
	jz	$_016
	cmp	dword ptr [rbp-0x10], 2
	jne	$_026
$_016:	mov	eax, dword ptr [Parse_Pass+rip]
	and	eax, 0xFF
	mov	ecx, dword ptr [rbp-0x4]
	cmp	dword ptr [rbp-0x10], 1
	jnz	$_017
	cmp	byte ptr [rdi+0x4A], al
	jz	$_017
	cmp	dword ptr [rdi+0x30], ecx
	jge	$_017
	jmp	$_018

$_017:	mov	eax, dword ptr [rdi+0x30]
	mov	dword ptr [rbp-0x4], eax
$_018:	mov	rax, qword ptr [rdi+0x40]
	mov	qword ptr [rbp-0x20], rax
	test	rax, rax
	jz	$_019
	cmp	rax, qword ptr [r14+0x38]
	jz	$_025
$_019:	test	rax, rax
	jz	$_020
	mov	rcx, qword ptr [rax+0x78]
$_020:	mov	dl, byte ptr [r14+0x4]
	cmp	qword ptr [r14+0x40], 0
	jz	$_022
	test	rax, rax
	jz	$_021
	cmp	byte ptr [rcx+0x1D], dl
	jnz	$_022
$_021:	jmp	$_024

$_022:	test	rax, rax
	jz	$_024
	cmp	qword ptr [r14+0x38], 0
	jz	$_024
	mov	rax, qword ptr [r14+0x38]
	mov	rdx, qword ptr [rax+0x78]
	mov	rax, qword ptr [rcx]
	test	rax, rax
	jz	$_023
	cmp	rax, qword ptr [rdx]
	jnz	$_023
	mov	al, byte ptr [r14+0x4]
	cmp	byte ptr [rcx+0x1D], al
	jnz	$_023
	jmp	$_024

$_023:	cmp	dword ptr [Parse_Pass+rip], 0
	jbe	$_024
	cmp	byte ptr [rbx+0x44], 129
	jnz	$_024
	cmp	qword ptr [SegOverride+rip], 0
	jnz	$_024
	mov	ecx, 2107
	call	asmerr@PLT
	jmp	$_122

$_024:	mov	dword ptr [rbp-0x10], 2
$_025:	jmp	$_027

$_026:	cmp	dword ptr [rbp-0x10], 0
	jz	$_027
	mov	ecx, 2076
	call	asmerr@PLT
	jmp	$_122

$_027:	cmp	dword ptr [rbp-0x10], 2
	je	$_051
	cmp	qword ptr [SegOverride+rip], 0
	jz	$_028
	cmp	byte ptr [rsi+0x8], 192
	jnz	$_028
	mov	ecx, 1
	call	GetOverrideAssume@PLT
	cmp	qword ptr [SegOverride+rip], rax
	jz	$_028
	mov	byte ptr [rsi+0x8], 130
$_028:	cmp	byte ptr [rsi+0x8], 192
	jz	$_029
	cmp	byte ptr [rsi+0x8], 129
	jne	$_051
$_029:	test	byte ptr [rsi], 0x04
	jne	$_051
	cmp	dword ptr [rsi+0x14], 628
	jnz	$_031
	cmp	byte ptr [rsi+0x8], 192
	jnz	$_031
	cmp	byte ptr [rdi+0x1E], 130
	jz	$_030
	cmp	qword ptr [SegOverride+rip], 0
	jz	$_031
$_030:	mov	rcx, rsi
	call	$_008
$_031:	call	GetCurrOffset@PLT
	mov	edx, dword ptr [rbp-0x4]
	sub	edx, eax
	sub	edx, 2
	add	edx, dword ptr [rsi+0x30]
	mov	eax, dword ptr [rsi+0x14]
	lea	r11, [optable_idx+rip]
	movzx	eax, word ptr [r11+rax*2-0x4E8]
	lea	rax, [r12+rax*8+0x2740]
	cmp	byte ptr [rsi+0x9], 0
	jz	$_032
	cmp	byte ptr [rax+0x1], 3
	jz	$_033
$_032:	cmp	byte ptr [rsi+0x9], 1
	jz	$_034
	cmp	byte ptr [rax+0x1], 4
	jnz	$_034
$_033:	dec	edx
$_034:	mov	ecx, 65536
	cmp	edx, -128
	jl	$_035
	cmp	edx, 127
	jg	$_035
	cmp	byte ptr [rsi+0x8], 129
	jz	$_035
	cmp	dword ptr [rsi+0x14], 628
	jne	$_045
$_035:	cmp	dword ptr [rbx+0x38], 317
	jz	$_036
	cmp	dword ptr [rsi+0x14], 660
	jc	$_041
	cmp	dword ptr [rsi+0x14], 677
	jnc	$_041
$_036:	cmp	dword ptr [rsi+0x14], 628
	jnz	$_037
	lea	rdx, [DS0000+rip]
	mov	ecx, 2008
	call	asmerr@PLT
	jmp	$_122

$_037:	cmp	edx, 0
	jge	$_038
	sub	edx, -128
	xor	eax, eax
	sub	eax, edx
	mov	edx, eax
	jmp	$_039

$_038:	sub	edx, 127
$_039:	cmp	byte ptr [rsi+0x8], 192
	jnz	$_040
	mov	ecx, 2075
	call	asmerr@PLT
	jmp	$_122

$_040:	mov	ecx, 2080
	call	asmerr@PLT
	jmp	$_122

$_041:	mov	ecx, 262144
	mov	ah, byte ptr [rbx+0x46]
	mov	al, byte ptr [rsi+0x9]
	cmp	ah, 254
	jz	$_042
	cmp	al, ah
	movzx	eax, al
	setne	al
	shl	al, 5
	and	byte ptr [rsi+0x1], 0xDF
	or	byte ptr [rsi+0x1], al
	sub	edx, eax
	mov	al, byte ptr [rbx+0x46]
$_042:	cmp	al, 0
	jbe	$_043
	sub	edx, 3
	jmp	$_044

$_043:	mov	ecx, 131072
	dec	edx
$_044:	mov	eax, dword ptr [rsi+0x14]
	cmp	eax, 630
	jc	$_045
	cmp	eax, 659
	ja	$_045
	dec	edx
$_045:	mov	dword ptr [rbp-0x4], edx
	mov	dword ptr [rsi+0x20], ecx
	mov	dword ptr [rsi+0x30], edx
	movzx	eax, byte ptr [r14+0x14]
	and	eax, 0x9F
	test	eax, 0x80
	jz	$_046
	mov	eax, 128
	jmp	$_047

$_046:	cmp	eax, 6
	jc	$_047
	mov	eax, 6
$_047:	mov	ecx, eax
	cmp	ecx, 3
	jnc	$_050
	cmp	dword ptr [rsi+0x14], 629
	jbe	$_050
	cmp	dword ptr [rsi+0x14], 660
	jnc	$_050
	cmp	dword ptr [rsi+0x20], 65536
	jz	$_050
	cmp	byte ptr [rsi+0x8], 192
	jnz	$_048
	test	byte ptr [r14+0x2], 0x40
	jz	$_048
	xor	edx, edx
	mov	rcx, rsi
	call	$_001
	sub	dword ptr [rbp-0x4], 1
	mov	eax, dword ptr [rbp-0x4]
	mov	dword ptr [rsi+0x30], eax
	jmp	$_050

$_048:	mov	eax, 2079
	cmp	byte ptr [rsi+0x8], 192
	jnz	$_049
	mov	eax, 2075
$_049:	mov	edx, dword ptr [rbp-0x4]
	mov	ecx, eax
	call	asmerr@PLT
	jmp	$_122

$_050:	cmp	dword ptr [rbp-0x10], 0
	jz	$_051
	xor	eax, eax
	jmp	$_122

$_051:	mov	dword ptr [rbp-0xC], 1
	mov	dword ptr [rbp-0x8], 1
	mov	al, byte ptr [rbx+0x44]
	mov	byte ptr [rbp-0x11], al
	cmp	dword ptr [rsi+0x14], 628
	jnz	$_055
	cmp	byte ptr [rsi+0x8], 192
	jnz	$_055
	cmp	byte ptr [rdi+0x1E], 130
	jz	$_052
	cmp	qword ptr [SegOverride+rip], 0
	jz	$_055
$_052:	mov	rax, qword ptr [rdi+0x40]
	mov	qword ptr [rbp-0x20], rax
	xor	ecx, ecx
	test	rax, rax
	jz	$_053
	mov	rcx, qword ptr [rax+0x78]
	test	rcx, rcx
	jz	$_053
	mov	rcx, qword ptr [rcx]
$_053:	mov	rdx, qword ptr [r14+0x38]
	mov	rdx, qword ptr [rdx+0x78]
	cmp	rax, qword ptr [r14+0x38]
	jz	$_054
	test	rax, rax
	jz	$_055
	test	rcx, rcx
	jz	$_055
	cmp	rcx, qword ptr [rdx]
	jnz	$_055
$_054:	mov	rcx, rsi
	call	$_008
$_055:	mov	al, byte ptr [rbp-0x11]
	cmp	byte ptr [rsi+0x8], 192
	jnz	$_062
	cmp	al, 192
	jz	$_062
	cmp	dword ptr [rbx+0x38], 317
	jz	$_062
	jmp	$_061

$_056:	cmp	dword ptr [rsi+0x14], 628
	jz	$_057
	cmp	dword ptr [rsi+0x14], 629
	jnz	$_058
$_057:	or	byte ptr [rsi], 0x04
$_058:	cmp	dword ptr [rbp-0x10], 0
	jz	$_059
	mov	byte ptr [rsi+0x8], al
$_059:	jmp	$_062

$_060:	mov	byte ptr [rsi+0x8], al
	jmp	$_062

$_061:	cmp	al, 130
	jz	$_056
	cmp	al, 129
	jz	$_058
	jmp	$_060

$_062:	mov	al, byte ptr [rsi+0x8]
	cmp	dword ptr [rsi+0x14], 628
	jz	$_063
	cmp	dword ptr [rsi+0x14], 629
	jne	$_074
$_063:	test	byte ptr [rsi], 0x04
	jnz	$_064
	cmp	al, 130
	jne	$_074
$_064:	or	byte ptr [rsi], 0x04
	jmp	$_072

$_065:	test	byte ptr [rbx+0x40], 0x02
	jnz	$_066
	cmp	dword ptr [rbx+0x38], 317
	jnz	$_067
$_066:	mov	ecx, 2077
	call	asmerr@PLT
	jmp	$_122

$_067:	cmp	byte ptr [rbx+0x46], 254
	jz	$_068
	movzx	ecx, byte ptr [rsi+0x9]
	cmp	cl, byte ptr [rbx+0x46]
	setne	al
	shl	al, 5
	and	byte ptr [rsi+0x1], 0xDF
	or	byte ptr [rsi+0x1], al
	jmp	$_069

$_068:	mov	rcx, rdi
	call	GetSymOfssize@PLT
	movzx	ecx, al
	cmp	cl, byte ptr [rsi+0x9]
	setne	al
	shl	al, 5
	and	byte ptr [rsi+0x1], 0xDF
	or	byte ptr [rsi+0x1], al
$_069:	mov	rcx, rdi
	call	set_frame@PLT
	cmp	byte ptr [rsi+0x9], 0
	setne	al
	test	byte ptr [rsi+0x1], 0x20
	setne	ah
	xor	al, ah
	test	al, al
	jz	$_070
	mov	dword ptr [rbp-0x8], 10
	mov	dword ptr [rsi+0x20], 1073741824
	jmp	$_071

$_070:	mov	dword ptr [rbp-0x8], 9
	mov	dword ptr [rsi+0x20], 262144
$_071:	jmp	$_073

$_072:	cmp	al, 129
	je	$_065
	cmp	al, 130
	jz	$_067
	cmp	al, 192
	je	$_067
$_073:	mov	r8d, dword ptr [rbp-0xC]
	mov	edx, dword ptr [rbp-0x8]
	mov	rcx, rdi
	call	CreateFixup@PLT
	mov	qword ptr [rsi+0x28], rax
	xor	eax, eax
	jmp	$_122

$_074:	mov	eax, dword ptr [rsi+0x14]
	jmp	$_120

$_075:	cmp	dword ptr [rbx+0x38], 317
	jnz	$_076
	mov	ecx, 2077
	call	asmerr@PLT
	jmp	$_122

$_076:	cmp	byte ptr [rsi+0x8], 192
	jnz	$_079
	mov	dword ptr [rbp-0xC], 5
	cmp	byte ptr [rsi+0x9], 0
	jbe	$_077
	mov	dword ptr [rbp-0x8], 3
	mov	dword ptr [rsi+0x20], 262144
	jmp	$_078

$_077:	mov	dword ptr [rbp-0x8], 2
	mov	dword ptr [rsi+0x20], 131072
$_078:	jmp	$_121

$_079:	mov	al, byte ptr [rsi+0x8]
	jmp	$_088

$_080:	mov	dword ptr [rsi+0x20], 65536
	mov	dword ptr [rbp-0x8], 1
	mov	eax, 0
	cmp	dword ptr [rbx+0x38], 317
	jnz	$_081
	mov	eax, 2
$_081:	mov	dword ptr [rbp-0xC], eax
	jmp	$_089

$_082:	mov	dword ptr [rbp-0xC], 2
	cmp	byte ptr [rbx+0x46], 254
	jz	$_085
	cmp	byte ptr [rbx+0x46], 0
	jnz	$_083
	mov	dword ptr [rbp-0x8], 2
	mov	dword ptr [rsi+0x20], 131072
	jmp	$_084

$_083:	mov	dword ptr [rbp-0x8], 3
	mov	dword ptr [rsi+0x20], 262144
$_084:	movzx	ecx, byte ptr [rsi+0x9]
	cmp	cl, byte ptr [rbx+0x46]
	setne	al
	shl	al, 5
	and	byte ptr [rsi+0x1], 0xDF
	or	byte ptr [rsi+0x1], al
	jmp	$_087

$_085:	cmp	byte ptr [rsi+0x9], 0
	jbe	$_086
	mov	dword ptr [rbp-0x8], 3
	mov	dword ptr [rsi+0x20], 262144
	jmp	$_087

$_086:	mov	dword ptr [rbp-0x8], 2
	mov	dword ptr [rsi+0x20], 131072
$_087:	mov	rcx, rdi
	call	set_frame@PLT
	jmp	$_089

$_088:	cmp	al, 192
	je	$_080
	cmp	al, 129
	je	$_082
$_089:	jmp	$_121

$_090:	cmp	eax, 660
	jc	$_092
	cmp	eax, 677
	jnc	$_092
	cmp	byte ptr [rsi+0x8], 192
	jz	$_091
	cmp	dword ptr [rbx+0x38], 317
	jz	$_091
	mov	ecx, 2080
	call	asmerr@PLT
	jmp	$_122

$_091:	mov	dword ptr [rsi+0x20], 65536
	mov	dword ptr [rbp-0xC], 2
	mov	dword ptr [rbp-0x8], 1
	jmp	$_121

$_092:	movzx	eax, byte ptr [r14+0x14]
	and	eax, 0x9F
	test	eax, 0x80
	jz	$_093
	mov	eax, 128
	jmp	$_094

$_093:	cmp	eax, 6
	jc	$_094
	mov	eax, 6
$_094:	cmp	eax, 3
	jc	$_110
	mov	al, byte ptr [rsi+0x8]
	jmp	$_108

$_095:	mov	eax, 4
	cmp	dword ptr [rbx+0x38], 317
	jnz	$_096
	mov	eax, 2
$_096:	mov	dword ptr [rbp-0xC], eax
	mov	dword ptr [rbp-0x8], 1
	mov	dword ptr [rsi+0x20], 65536
	jmp	$_109

$_097:	mov	dword ptr [rbp-0xC], 2
	cmp	byte ptr [rbx+0x46], 254
	jz	$_099
	movzx	ecx, byte ptr [rsi+0x9]
	cmp	cl, byte ptr [rbx+0x46]
	setne	al
	shl	al, 5
	and	byte ptr [rsi+0x1], 0xDF
	or	byte ptr [rsi+0x1], al
	mov	eax, 131072
	cmp	byte ptr [rbx+0x46], 1
	jc	$_098
	mov	eax, 262144
$_098:	mov	dword ptr [rsi+0x20], eax
	jmp	$_101

$_099:	cmp	byte ptr [rsi+0x9], 0
	jbe	$_100
	mov	dword ptr [rbp-0x8], 3
	mov	dword ptr [rsi+0x20], 262144
	jmp	$_101

$_100:	mov	dword ptr [rbp-0x8], 2
	mov	dword ptr [rsi+0x20], 131072
$_101:	jmp	$_109

$_102:	test	byte ptr [r14+0x2], 0x40
	jz	$_107
	cmp	byte ptr [rbx+0x46], 254
	jz	$_103
	movzx	ecx, byte ptr [rsi+0x9]
	cmp	cl, byte ptr [rbx+0x46]
	setne	al
	shl	al, 5
	and	byte ptr [rsi+0x1], 0xDF
	or	byte ptr [rsi+0x1], al
	jmp	$_104

$_103:	mov	rcx, rdi
	call	GetSymOfssize@PLT
	movzx	ecx, al
	cmp	cl, byte ptr [rsi+0x9]
	setne	al
	shl	al, 5
	and	byte ptr [rsi+0x1], 0xDF
	or	byte ptr [rsi+0x1], al
$_104:	mov	edx, 1
	mov	rcx, rsi
	call	$_001
	or	byte ptr [rsi], 0x04
	cmp	byte ptr [rsi+0x9], 0
	setne	al
	test	byte ptr [rsi+0x1], 0x20
	setne	ah
	xor	al, ah
	test	al, al
	jz	$_105
	mov	dword ptr [rbp-0x8], 10
	mov	dword ptr [rsi+0x20], 1073741824
	jmp	$_106

$_105:	mov	dword ptr [rbp-0x8], 9
	mov	dword ptr [rsi+0x20], 262144
$_106:	jmp	$_109

$_107:	mov	ecx, 2080
	call	asmerr@PLT
	jmp	$_122

	jmp	$_109

$_108:	cmp	al, 192
	je	$_095
	cmp	al, 129
	je	$_097
	cmp	al, 130
	je	$_102
	jmp	$_107

$_109:	jmp	$_119

$_110:	mov	al, byte ptr [rsi+0x8]
	jmp	$_118

$_111:	cmp	dword ptr [rbx+0x38], 317
	jnz	$_112
	mov	dword ptr [rbp-0xC], 2
	jmp	$_113

$_112:	mov	dword ptr [rbp-0xC], 3
$_113:	mov	dword ptr [rbp-0x8], 1
	mov	dword ptr [rsi+0x20], 65536
	jmp	$_119

$_114:	test	byte ptr [r14+0x2], 0x40
	jz	$_117
	cmp	al, 130
	jnz	$_115
	mov	edx, 1
	mov	rcx, rsi
	call	$_001
	mov	dword ptr [rbp-0x8], 9
	or	byte ptr [rsi], 0x04
	mov	dword ptr [rsi+0x20], 262144
	jmp	$_116

$_115:	xor	edx, edx
	mov	rcx, rsi
	call	$_001
	mov	dword ptr [rbp-0x8], 2
	mov	dword ptr [rsi+0x20], 131072
$_116:	jmp	$_119

$_117:	mov	ecx, 2080
	call	asmerr@PLT
	jmp	$_122

	jmp	$_119

$_118:	cmp	al, 192
	jz	$_111
	cmp	al, 129
	jz	$_114
	cmp	al, 130
	jz	$_114
	jmp	$_117

$_119:	jmp	$_121

$_120:	cmp	eax, 628
	je	$_075
	cmp	eax, 629
	je	$_079
	jmp	$_090

$_121:	mov	r8d, dword ptr [rbp-0xC]
	mov	edx, dword ptr [rbp-0x8]
	mov	rcx, rdi
	call	CreateFixup@PLT
	mov	qword ptr [rsi+0x28], rax
	mov	eax, 0
$_122:	leave
	pop	rbx
	pop	rdi
	pop	rsi
	ret


.SECTION .data
	.ALIGN	16

DS0000:
	.byte  0x73, 0x68, 0x6F, 0x72, 0x74, 0x00


.att_syntax prefix
