
.intel_syntax noprefix

.global cmpwarg
.global ReadFiles
.global AssembleSubdir
.global main
.global tgetenv
.global _pgmptr

.extern GetFNamePart
.extern MemInit
.extern MemFree
.extern MemAlloc
.extern tprintf
.extern write_logo
.extern asmerr
.extern write_usage
.extern ParseCmdline
.extern CmdlineFini
.extern close_files
.extern AssembleModule
.extern SpecialTable
.extern Options
.extern ModuleInfo
.extern _ltype
.extern tstrcat
.extern tstrcpy
.extern tstrrchr
.extern tstrchr
.extern tstrlen
.extern tmemicmp
.extern CollectLinkObject
.extern CollectLinkOption
.extern exit
.extern closedir
.extern readdir
.extern opendir
.extern sigaction


.SECTION .text
	.ALIGN	16

$_001:	mov	qword ptr [rsp+0x8], rcx
	mov	qword ptr [rsp+0x10], rdx
	push	rsi
	push	rdi
	push	rbx
	push	rbp
	mov	rbp, rsp
	sub	rsp, 312
	mov	qword ptr [rbp-0x8], 0
	mov	rbx, qword ptr [Options+0x18+rip]
	test	rbx, rbx
	jz	$_008
	mov	edx, 42
	mov	rcx, rbx
	call	tstrchr@PLT
	test	rax, rax
	jz	$_008
	mov	rdx, qword ptr [rbp+0x28]
	lea	rcx, [rbp-0x10C]
	call	tstrcpy@PLT
	mov	edx, 46
	mov	rcx, rax
	call	tstrrchr@PLT
	test	rax, rax
	jz	$_002
	mov	byte ptr [rax], 0
$_002:	mov	qword ptr [rbp-0x8], rbx
	mov	rdx, qword ptr [rbp+0x30]
	mov	qword ptr [Options+0x18+rip], rdx
$_003:	mov	al, byte ptr [rbx]
	cmp	al, 42
	jnz	$_006
	lea	rcx, [rbp-0x10C]
$_004:	mov	al, byte ptr [rcx]
	test	al, al
	jz	$_005
	mov	byte ptr [rdx], al
	inc	rcx
	inc	rdx
	jmp	$_004

$_005:	jmp	$_007

$_006:	mov	byte ptr [rdx], al
	inc	rdx
	test	al, al
	jz	$_008
$_007:	inc	rbx
	jmp	$_003

$_008:
	mov	rax, qword ptr [rbp-0x8]
	leave
	pop	rbx
	pop	rdi
	pop	rsi
	ret

cmpwarg:
	push	rsi
	push	rdi
	push	rbp
	mov	rbp, rsp
	mov	rdi, rcx
	mov	rsi, rdx
	xor	eax, eax
$_009:	lodsb
	mov	ah, byte ptr [rdi]
	inc	rdi
	cmp	ah, 42
	jnz	$_015
$_010:	mov	ah, byte ptr [rdi]
	test	ah, ah
	jnz	$_011
	mov	eax, 1
	jmp	$_018

$_011:	inc	rdi
	cmp	ah, 46
	jnz	$_010
	xor	edx, edx
	jmp	$_014

$_012:	cmp	al, ah
	jnz	$_013
	mov	rdx, rsi
$_013:	lodsb
$_014:	test	al, al
	jnz	$_012
	mov	rsi, rdx
	test	rdx, rdx
	jnz	$_009
	mov	ah, byte ptr [rdi]
	inc	rdi
	cmp	ah, 42
	jz	$_010
	test	eax, eax
	mov	ah, 0
	sete	al
	jmp	$_018

	jmp	$_010

$_015:	mov	edx, eax
	xor	eax, eax
	test	dl, dl
	jnz	$_016
	test	edx, edx
	jnz	$_018
	inc	eax
	jmp	$_018

$_016:	test	dh, dh
	jz	$_018
	cmp	dh, 63
	jz	$_009
	cmp	dh, 46
	jnz	$_017
	cmp	dl, 46
	jz	$_009
	jmp	$_018

$_017:	cmp	dl, 46
	jz	$_018
	or	edx, 0x2020
	cmp	dl, dh
	jnz	$_018
	jmp	$_009

$_018:
	leave
	pop	rdi
	pop	rsi
	ret

ReadFiles:
	mov	qword ptr [rsp+0x8], rcx
	mov	qword ptr [rsp+0x10], rdx
	mov	qword ptr [rsp+0x18], r8
	push	rsi
	push	rdi
	push	rbx
	push	rbp
	mov	rbp, rsp
	sub	rsp, 56
	mov	rbx, rcx
	cmp	byte ptr [rbx], 0
	jnz	$_019
	mov	word ptr [rbx], 46
$_019:	mov	rcx, rbx
	call	tstrlen@PLT
	lea	rax, [rbx+rax]
	mov	qword ptr [rbp-0x8], rax
	mov	rdi, qword ptr [rbp+0x28]
	call	opendir@PLT
	test	rax, rax
	je	$_027
	mov	qword ptr [rbp-0x10], rax
	mov	dword ptr [rbp-0x14], 0
	jmp	$_026

$_020:	mov	rbx, rax
	cmp	byte ptr [rbx+0x12], 4
	jz	$_023
	lea	rdx, [rbx+0x13]
	mov	rcx, qword ptr [rbp+0x30]
	call	cmpwarg
	test	rax, rax
	jz	$_022
	mov	rcx, qword ptr [rbp-0x8]
	mov	word ptr [rcx], 47
	lea	rdx, [rbx+0x13]
	call	tstrcat@PLT
	mov	rcx, qword ptr [rbp+0x28]
	call	tstrlen@PLT
	add	rax, 16
	mov	ecx, eax
	call	MemAlloc@PLT
	test	rax, rax
	jz	$_021
	mov	rcx, qword ptr [rbp+0x38]
	mov	qword ptr [rcx], rax
	mov	qword ptr [rbp+0x38], rax
	mov	qword ptr [rax], 0
	mov	rdx, qword ptr [rbp+0x28]
	lea	rcx, [rax+0x8]
	call	tstrcpy@PLT
	inc	dword ptr [rbp-0x14]
$_021:	mov	rcx, qword ptr [rbp-0x8]
	mov	byte ptr [rcx], 0
$_022:	jmp	$_026

$_023:	test	byte ptr [Options+0x4+rip], 0x10
	jz	$_026
	mov	eax, dword ptr [rbx+0x13]
	and	eax, 0xFFFFFF
	cmp	ax, 46
	jz	$_026
	cmp	eax, 11822
	jz	$_026
	mov	rcx, qword ptr [rbp-0x8]
	mov	word ptr [rcx], 47
	lea	rdx, [rbx+0x13]
	call	tstrcat@PLT
	mov	r8, qword ptr [rbp+0x38]
	mov	rdx, qword ptr [rbp+0x30]
	mov	rcx, qword ptr [rbp+0x28]
	call	ReadFiles
	add	dword ptr [rbp-0x14], eax
	mov	rcx, qword ptr [rbp-0x8]
	mov	byte ptr [rcx], 0
	mov	rcx, qword ptr [rbp+0x38]
	jmp	$_025

$_024:	mov	rcx, qword ptr [rcx]
$_025:	cmp	qword ptr [rcx], 0
	jnz	$_024
	mov	qword ptr [rbp+0x38], rcx
$_026:	mov	rdi, qword ptr [rbp-0x10]
	call	readdir@PLT
	test	rax, rax
	jne	$_020
	mov	rdi, qword ptr [rbp-0x10]
	call	closedir@PLT
$_027:	mov	eax, dword ptr [rbp-0x14]
	leave
	pop	rbx
	pop	rdi
	pop	rsi
	ret

AssembleSubdir:
	push	rbx
	push	rbp
	mov	rbp, rsp
	sub	rsp, 104
	mov	qword ptr [rbp-0x48], rdx
	mov	qword ptr [rbp-0x40], rsi
	mov	qword ptr [rbp-0x38], rdi
	mov	dword ptr [rbp-0xC], 0
	xor	eax, eax
	mov	qword ptr [rbp-0x20], rax
	mov	qword ptr [rbp-0x18], rax
	lea	r8, [rbp-0x20]
	mov	rdx, qword ptr [rbp-0x40]
	mov	rcx, qword ptr [rbp-0x38]
	call	ReadFiles
	mov	dword ptr [rbp-0x24], eax
	mov	rbx, qword ptr [rbp-0x20]
$_028:	test	rbx, rbx
	jz	$_031
	mov	rdx, qword ptr [rbp-0x48]
	lea	rcx, [rbx+0x8]
	call	$_001
	mov	qword ptr [rbp-0x8], rax
	lea	rcx, [rbx+0x8]
	call	AssembleModule@PLT
	test	rax, rax
	jz	$_029
	mov	dword ptr [rbp-0xC], eax
$_029:	mov	rax, qword ptr [rbp-0x8]
	test	rax, rax
	jz	$_030
	mov	qword ptr [Options+0x18+rip], rax
$_030:	mov	rcx, rbx
	mov	rbx, qword ptr [rbx]
	call	MemFree@PLT
	jmp	$_028

$_031:
	mov	eax, dword ptr [rbp-0xC]
	leave
	pop	rbx
	ret

GeneralFailure:
	push	rbp
	mov	rbp, rsp
	sub	rsp, 192
	mov	dword ptr [rbp-0x10], edi
	cmp	dword ptr [rbp-0x10], 15
	je	$_033
	lea	rdi, [DS0000+rip]
	mov	rbx, rdx
	add	rbx, 40
	mov	rax, qword ptr [rbx+0x88]
	mov	ecx, 16
$_032:	shr	eax, 1
	adc	byte ptr [rdi+rcx+0x108], 0
	dec	rcx
	jnz	$_032
	mov	rcx, qword ptr [rbx+0x80]
	mov	rdx, qword ptr [rcx]
	mov	r10, qword ptr [rcx-0x8]
	mov	r11, qword ptr [rcx+0x8]
	mov	qword ptr [rsp+0xA0], r11
	mov	qword ptr [rsp+0x98], r10
	mov	qword ptr [rsp+0x90], rdx
	mov	qword ptr [rsp+0x88], rcx
	mov	rax, qword ptr [rbx+0x38]
	mov	qword ptr [rsp+0x80], rax
	mov	rax, qword ptr [rbx+0x78]
	mov	qword ptr [rsp+0x78], rax
	mov	rax, qword ptr [rbx+0x30]
	mov	qword ptr [rsp+0x70], rax
	mov	rax, qword ptr [rbx+0x50]
	mov	qword ptr [rsp+0x68], rax
	mov	rax, qword ptr [rbx+0x28]
	mov	qword ptr [rsp+0x60], rax
	mov	rax, qword ptr [rbx+0x40]
	mov	qword ptr [rsp+0x58], rax
	mov	rax, qword ptr [rbx+0x20]
	mov	qword ptr [rsp+0x50], rax
	mov	rax, qword ptr [rbx+0x48]
	mov	qword ptr [rsp+0x48], rax
	mov	rax, qword ptr [rbx+0x18]
	mov	qword ptr [rsp+0x40], rax
	mov	rax, qword ptr [rbx+0x60]
	mov	qword ptr [rsp+0x38], rax
	mov	rax, qword ptr [rbx+0x10]
	mov	qword ptr [rsp+0x30], rax
	mov	rax, qword ptr [rbx+0x70]
	mov	qword ptr [rsp+0x28], rax
	mov	rax, qword ptr [rbx+0x8]
	mov	qword ptr [rsp+0x20], rax
	mov	r9, qword ptr [rbx+0x58]
	mov	r8, qword ptr [rbx]
	mov	rdx, qword ptr [rbx+0x68]
	mov	rcx, rdi
	call	tprintf@PLT
	mov	rdx, qword ptr [Options+0x10+rip]
	lea	rcx, [DS0001+rip]
	call	tprintf@PLT
	mov	edx, 1
	mov	rsi, rdi
	xor	edi, edi
	xor	eax, eax
	syscall
	mov	ecx, 1901
	call	asmerr@PLT
$_033:	call	close_files@PLT
	mov	edi, 1
	call	exit@PLT

main:
	push	rbp
	mov	rbp, rsp
	sub	rsp, 784
	mov	qword ptr [rbp-0x2F0], rdx
	mov	qword ptr [rbp-0x2E8], rsi
	mov	dword ptr [rbp-0x4], 0
	mov	dword ptr [rbp-0x8], 0
	mov	dword ptr [rbp-0xC], 0
	mov	rax, qword ptr [rbp-0x2F0]
	mov	qword ptr [my_environ+rip], rax
	lea	rax, [rbp-0x110]
	mov	qword ptr [rbp-0x118], rax
	call	MemInit@PLT
	lea	rax, [GeneralFailure@PLT+rip]
	mov	qword ptr [rbp-0x1B0], rax
	mov	dword ptr [rbp-0x1A8], 4
	xor	edx, edx
	lea	rsi, [rbp-0x1B0]
	mov	edi, 11
	call	sigaction@PLT
	lea	rcx, [DS0002+rip]
	call	tgetenv
	test	rax, rax
	jnz	$_034
	lea	rax, [DS0002+0x4+rip]
$_034:	mov	rcx, qword ptr [rbp-0x2E8]
	mov	rdx, qword ptr [rcx]
	mov	qword ptr [_pgmptr+rip], rdx
	mov	qword ptr [rcx], rax
	lea	r12, [SpecialTable+rip]
	lea	r14, [ModuleInfo+rip]
	lea	r15, [_ltype+rip]
	jmp	$_039

$_035:	call	write_logo@PLT
	inc	dword ptr [rbp-0xC]
	mov	rbx, qword ptr [Options+0x10+rip]
	mov	rdx, rbx
	mov	rcx, qword ptr [rbp-0x118]
	call	tstrcpy@PLT
	mov	edx, 42
	mov	rcx, rax
	call	tstrchr@PLT
	test	rax, rax
	jnz	$_036
	mov	edx, 63
	mov	rcx, qword ptr [rbp-0x118]
	call	tstrchr@PLT
$_036:	test	rax, rax
	jz	$_038
	mov	rcx, qword ptr [rbp-0x118]
	call	GetFNamePart@PLT
	cmp	rax, qword ptr [rbp-0x118]
	jbe	$_037
	dec	rax
$_037:	mov	byte ptr [rax], 0
	mov	rcx, rbx
	call	GetFNamePart@PLT
	mov	rcx, rax
	lea	rdx, [rbp-0x2BC]
	mov	rsi, rcx
	mov	rdi, qword ptr [rbp-0x118]
	call	AssembleSubdir
	mov	dword ptr [rbp-0x4], eax
	jmp	$_039

$_038:	mov	rcx, rbx
	call	GetFNamePart@PLT
	mov	rcx, rax
	lea	rdx, [rbp-0x2BC]
	call	$_001
	mov	qword ptr [rbp-0x1B8], rax
	mov	rcx, rbx
	call	AssembleModule@PLT
	mov	dword ptr [rbp-0x4], eax
	mov	rax, qword ptr [rbp-0x1B8]
	test	rax, rax
	jz	$_039
	mov	qword ptr [Options+0x18+rip], rax
$_039:	lea	rdx, [rbp-0x8]
	mov	rcx, qword ptr [rbp-0x2E8]
	call	ParseCmdline@PLT
	test	rax, rax
	jne	$_035
	call	CmdlineFini@PLT
	cmp	dword ptr [rbp-0x8], 0
	jnz	$_040
	call	write_usage@PLT
	jmp	$_085

$_040:	cmp	dword ptr [rbp-0xC], 0
	jnz	$_041
	mov	ecx, 1017
	call	asmerr@PLT
	jmp	$_085

$_041:	cmp	dword ptr [rbp-0x4], 1
	jne	$_085
	test	byte ptr [Options+0x7+rip], 0x04
	jne	$_085
	cmp	dword ptr [Options+0x8C+rip], 3
	jne	$_085
	mov	dword ptr [rbp-0x2D0], -1
	mov	rbx, qword ptr [Options+0x78+rip]
	xor	ecx, ecx
	mov	rbx, qword ptr [Options+0x78+rip]
$_042:	test	rbx, rbx
	jz	$_054
	mov	eax, dword ptr [rbx+0x9]
	or	eax, 0x20202020
	jmp	$_052

$_043:
	cmp	ax, 8303
	jnz	$_044
	or	ecx, 0x01
$_044:	jmp	$_053

$_045:	cmp	eax, 1952543859
	jnz	$_046
	or	ecx, 0x08
	jmp	$_048

$_046:
	cmp	ax, 8307
	jz	$_047
	cmp	ax, 8295
	jnz	$_048
$_047:	or	ecx, 0x10
$_048:
	cmp	ax, 14956
	jnz	$_049
	or	ecx, 0x02
$_049:	jmp	$_053

$_050:	cmp	eax, 1953722222
	jnz	$_051
	or	ecx, 0x04
$_051:	jmp	$_053

$_052:	cmp	al, 111
	jz	$_043
	cmp	al, 115
	jz	$_045
	cmp	al, 108
	jz	$_048
	cmp	al, 110
	jz	$_050
$_053:	mov	rbx, qword ptr [rbx]
	jmp	$_042

$_054:	mov	dword ptr [rbp-0x2D4], ecx
	cmp	qword ptr [Options+0x70+rip], 0
	jne	$_067
	cmp	dword ptr [Options+0x9C+rip], 3
	jz	$_055
	lea	rcx, [DS0003+rip]
	call	CollectLinkOption@PLT
$_055:	test	byte ptr [Options+0x1+rip], 0x01
	jz	$_056
	lea	rcx, [DS0004+rip]
	call	CollectLinkOption@PLT
	jmp	$_062

$_056:	test	byte ptr [Options+0x7+rip], 0x08
	jnz	$_057
	test	byte ptr [Options+rip], 0x40
	jnz	$_061
	test	byte ptr [Options+rip], 0x80
	jnz	$_061
$_057:	test	byte ptr [rbp-0x2D4], 0x08
	jnz	$_058
	lea	rcx, [DS0005+rip]
	call	CollectLinkOption@PLT
$_058:	lea	rcx, [DS0006+rip]
	call	CollectLinkOption@PLT
	test	byte ptr [Options+0x7+rip], 0x08
	jz	$_060
	test	byte ptr [rbp-0x2D4], 0x06
	jnz	$_060
	lea	rcx, [DS0007+rip]
	call	CollectLinkOption@PLT
	cmp	dword ptr [Options+0x9C+rip], 3
	jnz	$_059
	lea	rcx, [DS0008+rip]
	call	CollectLinkObject@PLT
	jmp	$_060

$_059:	lea	rcx, [DS0009+rip]
	call	CollectLinkObject@PLT
$_060:	jmp	$_062

$_061:	lea	rcx, [DS000A+rip]
	call	CollectLinkOption@PLT
$_062:	test	byte ptr [rbp-0x2D4], 0x06
	jnz	$_063
	test	byte ptr [Options+0x4+rip], 0x02
	jnz	$_063
	lea	rcx, [DS000B+rip]
	call	CollectLinkOption@PLT
$_063:	test	byte ptr [rbp-0x2D4], 0x10
	jnz	$_064
	test	byte ptr [Options+0x4+rip], 0x02
	jnz	$_064
	lea	rcx, [DS000C+rip]
	call	CollectLinkOption@PLT
$_064:	test	byte ptr [rbp-0x2D4], 0x01
	jnz	$_067
	lea	rcx, [DS000D+rip]
	call	CollectLinkOption@PLT
	mov	rcx, qword ptr [Options+0x68+rip]
	test	rcx, rcx
	jnz	$_066
	mov	rcx, qword ptr [Options+0x80+rip]
	lea	rdx, [rcx+0x8]
	lea	rcx, [rbp-0xF0]
	call	tstrcpy@PLT
	mov	edx, 46
	mov	rcx, rax
	call	tstrrchr@PLT
	test	rax, rax
	jz	$_065
	mov	byte ptr [rax], 0
$_065:	lea	rcx, [rbp-0xF0]
$_066:	call	CollectLinkOption@PLT
$_067:	lea	rbx, [DS000E+rip]
	cmp	qword ptr [Options+0x70+rip], 0
	jz	$_068
	mov	rbx, qword ptr [Options+0x70+rip]
$_068:	mov	rdx, rbx
	mov	rcx, qword ptr [rbp-0x118]
	call	tstrcpy@PLT
	test	byte ptr [Options+0x4+rip], 0x01
	jnz	$_071
	lea	rcx, [DS000F+rip]
	call	tprintf@PLT
	mov	rbx, qword ptr [Options+0x78+rip]
$_069:	test	rbx, rbx
	jz	$_070
	lea	rdx, [rbx+0x8]
	lea	rcx, [DS0010+rip]
	call	tprintf@PLT
	mov	rbx, qword ptr [rbx]
	jmp	$_069

$_070:	lea	rcx, [DS0001+0x9+rip]
	call	tprintf@PLT
$_071:	mov	ebx, 2
	mov	rcx, qword ptr [Options+0x78+rip]
$_072:	test	rcx, rcx
	jz	$_073
	mov	rcx, qword ptr [rcx]
	inc	ebx
	jmp	$_072

$_073:	mov	rcx, qword ptr [Options+0x80+rip]
$_074:	test	rcx, rcx
	jz	$_075
	mov	rcx, qword ptr [rcx]
	inc	ebx
	jmp	$_074

$_075:	lea	ecx, [rbx*8]
	call	MemAlloc@PLT
	mov	qword ptr [rbp-0x2C8], rax
	mov	rcx, qword ptr [rbp-0x118]
	mov	qword ptr [rax], rcx
	lea	rbx, [rax+0x8]
	mov	rcx, qword ptr [Options+0x80+rip]
$_076:	test	rcx, rcx
	jz	$_077
	lea	rax, [rcx+0x8]
	mov	qword ptr [rbx], rax
	mov	rcx, qword ptr [rcx]
	add	rbx, 8
	jmp	$_076

$_077:	mov	rcx, qword ptr [Options+0x78+rip]
$_078:	test	rcx, rcx
	jz	$_079
	lea	rax, [rcx+0x8]
	mov	qword ptr [rbx], rax
	mov	rcx, qword ptr [rcx]
	add	rbx, 8
	jmp	$_078

$_079:	xor	eax, eax
	mov	qword ptr [rbx], rax
	mov	eax, 57
	syscall
	mov	dword ptr [rbp-0x2CC], eax
	cmp	dword ptr [rbp-0x2CC], 0
	jnz	$_080
	mov	rdx, qword ptr [rbp-0x2F0]
	mov	rsi, qword ptr [rbp-0x2C8]
	mov	rdi, qword ptr [rbp-0x118]
	mov	eax, 59
	syscall
	xor	edi, edi
	mov	eax, 60
	syscall
	jmp	$_084

$_080:	cmp	dword ptr [rbp-0x2CC], 0
	jle	$_083
	xor	ecx, ecx
	xor	edx, edx
	lea	rsi, [rbp-0x2D0]
	mov	edi, dword ptr [rbp-0x2CC]
	mov	r10, rcx
	mov	eax, 61
	syscall
	cmp	eax, 0
	jge	$_081
	mov	eax, 4294967295
	jmp	$_082

$_081:	mov	eax, dword ptr [rbp-0x2D0]
$_082:	jmp	$_084

$_083:	mov	eax, 4294967295
$_084:	cmp	eax, -1
	jnz	$_085
	mov	rdx, qword ptr [rbp-0x118]
	mov	ecx, 2018
	call	asmerr@PLT
	mov	dword ptr [rbp-0x4], 0
$_085:	mov	eax, 1
	sub	eax, dword ptr [rbp-0x4]
	leave
	ret

tgetenv:
	push	rsi
	push	rdi
	push	rbx
	push	rbp
	mov	rbp, rsp
	sub	rsp, 40
	mov	rbx, rcx
	call	tstrlen@PLT
	test	eax, eax
	jz	$_089
	mov	edi, eax
	mov	rsi, qword ptr [my_environ+rip]
	mov	rax, qword ptr [rsi]
	add	rsi, 8
	jmp	$_088

$_086:	mov	r8d, edi
	mov	rdx, rbx
	mov	rcx, rax
	call	tmemicmp@PLT
	test	eax, eax
	jnz	$_087
	mov	rax, qword ptr [rsi-0x8]
	add	rax, rdi
	cmp	byte ptr [rax], 61
	jnz	$_087
	lea	rax, [rax+0x1]
	jmp	$_089

$_087:	mov	rax, qword ptr [rsi]
	add	rsi, 8
$_088:	test	rax, rax
	jnz	$_086
$_089:	leave
	pop	rbx
	pop	rdi
	pop	rsi
	ret


.SECTION .data
	.ALIGN	16

_pgmptr:
	.quad  0x0000000000000000

my_environ:
	.quad  0x0000000000000000

DS0000:
	.byte  0x0A, 0x54, 0x68, 0x69, 0x73, 0x20, 0x6D, 0x65
	.byte  0x73, 0x73, 0x61, 0x67, 0x65, 0x20, 0x69, 0x73
	.byte  0x20, 0x63, 0x72, 0x65, 0x61, 0x74, 0x65, 0x64
	.byte  0x20, 0x64, 0x75, 0x65, 0x20, 0x74, 0x6F, 0x20
	.byte  0x75, 0x6E, 0x72, 0x65, 0x63, 0x6F, 0x76, 0x65
	.byte  0x72, 0x61, 0x62, 0x6C, 0x65, 0x20, 0x65, 0x72
	.byte  0x72, 0x6F, 0x72, 0x0A, 0x61, 0x6E, 0x64, 0x20
	.byte  0x6D, 0x61, 0x79, 0x20, 0x63, 0x6F, 0x6E, 0x74
	.byte  0x61, 0x69, 0x6E, 0x20, 0x64, 0x61, 0x74, 0x61
	.byte  0x20, 0x6E, 0x65, 0x63, 0x65, 0x73, 0x73, 0x61
	.byte  0x72, 0x79, 0x20, 0x74, 0x6F, 0x20, 0x6C, 0x6F
	.byte  0x63, 0x61, 0x74, 0x65, 0x20, 0x69, 0x74, 0x2E
	.byte  0x0A, 0x0A, 0x09, 0x52, 0x41, 0x58, 0x3A, 0x20
	.byte  0x25, 0x70, 0x20, 0x52, 0x38, 0x3A, 0x20, 0x20
	.byte  0x25, 0x70, 0x0A, 0x09, 0x52, 0x42, 0x58, 0x3A
	.byte  0x20, 0x25, 0x70, 0x20, 0x52, 0x39, 0x3A, 0x20
	.byte  0x20, 0x25, 0x70, 0x0A, 0x09, 0x52, 0x43, 0x58
	.byte  0x3A, 0x20, 0x25, 0x70, 0x20, 0x52, 0x31, 0x30
	.byte  0x3A, 0x20, 0x25, 0x70, 0x0A, 0x09, 0x52, 0x44
	.byte  0x58, 0x3A, 0x20, 0x25, 0x70, 0x20, 0x52, 0x31
	.byte  0x31, 0x3A, 0x20, 0x25, 0x70, 0x0A, 0x09, 0x52
	.byte  0x53, 0x49, 0x3A, 0x20, 0x25, 0x70, 0x20, 0x52
	.byte  0x31, 0x32, 0x3A, 0x20, 0x25, 0x70, 0x0A, 0x09
	.byte  0x52, 0x44, 0x49, 0x3A, 0x20, 0x25, 0x70, 0x20
	.byte  0x52, 0x31, 0x33, 0x3A, 0x20, 0x25, 0x70, 0x0A
	.byte  0x09, 0x52, 0x42, 0x50, 0x3A, 0x20, 0x25, 0x70
	.byte  0x20, 0x52, 0x31, 0x34, 0x3A, 0x20, 0x25, 0x70
	.byte  0x0A, 0x09, 0x52, 0x53, 0x50, 0x3A, 0x20, 0x25
	.byte  0x70, 0x20, 0x52, 0x31, 0x35, 0x3A, 0x20, 0x25
	.byte  0x70, 0x0A, 0x09, 0x52, 0x49, 0x50, 0x3A, 0x20
	.byte  0x25, 0x70, 0x20, 0x25, 0x70, 0x0A, 0x09, 0x20
	.byte  0x20, 0x20, 0x20, 0x20, 0x25, 0x70, 0x20, 0x25
	.byte  0x70, 0x0A, 0x0A, 0x09, 0x45, 0x46, 0x4C, 0x3A
	.byte  0x20, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30
	.byte  0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30
	.byte  0x30, 0x0A, 0x09, 0x20, 0x20, 0x20, 0x20, 0x20
	.byte  0x72, 0x20, 0x6E, 0x20, 0x6F, 0x64, 0x69, 0x74
	.byte  0x73, 0x7A, 0x20, 0x61, 0x20, 0x70, 0x20, 0x63
	.byte  0x0A, 0x0A, 0x00

DS0001:
	.byte  0x46, 0x69, 0x6C, 0x65, 0x20, 0x3A, 0x20, 0x25
	.byte  0x73, 0x0A, 0x00

DS0002:
	.byte  0x41, 0x53, 0x4D, 0x43, 0x00

DS0003:
	.byte  0x2D, 0x6D, 0x33, 0x32, 0x00

DS0004:
	.byte  0x2D, 0x6E, 0x6F, 0x2D, 0x70, 0x69, 0x65, 0x00

DS0005:
	.byte  0x2D, 0x73, 0x74, 0x61, 0x74, 0x69, 0x63, 0x00

DS0006:
	.byte  0x2D, 0x66, 0x6E, 0x6F, 0x2D, 0x70, 0x69, 0x63
	.byte  0x00

DS0007:
	.byte  0x2D, 0x6E, 0x6F, 0x73, 0x74, 0x64, 0x6C, 0x69
	.byte  0x62, 0x00

DS0008:
	.byte  0x2D, 0x6C, 0x3A, 0x6C, 0x69, 0x62, 0x63, 0x6D
	.byte  0x74, 0x2E, 0x61, 0x00

DS0009:
	.byte  0x2D, 0x6C, 0x3A, 0x78, 0x38, 0x36, 0x2F, 0x6C
	.byte  0x69, 0x62, 0x63, 0x6D, 0x74, 0x2E, 0x61, 0x00

DS000A:
	.byte  0x2D, 0x6C, 0x6D, 0x00

DS000B:
	.byte  0x2D, 0x57, 0x6C, 0x2C, 0x2D, 0x7A, 0x2C, 0x6E
	.byte  0x6F, 0x65, 0x78, 0x65, 0x63, 0x73, 0x74, 0x61
	.byte  0x63, 0x6B, 0x00

DS000C:
	.byte  0x2D, 0x73, 0x00

DS000D:
	.byte  0x2D, 0x6F, 0x00

DS000E:
	.byte  0x2F, 0x75, 0x73, 0x72, 0x2F, 0x62, 0x69, 0x6E
	.byte  0x2F, 0x67, 0x63, 0x63, 0x00

DS000F:
	.byte  0x20, 0x20, 0x20, 0x20, 0x4C, 0x69, 0x6E, 0x6B
	.byte  0x69, 0x6E, 0x67, 0x3A, 0x00

DS0010:
	.byte  0x20, 0x25, 0x73, 0x00


.att_syntax prefix
