
.intel_syntax noprefix

.global ClearStruct
.global NewDirective

.extern GetQualifiedType
.extern RunLineQueue
.extern AddLineQueueX
.extern AddLineQueue
.extern quad_resize
.extern __cvtq_ld
.extern Tokenize
.extern EvalOperand
.extern DefaultConstructor
.extern SetLocalOffsets
.extern CurrProc
.extern tsprintf
.extern asmerr
.extern Parse_Pass
.extern SymFind
.extern SymLCreate
.extern tstrcat
.extern tstrcpy
.extern tstrlen


.SECTION .text
	.ALIGN	16

$_001:	mov	qword ptr [rsp+0x8], rcx
	mov	qword ptr [rsp+0x10], rdx
	mov	qword ptr [rsp+0x18], r8
	mov	qword ptr [rsp+0x20], r9
	push	rsi
	push	rdi
	push	rbx
	push	rbp
	mov	rbp, rsp
	sub	rsp, 328
	mov	rdx, qword ptr [rbp+0x40]
	lea	rcx, [rbp-0x118]
	call	tstrcpy@PLT
	lea	rdx, [DS0000+rip]
	mov	rcx, rax
	call	tstrcat@PLT
	mov	rdx, qword ptr [rbp+0x40]
	mov	rcx, rax
	call	tstrcat@PLT
	mov	rsi, rax
	mov	rcx, rsi
	call	SymFind@PLT
	mov	qword ptr [rbp-0x10], rax
	cmp	dword ptr [Parse_Pass+rip], 0
	jbe	$_002
	test	rax, rax
	jz	$_002
	cmp	byte ptr [rax+0x1D], 0
	jnz	$_002
	mov	byte ptr [rax+0x1D], 9
$_002:	xor	ecx, ecx
	mov	dword ptr [rbp-0x8], ecx
	test	rax, rax
	jz	$_003
	cmp	byte ptr [rax+0x1D], 9
	jnz	$_003
	mov	ecx, 18
	mov	dword ptr [rbp-0x8], 18
	cmp	byte ptr [r14+0x4], 2
	jnz	$_003
	mov	ecx, 24
	mov	dword ptr [rbp-0x8], 170
	cmp	byte ptr [rax+0x1F], 2
	jz	$_003
	mov	ecx, 18
	mov	dword ptr [rbp-0x8], 164
$_003:	xor	eax, eax
	mov	rbx, qword ptr [rbp+0x38]
	mov	edx, 0
	cmp	byte ptr [rbx-0x20], 58
	jnz	$_006
	mov	rdx, qword ptr [rbp+0x50]
	test	rdx, rdx
	jz	$_004
	cmp	byte ptr [rdx+0x1E], 195
	jnz	$_004
	mov	edx, 2
	jmp	$_005

$_004:	mov	edx, 1
$_005:	jmp	$_007

$_006:	cmp	qword ptr [rbp+0x48], 0
	jz	$_007
	mov	edx, 2
$_007:	mov	dword ptr [rbp-0x14], edx
	cmp	byte ptr [rbx-0x20], 58
	jnz	$_008
	cmp	edx, 2
	jnz	$_009
$_008:	inc	eax
	cmp	qword ptr [rbp+0x48], 0
	jnz	$_009
	inc	eax
$_009:	mov	rdi, qword ptr [rbx+0x58]
	mov	rdx, qword ptr [rbp+0x30]
	mov	rbx, qword ptr [rdx]
	cmp	byte ptr [rbx-0x40], 40
	jz	$_010
	add	eax, 3
	mov	rbx, qword ptr [rbx-0x8]
	mov	byte ptr [rbx], 0
	jmp	$_011

$_010:	xor	ebx, ebx
$_011:	mov	rdx, qword ptr [rbp+0x28]
	test	ecx, ecx
	je	$_024
	mov	dword ptr [rbp-0x18], eax
	jmp	$_014

$_012:	mov	r8, rdx
	mov	edx, dword ptr [rbp-0x8]
	lea	rcx, [DS0001+rip]
	call	AddLineQueueX@PLT
	jmp	$_015

$_013:	mov	r8d, ecx
	mov	edx, ecx
	lea	rcx, [DS0002+rip]
	call	AddLineQueueX@PLT
	jmp	$_015

$_014:	cmp	eax, 0
	jz	$_012
	cmp	eax, 3
	jz	$_012
	cmp	eax, 1
	jz	$_013
	cmp	eax, 2
	jz	$_013
	cmp	eax, 4
	jz	$_013
	cmp	eax, 5
	jz	$_013
$_015:	mov	rdx, qword ptr [rbp+0x28]
	mov	ecx, dword ptr [rbp-0x8]
	mov	eax, dword ptr [rbp-0x18]
	jmp	$_022

$_016:	mov	r8d, ecx
	mov	rdx, rsi
	lea	rcx, [DS0003+rip]
	call	AddLineQueueX@PLT
	jmp	$_023

$_017:	mov	r9d, ecx
	mov	r8, rsi
	lea	rcx, [DS0004+rip]
	call	AddLineQueueX@PLT
	jmp	$_023

$_018:	mov	r8d, ecx
	mov	rdx, rsi
	lea	rcx, [DS0003+rip]
	call	AddLineQueueX@PLT
	jmp	$_023

$_019:	mov	r9, rdi
	mov	r8d, ecx
	mov	rdx, rsi
	lea	rcx, [DS0005+rip]
	call	AddLineQueueX@PLT
	jmp	$_023

$_020:	mov	qword ptr [rsp+0x20], rdi
	mov	r9d, ecx
	mov	r8, rsi
	lea	rcx, [DS0006+rip]
	call	AddLineQueueX@PLT
	jmp	$_023

$_021:	mov	r9, rdi
	mov	r8d, ecx
	mov	rdx, rsi
	lea	rcx, [DS0005+rip]
	call	AddLineQueueX@PLT
	jmp	$_023

$_022:	cmp	eax, 0
	je	$_016
	cmp	eax, 1
	jz	$_017
	cmp	eax, 2
	jz	$_018
	cmp	eax, 3
	jz	$_019
	cmp	eax, 4
	jz	$_020
	cmp	eax, 5
	jz	$_021
$_023:	jmp	$_039

$_024:	jmp	$_038

$_025:	mov	r8, rdx
	mov	rdx, rsi
	lea	rcx, [DS0007+rip]
	call	AddLineQueueX@PLT
	jmp	$_039

$_026:	mov	edi, eax
	cmp	qword ptr [rbp-0x10], 0
	jnz	$_032
	mov	rax, qword ptr [rbp+0x50]
	test	rax, rax
	jz	$_027
	cmp	byte ptr [rax+0x1D], 10
	jnz	$_027
	mov	rcx, qword ptr [rax+0x30]
	call	SymFind@PLT
$_027:	test	rax, rax
	jz	$_032
	cmp	byte ptr [rax+0x1D], 7
	jnz	$_030
	jmp	$_029

$_028:	mov	rax, qword ptr [rax+0x28]
$_029:	cmp	qword ptr [rax+0x28], 0
	jnz	$_028
$_030:	test	byte ptr [rax+0x12], 0x02
	jz	$_032
	xor	edx, edx
	mov	rcx, rax
	call	DefaultConstructor@PLT
	cmp	edi, 1
	jnz	$_031
	mov	r8d, eax
	mov	rdx, qword ptr [rbp+0x28]
	lea	rcx, [DS0008+rip]
	call	AddLineQueueX@PLT
$_031:	jmp	$_039

$_032:	cmp	edi, 1
	jnz	$_033
	mov	r8, rsi
	lea	rcx, [DS0009+rip]
	call	AddLineQueueX@PLT
	jmp	$_034

$_033:	mov	rdx, rsi
	lea	rcx, [DS000A+rip]
	call	AddLineQueueX@PLT
$_034:	jmp	$_039

$_035:	mov	r9, rdi
	mov	r8, rdx
	mov	rdx, rsi
	lea	rcx, [DS000B+rip]
	call	AddLineQueueX@PLT
	jmp	$_039

$_036:	mov	r9, rdi
	mov	r8, rsi
	lea	rcx, [DS000C+rip]
	call	AddLineQueueX@PLT
	jmp	$_039

$_037:	mov	r8, rdi
	mov	rdx, rsi
	lea	rcx, [DS000D+rip]
	call	AddLineQueueX@PLT
	jmp	$_039

$_038:	cmp	eax, 0
	je	$_025
	cmp	eax, 1
	je	$_026
	cmp	eax, 2
	je	$_026
	cmp	eax, 3
	jz	$_035
	cmp	eax, 4
	jz	$_036
	cmp	eax, 5
	jz	$_037
$_039:	test	rbx, rbx
	jz	$_040
	mov	byte ptr [rbx], 41
$_040:	mov	rdx, qword ptr [rbp+0x30]
	mov	rbx, qword ptr [rdx]
	cmp	byte ptr [rbx], 58
	jne	$_052
	add	rbx, 32
	mov	eax, dword ptr [r14+0x5C]
	mov	dword ptr [rbp-0x4], eax
	cmp	dword ptr [rbp-0x8], 0
	jz	$_041
	mov	eax, dword ptr [rbp-0x8]
	mov	dword ptr [rbp-0x4], eax
$_041:	jmp	$_050

$_042:	mov	rdx, qword ptr [rbx+0x10]
	add	rbx, 64
	mov	rdi, qword ptr [rbx+0x18]
	mov	eax, 1
$_043:	cmp	byte ptr [rbx], 0
	jz	$_046
	cmp	byte ptr [rbx], 40
	jnz	$_044
	inc	eax
	jmp	$_045

$_044:	cmp	byte ptr [rbx], 41
	jnz	$_045
	dec	eax
	jz	$_046
$_045:	add	rbx, 32
	jmp	$_043

$_046:	cmp	byte ptr [rbx], 41
	jz	$_047
	mov	rdx, qword ptr [rbx+0x10]
	mov	ecx, 2008
	call	asmerr@PLT
	jmp	$_052

$_047:	mov	rsi, qword ptr [rbx+0x18]
	mov	byte ptr [rsi], 0
	cmp	dword ptr [rbp-0x14], 1
	jnz	$_048
	mov	r9, rdi
	mov	r8, rdx
	mov	rdx, qword ptr [rbp+0x28]
	lea	rcx, [DS000E+rip]
	call	AddLineQueueX@PLT
	jmp	$_049

$_048:	mov	qword ptr [rsp+0x20], rdi
	mov	r9, rdx
	mov	r8, qword ptr [rbp+0x40]
	mov	edx, dword ptr [rbp-0x4]
	lea	rcx, [DS000F+rip]
	call	AddLineQueueX@PLT
$_049:	mov	byte ptr [rsi], 41
	add	rbx, 32
	cmp	byte ptr [rbx], 44
	jnz	$_050
	add	rbx, 32
$_050:	cmp	byte ptr [rbx], 8
	jnz	$_051
	cmp	byte ptr [rbx+0x20], 40
	je	$_042
$_051:	mov	rdx, qword ptr [rbp+0x30]
	mov	qword ptr [rdx], rbx
$_052:	leave
	pop	rbx
	pop	rdi
	pop	rsi
	ret

$_053:
	mov	qword ptr [rsp+0x8], rcx
	mov	qword ptr [rsp+0x18], r8
	push	rsi
	push	rdi
	push	rbx
	push	rbp
	mov	rbp, rsp
	sub	rsp, 184
	mov	ebx, dword ptr [rdx+0x60]
	mov	rdi, qword ptr [rdx+0x8]
	cmp	ebx, 4
	jbe	$_061
	mov	esi, dword ptr [r14+0x64]
	add	esi, 1
	mov	dword ptr [rbp-0x4], esi
	xor	r9d, r9d
	mov	r8, qword ptr [r14+0x1D0]
	mov	edx, esi
	mov	rcx, qword ptr [rbp+0x38]
	call	Tokenize@PLT
	mov	edx, eax
	imul	eax, esi, 32
	add	rax, qword ptr [r14+0x1D0]
	cmp	byte ptr [rax], 10
	jz	$_054
	cmp	byte ptr [rax], 11
	jne	$_061
$_054:	mov	byte ptr [rsp+0x20], 0
	lea	r9, [rbp-0x70]
	mov	r8d, edx
	mov	rdx, qword ptr [r14+0x1D0]
	lea	rcx, [rbp-0x4]
	call	EvalOperand@PLT
	cmp	eax, -1
	je	$_061
	cmp	dword ptr [rbp-0x34], 3
	jnz	$_055
	mov	dword ptr [rbp-0x34], 0
	cmp	ebx, 16
	jz	$_055
	mov	edx, ebx
	lea	rcx, [rbp-0x70]
	call	quad_resize@PLT
$_055:	cmp	dword ptr [rbp-0x34], 0
	jne	$_061
	cmp	ebx, 8
	jnz	$_056
	cmp	dword ptr [rbp-0x6C], 0
	jnz	$_056
	cmp	byte ptr [r14+0x4], 2
	je	$_061
$_056:	jmp	$_060

$_057:	mov	eax, dword ptr [rbp-0x68]
	mov	dword ptr [rsp+0x30], eax
	mov	qword ptr [rsp+0x28], rdi
	mov	rax, qword ptr [rbp+0x28]
	mov	qword ptr [rsp+0x20], rax
	mov	r9d, dword ptr [rbp-0x64]
	mov	r8, rdi
	mov	rdx, qword ptr [rbp+0x28]
	lea	rcx, [DS0010+rip]
	call	AddLineQueueX@PLT
$_058:	cmp	ebx, 10
	jnz	$_059
	mov	r9d, dword ptr [rbp-0x68]
	mov	r8, rdi
	mov	rdx, qword ptr [rbp+0x28]
	lea	rcx, [DS0011+rip]
	call	AddLineQueueX@PLT
$_059:	mov	eax, dword ptr [rbp-0x70]
	mov	dword ptr [rsp+0x30], eax
	mov	qword ptr [rsp+0x28], rdi
	mov	rax, qword ptr [rbp+0x28]
	mov	qword ptr [rsp+0x20], rax
	mov	r9d, dword ptr [rbp-0x6C]
	mov	r8, rdi
	mov	rdx, qword ptr [rbp+0x28]
	lea	rcx, [DS0012+rip]
	call	AddLineQueueX@PLT
	jmp	$_062

	jmp	$_061

$_060:	cmp	ebx, 16
	jz	$_057
	cmp	ebx, 10
	jz	$_058
	cmp	ebx, 8
	jz	$_059
$_061:	mov	r9, qword ptr [rbp+0x38]
	mov	r8, rdi
	mov	rdx, qword ptr [rbp+0x28]
	lea	rcx, [DS000E+rip]
	call	AddLineQueueX@PLT
$_062:	leave
	pop	rbx
	pop	rdi
	pop	rsi
	ret

$_063:
	mov	qword ptr [rsp+0x8], rcx
	push	rsi
	push	rdi
	push	rbx
	push	rbp
	mov	rbp, rsp
	sub	rsp, 328
	mov	dword ptr [rbp-0x104], 0
	mov	rax, r8
	lea	rsi, [rax+0x1]
	test	rdx, rdx
	jz	$_067
	jmp	$_065

$_064:	cmp	rdx, qword ptr [rdx+0x28]
	jz	$_066
	mov	rdx, qword ptr [rdx+0x28]
$_065:	cmp	byte ptr [rdx+0x1D], 7
	jnz	$_066
	cmp	qword ptr [rdx+0x28], 0
	jnz	$_064
$_066:	mov	rcx, qword ptr [rdx+0x78]
	mov	rbx, qword ptr [rcx]
	jmp	$_068

$_067:	inc	dword ptr [rbp-0x104]
$_068:	lodsb
	cmp	al, 32
	jz	$_068
	cmp	al, 9
	jz	$_068
	cmp	al, 125
	je	$_103
	dec	rsi
	test	al, al
	je	$_103
	lea	rdi, [rbp-0x100]
	cmp	byte ptr [rsi], 123
	jnz	$_072
	mov	rdx, qword ptr [rbp+0x28]
	mov	rcx, rdi
	call	tstrcpy@PLT
	mov	rcx, qword ptr [rbx+0x8]
	cmp	byte ptr [rcx], 0
	jz	$_069
	lea	rdx, [DS0013+rip]
	mov	rcx, rdi
	call	tstrcat@PLT
	mov	rdx, qword ptr [rbx+0x8]
	mov	rcx, rdi
	call	tstrcat@PLT
$_069:	mov	r8, rsi
	mov	rdx, qword ptr [rbx+0x28]
	mov	rcx, rdi
	call	$_063
	mov	rsi, rax
	test	eax, eax
	je	$_103
	jmp	$_071

$_070:	add	rsi, 1
$_071:	cmp	byte ptr [rsi], 32
	jz	$_070
	cmp	byte ptr [rsi], 9
	jz	$_070
	jmp	$_100

$_072:	xor	eax, eax
	xor	edx, edx
	mov	byte ptr [rbp-0x10A], al
	mov	byte ptr [rdi], al
	lea	rcx, [rdi+0xFF]
	jmp	$_081

$_073:	mov	al, byte ptr [rsi]
	jmp	$_078

$_074:	jmp	$_082

$_075:	cmp	byte ptr [rbp-0x10A], 0
	jz	$_082
	jmp	$_079

$_076:	inc	byte ptr [rbp-0x10A]
	jmp	$_079

$_077:	dec	byte ptr [rbp-0x10A]
	jmp	$_079

$_078:	cmp	al, 0
	jz	$_074
	cmp	al, 44
	jz	$_075
	cmp	al, 125
	jz	$_075
	cmp	al, 40
	jz	$_076
	cmp	al, 41
	jz	$_077
$_079:	test	byte ptr [r15+rax], 0x44
	jnz	$_080
	inc	edx
$_080:	movsb
$_081:	cmp	rdi, rcx
	jc	$_073
$_082:	xor	eax, eax
	mov	byte ptr [rdi], al
	lea	rcx, [rbp-0x100]
$_083:	cmp	rcx, rdi
	jnc	$_085
	cmp	byte ptr [rdi-0x1], 32
	jz	$_084
	cmp	byte ptr [rdi-0x1], 9
	jnz	$_085
$_084:	dec	edx
	dec	rdi
	mov	byte ptr [rdi], 0
	jmp	$_083

$_085:	test	edx, edx
	jne	$_087
	mov	rdi, rcx
	mov	rcx, rdi
	call	SymFind@PLT
	test	rax, rax
	jz	$_087
	cmp	byte ptr [rax+0x1D], 10
	jnz	$_087
	mov	rcx, qword ptr [rax+0x30]
	cmp	byte ptr [rcx], 123
	jnz	$_086
	cmp	dword ptr [rbp-0x104], 0
	jnz	$_086
	test	byte ptr [rbx+0x10], 0x40
	jz	$_086
	mov	rdx, rax
	xor	eax, eax
	mov	rdi, rsi
	mov	ecx, 4294967295
	repne scasb
	not	ecx
	mov	edi, dword ptr [rdx+0x60]
	lea	rax, [rdi+rcx+0xF]
	and	rax, 0xFFFFFFFFFFFFFFF0
	sub	rsp, rax
	mov	eax, ecx
	lea	rcx, [rdi-0x1]
	mov	rdi, rsp
	mov	rdx, qword ptr [rdx+0x30]
	xchg	rsi, rdx
	rep movsb
	mov	rsi, rdx
	mov	ecx, eax
	rep movsb
	mov	rsi, rsp
	sub	rsp, 48
	jmp	$_068

	jmp	$_087

$_086:	mov	rdx, rsi
	mov	rsi, rcx
	mov	ecx, dword ptr [rax+0x60]
	inc	ecx
	and	ecx, 0xFF
	rep movsb
	mov	rsi, rdx
$_087:	cmp	byte ptr [rbp-0x100], 0
	je	$_100
	cmp	dword ptr [rbp-0x104], 0
	jz	$_088
	mov	eax, dword ptr [rbx+0x60]
	xor	edx, edx
	div	dword ptr [rbx+0x68]
	mov	ecx, dword ptr [rbp-0x104]
	dec	ecx
	mul	ecx
	mov	ecx, eax
$_088:	cmp	byte ptr [rbp-0x100], 34
	jz	$_089
	cmp	byte ptr [rbp-0x100], 76
	jnz	$_092
	cmp	byte ptr [rbp-0xFF], 34
	jnz	$_092
$_089:	cmp	dword ptr [rbp-0x104], 0
	jz	$_090
	lea	r9, [rbp-0x100]
	mov	r8d, ecx
	mov	rdx, qword ptr [rbp+0x28]
	lea	rcx, [DS0014+rip]
	call	AddLineQueueX@PLT
	jmp	$_091

$_090:	lea	r9, [rbp-0x100]
	mov	r8, qword ptr [rbx+0x8]
	mov	rdx, qword ptr [rbp+0x28]
	lea	rcx, [DS0015+rip]
	call	AddLineQueueX@PLT
$_091:	jmp	$_100

$_092:	cmp	dword ptr [rbp-0x104], 0
	je	$_099
	mov	dword ptr [rbp-0x108], ecx
	mov	byte ptr [rbp-0x109], 0
	movsx	eax, byte ptr [rbp-0x100]
	test	byte ptr [rbx+0x1E], 0x20
	jz	$_095
	test	byte ptr [r15+rax], 0x40
	jz	$_095
	lea	rdi, [rbp-0xFF]
	jmp	$_094

$_093:	inc	rdi
$_094:	movzx	eax, byte ptr [rdi]
	test	byte ptr [r15+rax], 0x44
	jnz	$_093
	cmp	byte ptr [rdi], 40
	jnz	$_095
	mov	byte ptr [rdi], 0
	lea	rcx, [rbp-0x100]
	call	SymFind@PLT
	mov	byte ptr [rdi], 40
	test	rax, rax
	jz	$_095
	test	byte ptr [rax+0x10], 0x02
	jz	$_095
	mov	byte ptr [rbp-0x109], 1
$_095:	mov	edx, 779
	cmp	byte ptr [rbp-0x109], 0
	jz	$_098
	cmp	byte ptr [rbx+0x1E], 35
	jnz	$_096
	mov	edx, 1143
	jmp	$_098

$_096:	cmp	byte ptr [rbx+0x1E], 39
	jnz	$_097
	mov	edx, 709
	jmp	$_098

$_097:	cmp	byte ptr [rbx+0x1E], 47
	jnz	$_098
	mov	edx, 1132
$_098:	lea	rax, [rbp-0x100]
	mov	qword ptr [rsp+0x20], rax
	mov	r9d, dword ptr [rbp-0x108]
	mov	r8, qword ptr [rbp+0x28]
	lea	rcx, [DS0016+rip]
	call	AddLineQueueX@PLT
	jmp	$_100

$_099:	lea	r8, [rbp-0x100]
	mov	rdx, rbx
	mov	rcx, qword ptr [rbp+0x28]
	call	$_053
$_100:	cmp	byte ptr [rsi], 0
	jz	$_103
	lodsb
	cmp	al, 44
	jnz	$_103
	cmp	dword ptr [rbp-0x104], 0
	jz	$_101
	inc	dword ptr [rbp-0x104]
	jmp	$_102

$_101:	mov	rbx, qword ptr [rbx+0x80]
$_102:	test	rbx, rbx
	jz	$_103
	jmp	$_068

$_103:
	mov	rax, rsi
	leave
	pop	rbx
	pop	rdi
	pop	rsi
	ret

$_104:
	mov	qword ptr [rsp+0x8], rcx
	mov	qword ptr [rsp+0x10], rdx
	mov	qword ptr [rsp+0x18], r8
	mov	qword ptr [rsp+0x20], r9
	push	rsi
	push	rdi
	push	rbx
	push	rbp
	mov	rbp, rsp
	sub	rsp, 312
	cmp	qword ptr [rbp+0x38], 0
	jnz	$_105
	mov	rsi, qword ptr [rbp+0x30]
	lea	rdi, [rbp-0x118]
	mov	ecx, 144
	rep movsb
	mov	qword ptr [rbp-0x98], 0
	lea	rbx, [rbp-0x118]
	mov	r8, qword ptr [rbp+0x40]
	xor	edx, edx
	mov	rcx, qword ptr [rbp+0x28]
	call	$_063
	jmp	$_112

$_105:	mov	rdi, qword ptr [rbp+0x30]
	test	byte ptr [rdi+0x10], 0x40
	jnz	$_106
	mov	r8, qword ptr [rbp+0x40]
	mov	rdx, qword ptr [rbp+0x38]
	mov	rcx, qword ptr [rbp+0x28]
	call	$_063
	jmp	$_112

$_106:	mov	rsi, qword ptr [rbp+0x40]
	inc	rsi
	jmp	$_108

$_107:	add	rsi, 1
$_108:	cmp	byte ptr [rsi], 32
	jz	$_107
	cmp	byte ptr [rsi], 9
	jz	$_107
	mov	eax, dword ptr [rdi+0x60]
	mov	ebx, dword ptr [rdi+0x68]
	xor	edx, edx
	div	ebx
	mov	dword ptr [rbp-0x84], eax
	xor	edi, edi
$_109:	test	ebx, ebx
	jz	$_111
	mov	r9d, edi
	mov	r8, qword ptr [rbp+0x28]
	lea	rdx, [DS0017+rip]
	lea	rcx, [rbp-0x80]
	call	tsprintf@PLT
	mov	r8, rsi
	mov	rdx, qword ptr [rbp+0x38]
	lea	rcx, [rbp-0x80]
	call	$_063
	mov	rsi, rax
	lodsb
	test	al, al
	jz	$_111
$_110:	lodsb
	cmp	al, 32
	jz	$_110
	cmp	al, 9
	jz	$_110
	dec	rsi
	cmp	al, 123
	jnz	$_111
	dec	ebx
	add	edi, dword ptr [rbp-0x84]
	jmp	$_109

$_111:	mov	rax, rsi
$_112:	leave
	pop	rbx
	pop	rdi
	pop	rsi
	ret

ClearStruct:
	push	rsi
	push	rdi
	push	rbx
	push	rbp
	mov	rbp, rsp
	sub	rsp, 88
	mov	rsi, rcx
	mov	edi, dword ptr [rdx+0x60]
	mov	eax, dword ptr [r14+0x5C]
	cmp	eax, 163
	jnz	$_113
	mov	eax, 17
$_113:	mov	r8d, eax
	mov	edx, eax
	lea	rcx, [DS0002+rip]
	call	AddLineQueueX@PLT
	mov	eax, 16
	cmp	byte ptr [r14+0x4], 2
	jnz	$_114
	mov	eax, 32
$_114:	cmp	edi, eax
	jbe	$_117
	cmp	byte ptr [r14+0x4], 0
	jz	$_117
	mov	ecx, 10
	mov	edx, 16
	mov	ebx, ecx
	cmp	byte ptr [r14+0x4], 1
	jnz	$_115
	mov	ecx, 18
	mov	edx, 24
	mov	ebx, 18
	jmp	$_116

$_115:	cmp	byte ptr [r14+0x4], 2
	jnz	$_116
	mov	ecx, 164
	mov	edx, 170
	mov	ebx, 18
$_116:	mov	dword ptr [rsp+0x40], edx
	mov	dword ptr [rsp+0x38], ecx
	mov	dword ptr [rsp+0x30], edi
	mov	dword ptr [rsp+0x28], ebx
	mov	qword ptr [rsp+0x20], rsi
	mov	r9d, edx
	mov	r8d, ecx
	lea	rcx, [DS0018+rip]
	call	AddLineQueueX@PLT
	jmp	$_123

$_117:	mov	dword ptr [rbp-0x8], 2
	mov	dword ptr [rbp-0x4], 271
	cmp	byte ptr [r14+0x4], 1
	jnz	$_118
	mov	dword ptr [rbp-0x8], 4
	mov	dword ptr [rbp-0x4], 274
	jmp	$_119

$_118:	cmp	byte ptr [r14+0x4], 2
	jnz	$_119
	mov	dword ptr [rbp-0x8], 8
	mov	dword ptr [rbp-0x4], 278
$_119:	xor	ebx, ebx
$_120:	cmp	edi, dword ptr [rbp-0x8]
	jl	$_121
	mov	eax, dword ptr [r14+0x5C]
	mov	dword ptr [rsp+0x20], eax
	mov	r9d, ebx
	mov	r8, rsi
	mov	edx, dword ptr [rbp-0x4]
	lea	rcx, [DS0019+rip]
	call	AddLineQueueX@PLT
	sub	edi, dword ptr [rbp-0x8]
	add	ebx, dword ptr [rbp-0x8]
	jmp	$_120

$_121:	cmp	edi, 4
	jc	$_122
	mov	r8d, ebx
	mov	rdx, rsi
	lea	rcx, [DS001A+rip]
	call	AddLineQueueX@PLT
	add	ebx, 4
	sub	edi, 4
$_122:	test	edi, edi
	jz	$_123
	mov	r8d, ebx
	mov	rdx, rsi
	lea	rcx, [DS001B+rip]
	call	AddLineQueueX@PLT
	dec	edi
	inc	ebx
	jmp	$_122

$_123:
	leave
	pop	rbx
	pop	rdi
	pop	rsi
	ret

$_124:
	mov	qword ptr [rsp+0x8], rcx
	mov	qword ptr [rsp+0x10], rdx
	mov	qword ptr [rsp+0x18], r8
	push	rsi
	push	rdi
	push	rbx
	push	rbp
	mov	rbp, rsp
	sub	rsp, 968
	inc	dword ptr [rbp+0x30]
	imul	ebx, dword ptr [rbp+0x30], 32
	add	rbx, qword ptr [rbp+0x38]
	mov	rsi, r9
	mov	byte ptr [rbp-0x300], 0
	mov	byte ptr [rbp-0x36A], 0
	cmp	byte ptr [rbx], 9
	jne	$_133
	cmp	byte ptr [rbx+0x1], 123
	jne	$_133
	mov	rcx, qword ptr [rbp+0x28]
	call	SymFind@PLT
	test	rax, rax
	jnz	$_125
	mov	rdx, qword ptr [rbx+0x18]
	mov	ecx, 2008
	call	asmerr@PLT
	jmp	$_165

$_125:	xor	edx, edx
	mov	rcx, qword ptr [rbx+0x10]
	jmp	$_127

$_126:	inc	rcx
$_127:	cmp	byte ptr [rcx], 32
	jz	$_126
	cmp	byte ptr [rcx], 9
	jz	$_126
	cmp	byte ptr [rcx], 48
	jnz	$_130
	inc	rcx
	jmp	$_129

$_128:	inc	rcx
$_129:	cmp	byte ptr [rcx], 32
	jz	$_128
	cmp	byte ptr [rcx], 9
	jz	$_128
	cmp	byte ptr [rcx], 0
	jnz	$_130
	inc	rdx
$_130:	test	edx, edx
	jz	$_131
	mov	rdx, rax
	mov	rcx, qword ptr [rbp+0x28]
	call	ClearStruct
	jmp	$_132

$_131:	mov	r9, qword ptr [rbx+0x18]
	mov	r8, qword ptr [rax+0x28]
	mov	rdx, rax
	mov	rcx, qword ptr [rbp+0x28]
	call	$_104
$_132:	lea	rax, [rbx+0x20]
	jmp	$_165

$_133:	lea	rdi, [rbp-0x200]
	mov	eax, 779
	cmp	byte ptr [rbx], 11
	jz	$_136
	cmp	byte ptr [rbx], 45
	jz	$_136
	cmp	byte ptr [rsi+0x10], 35
	jnz	$_134
	mov	eax, 1143
	jmp	$_136

$_134:	cmp	byte ptr [rsi+0x10], 39
	jnz	$_135
	mov	eax, 709
	jmp	$_136

$_135:	cmp	byte ptr [rsi+0x10], 47
	jnz	$_136
	mov	eax, 1132
$_136:	mov	r8d, eax
	lea	rdx, [DS001C+rip]
	mov	rcx, rdi
	call	tsprintf@PLT
	mov	eax, dword ptr [rsi]
	mov	rdx, qword ptr [rbx+0x10]
	cmp	byte ptr [rsi+0x11], 0
	jz	$_137
	cmp	byte ptr [rbx], 8
	jnz	$_137
	cmp	word ptr [rdx], 76
	jnz	$_137
	cmp	byte ptr [rbx+0x20], 9
	jnz	$_137
	cmp	byte ptr [rbx+0x21], 34
	jnz	$_137
	add	rbx, 32
	inc	byte ptr [rbp-0x36A]
	jmp	$_152

$_137:	cmp	eax, 8
	jc	$_152
	cmp	eax, 8
	jnz	$_139
	cmp	byte ptr [rsi+0x13], 1
	jnz	$_139
	test	byte ptr [rbx+0x2], 0x08
	jz	$_139
	cmp	byte ptr [rsi+0x10], 7
	jz	$_138
	cmp	byte ptr [rsi+0x10], 71
	jnz	$_139
$_138:	jmp	$_152

$_139:	cmp	eax, 16
	jnz	$_141
	cmp	byte ptr [rsi+0x13], 2
	jnz	$_141
	test	byte ptr [rbx+0x2], 0x08
	jz	$_141
	cmp	byte ptr [rsi+0x10], 15
	jz	$_140
	cmp	byte ptr [rsi+0x10], 79
	jnz	$_141
$_140:	jmp	$_152

$_141:	cmp	eax, 8
	jnz	$_143
	cmp	byte ptr [rsi+0x13], 2
	jnz	$_143
	test	byte ptr [rbx+0x2], 0x08
	jnz	$_142
	cmp	word ptr [rdx], 38
	jnz	$_143
$_142:	jmp	$_152

$_143:	cmp	dword ptr [r14+0x58], 0
	jz	$_144
	jmp	$_152

$_144:	mov	byte ptr [rsp+0x20], 0
	lea	r9, [rbp-0x368]
	mov	r8d, dword ptr [r14+0x64]
	mov	rdx, qword ptr [rbp+0x38]
	lea	rcx, [rbp+0x30]
	call	EvalOperand@PLT
	cmp	eax, -1
	je	$_152
	mov	eax, dword ptr [rsi]
	cmp	eax, 8
	jnz	$_147
	cmp	dword ptr [rbp-0x32C], 0
	jnz	$_147
	cmp	byte ptr [rsi+0x13], 1
	jz	$_145
	cmp	byte ptr [rbx], 9
	jz	$_146
	cmp	dword ptr [rbp-0x364], 0
	jg	$_145
	cmp	dword ptr [rbp-0x364], -1
	jge	$_146
$_145:	mov	eax, dword ptr [rbp-0x364]
	mov	dword ptr [rsp+0x20], eax
	mov	r9, qword ptr [rbp+0x28]
	mov	r8d, dword ptr [rbp-0x368]
	mov	rdx, qword ptr [rbp+0x28]
	lea	rcx, [DS001D+rip]
	call	AddLineQueueX@PLT
	imul	eax, dword ptr [rbp+0x30], 32
	add	rax, qword ptr [rbp+0x38]
	jmp	$_165

$_146:	jmp	$_152

$_147:	cmp	dword ptr [rbp-0x32C], 3
	jne	$_152
	cmp	eax, 8
	jz	$_148
	cmp	eax, 10
	jz	$_148
	cmp	eax, 16
	jne	$_152
$_148:	cmp	eax, 8
	jnz	$_149
	mov	rax, qword ptr [rbx+0x18]
	mov	qword ptr [rsp+0x20], rax
	mov	r9, qword ptr [rbp+0x28]
	mov	r8, qword ptr [rbx+0x18]
	mov	rdx, qword ptr [rbp+0x28]
	lea	rcx, [DS001E+rip]
	call	AddLineQueueX@PLT
	jmp	$_151

$_149:	cmp	eax, 10
	jnz	$_150
	lea	rdx, [rbp-0x368]
	lea	rcx, [rbp-0x368]
	call	__cvtq_ld@PLT
	mov	eax, dword ptr [rbp-0x360]
	mov	dword ptr [rsp+0x30], eax
	mov	rax, qword ptr [rbp+0x28]
	mov	qword ptr [rsp+0x28], rax
	mov	eax, dword ptr [rbp-0x364]
	mov	dword ptr [rsp+0x20], eax
	mov	r9, qword ptr [rbp+0x28]
	mov	r8d, dword ptr [rbp-0x368]
	mov	rdx, qword ptr [rbp+0x28]
	lea	rcx, [DS001F+rip]
	call	AddLineQueueX@PLT
	jmp	$_151

$_150:	mov	eax, dword ptr [rbp-0x35C]
	mov	dword ptr [rsp+0x40], eax
	mov	rax, qword ptr [rbp+0x28]
	mov	qword ptr [rsp+0x38], rax
	mov	eax, dword ptr [rbp-0x360]
	mov	dword ptr [rsp+0x30], eax
	mov	rax, qword ptr [rbp+0x28]
	mov	qword ptr [rsp+0x28], rax
	mov	eax, dword ptr [rbp-0x364]
	mov	dword ptr [rsp+0x20], eax
	mov	r9, qword ptr [rbp+0x28]
	mov	r8d, dword ptr [rbp-0x368]
	mov	rdx, qword ptr [rbp+0x28]
	lea	rcx, [DS0020+rip]
	call	AddLineQueueX@PLT
$_151:	imul	eax, dword ptr [rbp+0x30], 32
	add	rax, qword ptr [rbp+0x38]
	jmp	$_165

$_152:	mov	rdx, qword ptr [rbp+0x28]
	mov	rcx, rdi
	call	tstrcat@PLT
	lea	rdx, [DS0021+rip]
	mov	rcx, rax
	call	tstrcat@PLT
	mov	rcx, rax
	call	tstrlen@PLT
	add	rdi, rax
	mov	byte ptr [rbp-0x369], 0
$_153:	movzx	eax, byte ptr [rbx]
	jmp	$_158

$_154:	jmp	$_162

$_155:	cmp	byte ptr [rbp-0x369], 0
	je	$_162
	jmp	$_159

$_156:	inc	byte ptr [rbp-0x369]
	jmp	$_159

$_157:	dec	byte ptr [rbp-0x369]
	jmp	$_159

$_158:	cmp	eax, 0
	jz	$_154
	cmp	eax, 44
	jz	$_155
	cmp	eax, 40
	jz	$_156
	cmp	eax, 41
	jz	$_157
$_159:	cmp	byte ptr [rbp-0x369], 0
	jnz	$_161
	cmp	byte ptr [rbx], 9
	jnz	$_161
	cmp	byte ptr [rbx+0x1], 34
	jnz	$_161
	mov	rcx, qword ptr [rbp+0x28]
	call	SymFind@PLT
	test	rax, rax
	jz	$_161
	test	byte ptr [rax+0x1E], 0xC3
	jz	$_161
	lea	rsi, [DS0022+rip]
	mov	ecx, 7
	rep movsb
	cmp	byte ptr [rbp-0x36A], 0
	jz	$_160
	mov	al, 76
	stosb
$_160:	mov	rsi, qword ptr [rbx+0x10]
	mov	ecx, dword ptr [rbx+0x4]
	add	ecx, 2
	rep movsb
	mov	eax, 41
	stosw
	add	rbx, 32
	jmp	$_162

$_161:	mov	rsi, qword ptr [rbx+0x18]
	mov	rcx, qword ptr [rbx+0x38]
	sub	rcx, rsi
	rep movsb
	mov	byte ptr [rdi], 0
	add	rbx, 32
	jmp	$_153

$_162:	cmp	byte ptr [rbp-0x369], 0
	jz	$_163
	mov	ecx, 2157
	call	asmerr@PLT
$_163:	lea	rcx, [rbp-0x200]
	call	AddLineQueue@PLT
	cmp	byte ptr [rbp-0x300], 0
	jz	$_164
	lea	rcx, [rbp-0x300]
	call	AddLineQueue@PLT
$_164:	mov	rax, rbx
$_165:	leave
	pop	rbx
	pop	rdi
	pop	rsi
	ret

$_166:
	mov	qword ptr [rsp+0x8], rcx
	mov	qword ptr [rsp+0x10], rdx
	push	rsi
	push	rdi
	push	rbx
	push	rbp
	mov	rbp, rsp
	sub	rsp, 248
	inc	dword ptr [rbp+0x28]
	imul	ebx, dword ptr [rbp+0x28], 32
	add	rbx, qword ptr [rbp+0x30]
	mov	dword ptr [rbp-0x14], 0
$_167:	cmp	byte ptr [rbx], 8
	jz	$_168
	mov	rdx, qword ptr [rbx+0x10]
	mov	ecx, 2008
	call	asmerr@PLT
	jmp	$_212

$_168:	mov	rax, qword ptr [rbx+0x10]
	mov	qword ptr [rbp-0x8], rax
	mov	qword ptr [rbp-0x10], 0
	mov	qword ptr [rbp-0x38], 0
	mov	byte ptr [rbp-0x2F], 0
	mov	byte ptr [rbp-0x2C], 192
	mov	cl, byte ptr [r14+0x15]
	mov	eax, 1
	shl	eax, cl
	test	eax, 0x68
	jz	$_169
	mov	byte ptr [rbp-0x2E], 1
	jmp	$_170

$_169:	mov	byte ptr [rbp-0x2E], 0
$_170:	mov	al, byte ptr [r14+0x4]
	mov	byte ptr [rbp-0x2D], al
	mov	dword ptr [rbp-0x24], 0
	mov	rcx, qword ptr [rbp-0x8]
	call	SymFind@PLT
	test	rax, rax
	jnz	$_171
	mov	rcx, qword ptr [rbp-0x8]
	call	SymLCreate@PLT
	mov	dword ptr [rbp-0x24], 1
$_171:	test	rax, rax
	jnz	$_172
	mov	rax, -1
	jmp	$_212

$_172:	mov	qword ptr [rbp-0x20], rax
	cmp	dword ptr [rbp-0x24], 0
	jz	$_173
	mov	byte ptr [rax+0x1D], 5
	or	byte ptr [rax+0x10], 0x01
	mov	dword ptr [rax+0x68], 1
	jmp	$_174

$_173:	cmp	byte ptr [rax+0x1D], 5
	jz	$_174
	test	byte ptr [rax+0x13], 0x02
	jnz	$_174
	mov	rdx, qword ptr [rax+0x8]
	mov	ecx, 2005
	call	asmerr@PLT
	jmp	$_212

$_174:	cmp	byte ptr [rbp-0x2D], 0
	jnz	$_176
	cmp	dword ptr [rbp-0x24], 0
	jz	$_175
	mov	byte ptr [rax+0x1E], 1
$_175:	mov	dword ptr [rbp-0x40], 2
	jmp	$_178

$_176:	cmp	dword ptr [rbp-0x24], 0
	jz	$_177
	mov	byte ptr [rax+0x1E], 3
$_177:	mov	dword ptr [rbp-0x40], 4
$_178:	add	rbx, 32
	cmp	byte ptr [rbx], 91
	jne	$_183
	add	rbx, 32
	mov	rdi, rbx
	sub	rdi, qword ptr [rbp+0x30]
	mov	eax, edi
	mov	ecx, 32
	xor	edx, edx
	div	ecx
	mov	edi, eax
	mov	dword ptr [rbp+0x28], edi
	mov	rsi, rbx
$_179:	cmp	edi, dword ptr [r14+0x64]
	jge	$_180
	cmp	byte ptr [rbx], 44
	jz	$_180
	cmp	byte ptr [rbx], 58
	jz	$_180
	inc	edi
	add	rbx, 32
	jmp	$_179

$_180:	mov	byte ptr [rsp+0x20], 0
	lea	r9, [rbp-0xC0]
	mov	r8d, edi
	mov	rdx, qword ptr [rbp+0x30]
	lea	rcx, [rbp+0x28]
	call	EvalOperand@PLT
	cmp	eax, -1
	je	$_212
	cmp	dword ptr [rbp-0x84], 0
	jz	$_181
	mov	ecx, 2026
	call	asmerr@PLT
	mov	dword ptr [rbp-0xC0], 1
$_181:	imul	ebx, dword ptr [rbp+0x28], 32
	add	rbx, qword ptr [rbp+0x30]
	mov	rcx, qword ptr [rbp-0x20]
	mov	eax, dword ptr [rbp-0xC0]
	mov	dword ptr [rcx+0x68], eax
	or	byte ptr [rcx+0x10], 0x40
	cmp	byte ptr [rbx], 93
	jnz	$_182
	add	rbx, 32
	jmp	$_183

$_182:	mov	ecx, 2045
	call	asmerr@PLT
$_183:	mov	rsi, qword ptr [rbp-0x20]
	cmp	byte ptr [rbx], 58
	jne	$_187
	mov	rax, qword ptr [rbx+0x30]
	mov	qword ptr [rbp-0x10], rax
	sub	rbx, qword ptr [rbp+0x30]
	mov	ecx, 32
	mov	eax, ebx
	xor	edx, edx
	div	ecx
	mov	ebx, eax
	inc	ebx
	mov	dword ptr [rbp+0x28], ebx
	lea	r8, [rbp-0x40]
	mov	rdx, qword ptr [rbp+0x30]
	lea	rcx, [rbp+0x28]
	call	GetQualifiedType@PLT
	cmp	eax, -1
	je	$_212
	imul	ebx, dword ptr [rbp+0x28], 32
	add	rbx, qword ptr [rbp+0x30]
	cmp	dword ptr [rbp-0x24], 0
	jz	$_184
	mov	rax, qword ptr [rbp-0x40]
	mov	qword ptr [rbp-0x58], rax
	mov	rax, qword ptr [rbp-0x38]
	mov	qword ptr [rbp-0x50], rax
	mov	rax, qword ptr [rbp-0x30]
	mov	qword ptr [rbp-0x48], rax
	mov	dword ptr [rbp-0x14], 1
$_184:	mov	al, byte ptr [rbp-0x30]
	mov	byte ptr [rsi+0x1E], al
	cmp	byte ptr [rbp-0x30], 196
	jnz	$_185
	mov	rax, qword ptr [rbp-0x38]
	mov	qword ptr [rsi+0x28], rax
	jmp	$_186

$_185:	mov	rax, qword ptr [rbp-0x38]
	mov	qword ptr [rsi+0x50], rax
$_186:	jmp	$_189

$_187:	cmp	dword ptr [rbp-0x14], 0
	jz	$_189
	cmp	dword ptr [rbp-0x24], 0
	jz	$_189
	mov	rax, qword ptr [rbp-0x58]
	mov	qword ptr [rbp-0x40], rax
	mov	rax, qword ptr [rbp-0x50]
	mov	qword ptr [rbp-0x38], rax
	mov	rax, qword ptr [rbp-0x48]
	mov	qword ptr [rbp-0x30], rax
	mov	al, byte ptr [rbp-0x30]
	mov	byte ptr [rsi+0x1E], al
	cmp	byte ptr [rbp-0x30], 196
	jnz	$_188
	mov	rax, qword ptr [rbp-0x38]
	mov	qword ptr [rsi+0x28], rax
	jmp	$_189

$_188:	mov	rax, qword ptr [rbp-0x38]
	mov	qword ptr [rsi+0x50], rax
$_189:	cmp	dword ptr [rbp-0x24], 0
	jz	$_190
	mov	al, byte ptr [rbp-0x2F]
	mov	byte ptr [rsi+0x49], al
	mov	al, byte ptr [rbp-0x2E]
	mov	byte ptr [rsi+0x21], al
	mov	al, byte ptr [rbp-0x2D]
	mov	byte ptr [rsi+0x48], al
	mov	al, byte ptr [rbp-0x2C]
	mov	byte ptr [rsi+0x4A], al
	mov	eax, dword ptr [rbp-0x40]
	mul	dword ptr [rsi+0x68]
	mov	dword ptr [rsi+0x60], eax
$_190:	cmp	dword ptr [rbp-0x24], 0
	jz	$_194
	cmp	dword ptr [Parse_Pass+rip], 0
	jnz	$_194
	mov	rax, qword ptr [CurrProc+rip]
	mov	rdx, qword ptr [rax+0x78]
	cmp	qword ptr [rdx+0x20], 0
	jnz	$_191
	mov	qword ptr [rdx+0x20], rsi
	jmp	$_194

$_191:	mov	rcx, qword ptr [rdx+0x20]
$_192:	cmp	qword ptr [rcx+0x88], 0
	jz	$_193
	mov	rcx, qword ptr [rcx+0x88]
	jmp	$_192

$_193:	mov	qword ptr [rcx+0x88], rsi
$_194:	cmp	byte ptr [rbx], 0
	je	$_209
	cmp	byte ptr [rbx], 44
	jnz	$_196
	mov	rax, rbx
	sub	rax, qword ptr [rbp+0x30]
	xor	edx, edx
	mov	ecx, 32
	div	ecx
	inc	eax
	cmp	eax, dword ptr [r14+0x64]
	jge	$_195
	add	rbx, 32
$_195:	jmp	$_209

$_196:	cmp	byte ptr [rbx], 40
	jne	$_207
	lea	rdi, [rbx-0x20]
	mov	rsi, qword ptr [rbx-0x10]
	add	rbx, 32
	mov	eax, 1
$_197:	cmp	byte ptr [rbx], 0
	jz	$_200
	cmp	byte ptr [rbx], 40
	jnz	$_198
	inc	eax
	jmp	$_199

$_198:	cmp	byte ptr [rbx], 41
	jnz	$_199
	dec	eax
	jz	$_200
$_199:	add	rbx, 32
	jmp	$_197

$_200:	cmp	byte ptr [rbx], 41
	jz	$_201
	mov	ecx, 2045
	call	asmerr@PLT
	jmp	$_212

$_201:	add	rbx, 32
	mov	qword ptr [rbp-0xC8], rbx
	mov	rcx, rsi
	call	SymFind@PLT
	test	rax, rax
	jz	$_206
	mov	rcx, rax
	cmp	byte ptr [rcx+0x1D], 7
	jnz	$_205
	jmp	$_203

$_202:	mov	rcx, qword ptr [rcx+0x28]
$_203:	cmp	qword ptr [rcx+0x28], 0
	jnz	$_202
	cmp	qword ptr [rcx+0x50], 0
	jz	$_205
	cmp	byte ptr [rcx+0x1E], 195
	jz	$_204
	cmp	byte ptr [rcx+0x4A], 196
	jnz	$_205
$_204:	mov	rcx, qword ptr [rcx+0x50]
$_205:	mov	rsi, qword ptr [rcx+0x8]
$_206:	mov	qword ptr [rsp+0x28], rax
	mov	rax, qword ptr [rbp-0x10]
	mov	qword ptr [rsp+0x20], rax
	mov	r9, rsi
	mov	r8, rdi
	lea	rdx, [rbp-0xC8]
	mov	rcx, qword ptr [rbp-0x8]
	call	$_001
	mov	rbx, qword ptr [rbp-0xC8]
	jmp	$_209

$_207:	cmp	byte ptr [rbx], 3
	jnz	$_208
	cmp	byte ptr [rbx+0x1], 48
	jnz	$_208
	lea	r9, [rbp-0x40]
	mov	r8, qword ptr [rbp+0x30]
	mov	edx, dword ptr [rbp+0x28]
	mov	rcx, qword ptr [rbp-0x8]
	call	$_124
	mov	rbx, rax
	jmp	$_209

$_208:	lea	rdx, [DS0023+rip]
	mov	ecx, 2065
	call	asmerr@PLT
	jmp	$_212

$_209:	mov	rax, rbx
	sub	rax, qword ptr [rbp+0x30]
	xor	edx, edx
	mov	ecx, 32
	div	ecx
	cmp	eax, dword ptr [r14+0x64]
	jge	$_210
	jmp	$_167

$_210:	cmp	dword ptr [rbp-0x24], 0
	jz	$_211
	cmp	dword ptr [Parse_Pass+rip], 0
	jnz	$_211
	mov	rax, qword ptr [CurrProc+rip]
	mov	rcx, qword ptr [rax+0x78]
	mov	dword ptr [rcx+0x4], 0
	call	SetLocalOffsets@PLT
$_211:	xor	eax, eax
$_212:	leave
	pop	rbx
	pop	rdi
	pop	rsi
	ret

NewDirective:
	push	rsi
	push	rdi
	push	rbx
	push	rbp
	mov	rbp, rsp
	sub	rsp, 40
	mov	dword ptr [rbp-0x4], -1
	cmp	qword ptr [CurrProc+rip], 0
	je	$_222
	mov	rbx, rdx
	imul	eax, ecx, 32
	cmp	byte ptr [rbx+rax+0x20], 40
	jnz	$_220
	lea	rbx, [rbx+rax+0x40]
	mov	rcx, qword ptr [rbx+0x10]
	call	SymFind@PLT
	test	rax, rax
	jz	$_213
	cmp	byte ptr [rax+0x1D], 10
	jnz	$_213
	mov	rcx, qword ptr [rax+0x30]
	call	SymFind@PLT
$_213:	test	rax, rax
	jz	$_218
	cmp	byte ptr [rax+0x1D], 7
	jnz	$_216
	jmp	$_215

$_214:	mov	rax, qword ptr [rax+0x28]
$_215:	cmp	qword ptr [rax+0x28], 0
	jnz	$_214
$_216:	test	byte ptr [rax+0x12], 0x02
	jz	$_218
	mov	rsi, rax
	xor	edi, edi
	cmp	byte ptr [rbx+0x20], 44
	jnz	$_217
	cmp	byte ptr [rbx+0x40], 41
	jz	$_217
	lea	rdi, [rbx+0x40]
$_217:	mov	rdx, rdi
	mov	rcx, rsi
	call	DefaultConstructor@PLT
	mov	dword ptr [rbp-0x4], 0
$_218:	cmp	dword ptr [rbp-0x4], -1
	jnz	$_219
	mov	rdx, qword ptr [rbx+0x10]
	mov	ecx, 2008
	call	asmerr@PLT
$_219:	jmp	$_221

$_220:	mov	rdx, rbx
	call	$_166
	mov	dword ptr [rbp-0x4], eax
$_221:	jmp	$_223

$_222:	mov	ecx, 2012
	call	asmerr@PLT
$_223:	cmp	qword ptr [r14+0x2B0], 0
	jz	$_224
	call	RunLineQueue@PLT
$_224:	mov	eax, dword ptr [rbp-0x4]
	leave
	pop	rbx
	pop	rdi
	pop	rsi
	ret


.SECTION .data
	.ALIGN	16

DS0000:
	.byte  0x5F, 0x00

DS0001:
	.byte  0x20, 0x6C, 0x65, 0x61, 0x20, 0x25, 0x72, 0x2C
	.byte  0x20, 0x25, 0x73, 0x00

DS0002:
	.byte  0x20, 0x78, 0x6F, 0x72, 0x20, 0x25, 0x72, 0x2C
	.byte  0x20, 0x25, 0x72, 0x00

DS0003:
	.byte  0x20, 0x25, 0x73, 0x28, 0x25, 0x72, 0x29, 0x00

DS0004:
	.byte  0x20, 0x6D, 0x6F, 0x76, 0x20, 0x25, 0x73, 0x2C
	.byte  0x25, 0x73, 0x28, 0x25, 0x72, 0x29, 0x00

DS0005:
	.byte  0x20, 0x25, 0x73, 0x28, 0x25, 0x72, 0x2C, 0x25
	.byte  0x73, 0x29, 0x00

DS0006:
	.byte  0x20, 0x6D, 0x6F, 0x76, 0x20, 0x25, 0x73, 0x2C
	.byte  0x25, 0x73, 0x28, 0x25, 0x72, 0x2C, 0x25, 0x73
	.byte  0x29, 0x00

DS0007:
	.byte  0x20, 0x25, 0x73, 0x28, 0x26, 0x25, 0x73, 0x29
	.byte  0x00

DS0008:
	.byte  0x20, 0x6D, 0x6F, 0x76, 0x20, 0x25, 0x73, 0x2C
	.byte  0x25, 0x72, 0x00

DS0009:
	.byte  0x20, 0x6D, 0x6F, 0x76, 0x20, 0x25, 0x73, 0x2C
	.byte  0x25, 0x73, 0x28, 0x30, 0x29, 0x00

DS000A:
	.byte  0x20, 0x25, 0x73, 0x28, 0x30, 0x29, 0x00

DS000B:
	.byte  0x20, 0x25, 0x73, 0x28, 0x26, 0x25, 0x73, 0x2C
	.byte  0x25, 0x73, 0x29, 0x00

DS000C:
	.byte  0x20, 0x6D, 0x6F, 0x76, 0x20, 0x25, 0x73, 0x2C
	.byte  0x25, 0x73, 0x28, 0x30, 0x2C, 0x25, 0x73, 0x29
	.byte  0x00

DS000D:
	.byte  0x20, 0x25, 0x73, 0x28, 0x30, 0x2C, 0x25, 0x73
	.byte  0x29, 0x00

DS000E:
	.byte  0x20, 0x6D, 0x6F, 0x76, 0x20, 0x25, 0x73, 0x2E
	.byte  0x25, 0x73, 0x2C, 0x20, 0x25, 0x73, 0x00

DS000F:
	.byte  0x20, 0x6D, 0x6F, 0x76, 0x20, 0x5B, 0x25, 0x72
	.byte  0x5D, 0x2E, 0x25, 0x73, 0x2E, 0x25, 0x73, 0x2C
	.byte  0x20, 0x25, 0x73, 0x00

DS0010:
	.byte  0x20, 0x6D, 0x6F, 0x76, 0x20, 0x64, 0x77, 0x6F
	.byte  0x72, 0x64, 0x20, 0x70, 0x74, 0x72, 0x20, 0x25
	.byte  0x73, 0x2E, 0x25, 0x73, 0x5B, 0x31, 0x32, 0x5D
	.byte  0x2C, 0x20, 0x30, 0x78, 0x25, 0x78, 0x0A, 0x20
	.byte  0x6D, 0x6F, 0x76, 0x20, 0x64, 0x77, 0x6F, 0x72
	.byte  0x64, 0x20, 0x70, 0x74, 0x72, 0x20, 0x25, 0x73
	.byte  0x2E, 0x25, 0x73, 0x5B, 0x38, 0x5D, 0x2C, 0x20
	.byte  0x30, 0x78, 0x25, 0x78, 0x00

DS0011:
	.byte  0x20, 0x6D, 0x6F, 0x76, 0x20, 0x77, 0x6F, 0x72
	.byte  0x64, 0x20, 0x70, 0x74, 0x72, 0x20, 0x25, 0x73
	.byte  0x2E, 0x25, 0x73, 0x5B, 0x38, 0x5D, 0x2C, 0x20
	.byte  0x30, 0x78, 0x25, 0x78, 0x00

DS0012:
	.byte  0x20, 0x6D, 0x6F, 0x76, 0x20, 0x64, 0x77, 0x6F
	.byte  0x72, 0x64, 0x20, 0x70, 0x74, 0x72, 0x20, 0x25
	.byte  0x73, 0x2E, 0x25, 0x73, 0x5B, 0x34, 0x5D, 0x2C
	.byte  0x20, 0x30, 0x78, 0x25, 0x78, 0x0A, 0x20, 0x6D
	.byte  0x6F, 0x76, 0x20, 0x64, 0x77, 0x6F, 0x72, 0x64
	.byte  0x20, 0x70, 0x74, 0x72, 0x20, 0x25, 0x73, 0x2E
	.byte  0x25, 0x73, 0x5B, 0x30, 0x5D, 0x2C, 0x20, 0x30
	.byte  0x78, 0x25, 0x78, 0x00

DS0013:
	.byte  0x2E, 0x00

DS0014:
	.byte  0x20, 0x6D, 0x6F, 0x76, 0x20, 0x25, 0x73, 0x5B
	.byte  0x25, 0x64, 0x5D, 0x2C, 0x20, 0x26, 0x40, 0x43
	.byte  0x53, 0x74, 0x72, 0x28, 0x25, 0x73, 0x29, 0x00

DS0015:
	.byte  0x20, 0x6D, 0x6F, 0x76, 0x20, 0x25, 0x73, 0x2E
	.byte  0x25, 0x73, 0x2C, 0x20, 0x26, 0x40, 0x43, 0x53
	.byte  0x74, 0x72, 0x28, 0x25, 0x73, 0x29, 0x00

DS0016:
	.byte  0x20, 0x25, 0x72, 0x20, 0x25, 0x73, 0x5B, 0x25
	.byte  0x64, 0x5D, 0x2C, 0x20, 0x25, 0x73, 0x00

DS0017:
	.byte  0x25, 0x73, 0x5B, 0x25, 0x64, 0x5D, 0x00

DS0018:
	.byte  0x20, 0x70, 0x75, 0x73, 0x68, 0x20, 0x25, 0x72
	.byte  0x0A, 0x20, 0x70, 0x75, 0x73, 0x68, 0x20, 0x25
	.byte  0x72, 0x0A, 0x20, 0x6C, 0x65, 0x61, 0x20, 0x25
	.byte  0x72, 0x2C, 0x20, 0x25, 0x73, 0x0A, 0x20, 0x6D
	.byte  0x6F, 0x76, 0x20, 0x25, 0x72, 0x2C, 0x20, 0x25
	.byte  0x64, 0x0A, 0x20, 0x72, 0x65, 0x70, 0x20, 0x73
	.byte  0x74, 0x6F, 0x73, 0x62, 0x0A, 0x20, 0x70, 0x6F
	.byte  0x70, 0x20, 0x25, 0x72, 0x0A, 0x20, 0x70, 0x6F
	.byte  0x70, 0x20, 0x25, 0x72, 0x00

DS0019:
	.byte  0x20, 0x6D, 0x6F, 0x76, 0x20, 0x25, 0x72, 0x20
	.byte  0x70, 0x74, 0x72, 0x20, 0x25, 0x73, 0x5B, 0x25
	.byte  0x64, 0x5D, 0x2C, 0x20, 0x25, 0x72, 0x00

DS001A:
	.byte  0x20, 0x6D, 0x6F, 0x76, 0x20, 0x64, 0x77, 0x6F
	.byte  0x72, 0x64, 0x20, 0x70, 0x74, 0x72, 0x20, 0x25
	.byte  0x73, 0x5B, 0x25, 0x64, 0x5D, 0x2C, 0x20, 0x65
	.byte  0x61, 0x78, 0x00

DS001B:
	.byte  0x20, 0x6D, 0x6F, 0x76, 0x20, 0x62, 0x79, 0x74
	.byte  0x65, 0x20, 0x70, 0x74, 0x72, 0x20, 0x25, 0x73
	.byte  0x5B, 0x25, 0x64, 0x5D, 0x2C, 0x20, 0x61, 0x6C
	.byte  0x00

DS001C:
	.byte  0x20, 0x25, 0x72, 0x20, 0x00

DS001D:
	.byte  0x20, 0x6D, 0x6F, 0x76, 0x20, 0x64, 0x77, 0x6F
	.byte  0x72, 0x64, 0x20, 0x70, 0x74, 0x72, 0x20, 0x25
	.byte  0x73, 0x5B, 0x30, 0x5D, 0x2C, 0x20, 0x25, 0x75
	.byte  0x0A, 0x20, 0x6D, 0x6F, 0x76, 0x20, 0x64, 0x77
	.byte  0x6F, 0x72, 0x64, 0x20, 0x70, 0x74, 0x72, 0x20
	.byte  0x25, 0x73, 0x5B, 0x34, 0x5D, 0x2C, 0x20, 0x25
	.byte  0x75, 0x00

DS001E:
	.byte  0x20, 0x6D, 0x6F, 0x76, 0x20, 0x64, 0x77, 0x6F
	.byte  0x72, 0x64, 0x20, 0x70, 0x74, 0x72, 0x20, 0x25
	.byte  0x73, 0x5B, 0x30, 0x5D, 0x2C, 0x20, 0x4C, 0x4F
	.byte  0x57, 0x33, 0x32, 0x28, 0x25, 0x73, 0x29, 0x0A
	.byte  0x20, 0x6D, 0x6F, 0x76, 0x20, 0x64, 0x77, 0x6F
	.byte  0x72, 0x64, 0x20, 0x70, 0x74, 0x72, 0x20, 0x25
	.byte  0x73, 0x5B, 0x34, 0x5D, 0x2C, 0x20, 0x48, 0x49
	.byte  0x47, 0x48, 0x33, 0x32, 0x28, 0x25, 0x73, 0x29
	.byte  0x00

DS001F:
	.byte  0x20, 0x6D, 0x6F, 0x76, 0x20, 0x64, 0x77, 0x6F
	.byte  0x72, 0x64, 0x20, 0x70, 0x74, 0x72, 0x20, 0x25
	.byte  0x73, 0x5B, 0x30, 0x5D, 0x2C, 0x20, 0x25, 0x75
	.byte  0x0A, 0x20, 0x6D, 0x6F, 0x76, 0x20, 0x64, 0x77
	.byte  0x6F, 0x72, 0x64, 0x20, 0x70, 0x74, 0x72, 0x20
	.byte  0x25, 0x73, 0x5B, 0x34, 0x5D, 0x2C, 0x20, 0x25
	.byte  0x75, 0x0A, 0x20, 0x6D, 0x6F, 0x76, 0x20, 0x77
	.byte  0x6F, 0x72, 0x64, 0x20, 0x70, 0x74, 0x72, 0x20
	.byte  0x25, 0x73, 0x5B, 0x38, 0x5D, 0x2C, 0x20, 0x25
	.byte  0x75, 0x00

DS0020:
	.byte  0x20, 0x6D, 0x6F, 0x76, 0x20, 0x64, 0x77, 0x6F
	.byte  0x72, 0x64, 0x20, 0x70, 0x74, 0x72, 0x20, 0x25
	.byte  0x73, 0x5B, 0x30, 0x5D, 0x2C, 0x20, 0x25, 0x75
	.byte  0x0A, 0x20, 0x6D, 0x6F, 0x76, 0x20, 0x64, 0x77
	.byte  0x6F, 0x72, 0x64, 0x20, 0x70, 0x74, 0x72, 0x20
	.byte  0x25, 0x73, 0x5B, 0x34, 0x5D, 0x2C, 0x20, 0x25
	.byte  0x75, 0x0A, 0x20, 0x6D, 0x6F, 0x76, 0x20, 0x64
	.byte  0x77, 0x6F, 0x72, 0x64, 0x20, 0x70, 0x74, 0x72
	.byte  0x20, 0x25, 0x73, 0x5B, 0x38, 0x5D, 0x2C, 0x20
	.byte  0x25, 0x75, 0x0A, 0x20, 0x6D, 0x6F, 0x76, 0x20
	.byte  0x64, 0x77, 0x6F, 0x72, 0x64, 0x20, 0x70, 0x74
	.byte  0x72, 0x20, 0x25, 0x73, 0x5B, 0x31, 0x32, 0x5D
	.byte  0x2C, 0x25, 0x75, 0x00

DS0021:
	.byte  0x2C, 0x20, 0x00

DS0022:
	.byte  0x26, 0x40, 0x43, 0x53, 0x74, 0x72, 0x28, 0x00

DS0023:
	.byte  0x2C, 0x00


.att_syntax prefix
