

.intel_syntax noprefix

.global SwitchDirective

.extern RunLineQueue
.extern AddLineQueueX
.extern AddLineQueue
.extern GetResWName
.extern LstWrite
.extern EvalOperand
.extern Tokenize
.extern SizeFromMemtype
.extern get_register
.extern GetCurrOffset
.extern LclDup
.extern LclAlloc
.extern ExpandCStrings
.extern HllContinueIf
.extern ExpandHllExpression
.extern ExpandHllProc
.extern EvaluateHllExpression
.extern GetLabelStr
.extern tsprintf
.extern asmerr
.extern Options
.extern Parse_Pass
.extern SymFindID
.extern SymFind
.extern tstricmp
.extern tstrcmp
.extern tstrcpy
.extern tstrchr
.extern tmemcpy


.SECTION .text
	.ALIGN	16

$_001:	push	rsi
	push	rdi
	push	rbx
	push	rbp
	mov	rbp, rsp
	sub	rsp, 88
	mov	rsi, rcx
	mov	rbx, rdx
	mov	rdi, r8
	mov	rcx, qword ptr [rbx+0x20]
	test	rcx, rcx
	jnz	$_002
	mov	edx, dword ptr [rbx+0x18]
	lea	rcx, [DS0000+rip]
	call	AddLineQueueX@PLT
	jmp	$_004

$_002:	mov	edx, 46
	call	tstrchr@PLT
	test	rax, rax
	jz	$_003
	cmp	byte ptr [rax+0x1], 46
	jnz	$_003
	mov	byte ptr [rax], 0
	lea	rdi, [rax+0x2]
	inc	dword ptr [r14+0x36C]
	mov	eax, dword ptr [r14+0x36C]
	mov	ecx, eax
	lea	rax, [DS0002+rip]
	mov	qword ptr [rsp+0x40], rax
	mov	dword ptr [rsp+0x38], ecx
	mov	eax, dword ptr [rbx+0x18]
	mov	dword ptr [rsp+0x30], eax
	mov	qword ptr [rsp+0x28], rdi
	mov	rax, qword ptr [rsi+0x20]
	mov	qword ptr [rsp+0x20], rax
	mov	r9d, ecx
	mov	r8, qword ptr [rbx+0x20]
	mov	rdx, qword ptr [rsi+0x20]
	lea	rcx, [DS0001+rip]
	call	AddLineQueueX@PLT
	jmp	$_004

$_003:	mov	r9d, dword ptr [rbx+0x18]
	mov	r8, qword ptr [rbx+0x20]
	mov	rdx, qword ptr [rsi+0x20]
	lea	rcx, [DS0003+rip]
	call	AddLineQueueX@PLT
$_004:	leave
	pop	rbx
	pop	rdi
	pop	rsi
	ret

$_005:
	push	rsi
	push	rdi
	push	rbx
	push	rbp
	mov	rbp, rsp
	sub	rsp, 40
	mov	rsi, rcx
	mov	rdi, rdx
	lea	r8, [DS0002+rip]
	mov	rdx, rdi
	lea	rcx, [DS0004+rip]
	call	AddLineQueueX@PLT
	mov	rbx, qword ptr [rsi+0x8]
	jmp	$_007

$_006:	mov	r8, rdi
	mov	rdx, rbx
	mov	rcx, rsi
	call	$_001
	mov	rbx, qword ptr [rbx+0x8]
$_007:	test	rbx, rbx
	jnz	$_006
	leave
	pop	rbx
	pop	rdi
	pop	rsi
	ret

$_008:
	mov	qword ptr [rsp+0x18], r8
	push	rbp
	mov	rbp, rsp
	add	rdx, qword ptr [rbp+0x20]
	xor	eax, eax
	mov	rcx, qword ptr [rcx+0x8]
	jmp	$_011

$_009:	test	byte ptr [rcx+0x31], 0x20
	jz	$_010
	cmp	rdx, qword ptr [rcx+0x10]
	jl	$_010
	add	eax, 1
$_010:	mov	rcx, qword ptr [rcx+0x8]
$_011:	test	rcx, rcx
	jnz	$_009
	leave
	ret

$_012:
	mov	qword ptr [rsp+0x18], r8
	push	rbp
	mov	rbp, rsp
	sub	rdx, qword ptr [rbp+0x20]
	xor	eax, eax
	mov	rcx, qword ptr [rcx+0x8]
	jmp	$_015

$_013:	test	byte ptr [rcx+0x31], 0x20
	jz	$_014
	cmp	rdx, qword ptr [rcx+0x10]
	jg	$_014
	add	eax, 1
$_014:	mov	rcx, qword ptr [rcx+0x8]
$_015:	test	rcx, rcx
	jnz	$_013
	leave
	ret

$_016:
	mov	qword ptr [rsp+0x20], r9
	push	rbx
	push	rbp
	mov	rbp, rsp
	mov	rbx, r8
	add	rbx, qword ptr [rbp+0x30]
	xor	eax, eax
	mov	rcx, qword ptr [rcx+0x8]
	jmp	$_019

$_017:	test	byte ptr [rcx+0x31], 0x20
	jz	$_018
	cmp	rbx, qword ptr [rcx+0x10]
	jge	$_018
	and	byte ptr [rcx+0x31], 0xDF
	dec	dword ptr [rdx]
	inc	eax
$_018:	mov	rcx, qword ptr [rcx+0x8]
$_019:	test	rcx, rcx
	jnz	$_017
	mov	edx, dword ptr [rdx]
	leave
	pop	rbx
	ret

$_020:
	mov	qword ptr [rsp+0x20], r9
	push	rbx
	push	rbp
	mov	rbp, rsp
	mov	rbx, r8
	sub	rbx, qword ptr [rbp+0x30]
	xor	eax, eax
	mov	rcx, qword ptr [rcx+0x8]
	jmp	$_023

$_021:	test	byte ptr [rcx+0x31], 0x20
	jz	$_022
	cmp	rbx, qword ptr [rcx+0x10]
	jle	$_022
	and	byte ptr [rcx+0x31], 0xDF
	dec	dword ptr [rdx]
	inc	eax
$_022:	mov	rcx, qword ptr [rcx+0x8]
$_023:	test	rcx, rcx
	jnz	$_021
	mov	edx, dword ptr [rdx]
	leave
	pop	rbx
	ret

$_024:
	mov	rax, qword ptr [rcx+0x8]
	jmp	$_027

$_025:	test	byte ptr [rax+0x31], 0x20
	jz	$_026
	cmp	qword ptr [rax+0x10], rdx
	jnz	$_026
	jmp	$_028

$_026:	mov	rcx, rax
	mov	rax, qword ptr [rax+0x8]
$_027:	test	rax, rax
	jnz	$_025
$_028:	ret

$_029:
	push	rbp
	mov	rbp, rsp
	sub	rsp, 32
	call	$_024
	test	rax, rax
	jz	$_030
	and	byte ptr [rax+0x31], 0xDF
	mov	eax, 1
$_030:	leave
	ret

$_031:
	mov	qword ptr [rsp+0x8], rcx
	mov	qword ptr [rsp+0x10], rdx
	mov	qword ptr [rsp+0x18], r8
	mov	qword ptr [rsp+0x20], r9
	push	rsi
	push	rdi
	push	rbx
	push	rbp
	mov	rbp, rsp
	sub	rsp, 184
	mov	byte ptr [rbp-0x74], 1
	mov	rsi, rcx
	xor	edi, edi
	xor	ebx, ebx
	mov	rax, qword ptr [rdx+0x18]
	mov	qword ptr [rbp-0x80], rax
	test	byte ptr [rsi+0x31], 0x01
	jz	$_032
	inc	byte ptr [rbp-0x74]
	jmp	$_034

$_032:	test	byte ptr [rsi+0x31], 0x02
	jz	$_033
	mov	byte ptr [rbp-0x74], 4
	jmp	$_034

$_033:	test	byte ptr [rsi+0x31], 0x04
	jz	$_034
	mov	byte ptr [rbp-0x74], 8
$_034:	mov	rsi, qword ptr [rsi+0x8]
	jmp	$_042

$_035:	test	byte ptr [rsi+0x31], 0x10
	je	$_040
	or	byte ptr [rsi+0x31], 0x20
	xor	r9d, r9d
	mov	r8, qword ptr [rbp+0x30]
	xor	edx, edx
	mov	rcx, qword ptr [rsi+0x20]
	call	Tokenize@PLT
	mov	dword ptr [r14+0x64], eax
	mov	dword ptr [rbp-0x4], 0
	mov	ecx, eax
	mov	byte ptr [rsp+0x20], 1
	lea	r9, [rbp-0x70]
	mov	r8d, ecx
	mov	rdx, qword ptr [rbp+0x30]
	lea	rcx, [rbp-0x4]
	call	EvalOperand@PLT
	test	eax, eax
	jnz	$_043
	mov	rax, qword ptr [rbp-0x70]
	cmp	byte ptr [rbp-0x74], 1
	jnz	$_036
	movsx	rax, al
	jmp	$_038

$_036:	cmp	byte ptr [rbp-0x74], 2
	jnz	$_037
	movsx	rax, ax
	jmp	$_038

$_037:	cmp	byte ptr [rbp-0x74], 4
	jnz	$_038
	movsxd	rax, eax
$_038:	cmp	dword ptr [rbp-0x34], 1
	jnz	$_039
	mov	rcx, qword ptr [rbp-0x20]
	mov	ecx, dword ptr [rcx+0x30]
	add	rax, rcx
$_039:	mov	qword ptr [rsi+0x10], rax
	inc	ebx
	jmp	$_041

$_040:	cmp	qword ptr [rsi+0x20], 0
	jz	$_041
	inc	edi
$_041:	mov	rsi, qword ptr [rsi+0x8]
$_042:	test	rsi, rsi
	jne	$_035
$_043:	xor	r9d, r9d
	mov	r8, qword ptr [rbp+0x30]
	xor	edx, edx
	mov	rcx, qword ptr [rbp-0x80]
	call	Tokenize@PLT
	mov	dword ptr [r14+0x64], eax
	mov	rax, qword ptr [rbp+0x38]
	mov	dword ptr [rax], edi
	mov	rax, qword ptr [rbp+0x40]
	mov	dword ptr [rax], ebx
	test	ebx, ebx
	jz	$_047
	cmp	dword ptr [Parse_Pass+rip], 0
	jz	$_047
	mov	rsi, qword ptr [rbp+0x28]
	mov	rsi, qword ptr [rsi+0x8]
	mov	rdi, qword ptr [rsi+0x8]
	jmp	$_046

$_044:	test	byte ptr [rsi+0x31], 0x10
	jz	$_045
	mov	edx, dword ptr [rsi+0x10]
	mov	rcx, rsi
	call	$_024
	test	rax, rax
	jz	$_045
	mov	rcx, rax
	mov	eax, dword ptr [rcx+0x10]
	mov	dword ptr [rsp+0x20], eax
	mov	r9, qword ptr [rcx+0x20]
	mov	r8d, dword ptr [rsi+0x10]
	mov	rdx, qword ptr [rsi+0x20]
	mov	ecx, 3006
	call	asmerr@PLT
$_045:	mov	rsi, qword ptr [rsi+0x8]
	mov	rdi, qword ptr [rsi+0x8]
$_046:	test	rdi, rdi
	jnz	$_044
$_047:	mov	eax, ebx
	leave
	pop	rbx
	pop	rdi
	pop	rsi
	ret

$_048:
	mov	qword ptr [rsp+0x8], rcx
	mov	qword ptr [rsp+0x10], rdx
	mov	qword ptr [rsp+0x18], r8
	mov	qword ptr [rsp+0x20], r9
	push	rsi
	push	rdi
	push	rbx
	push	rbp
	mov	rbp, rsp
	mov	rsi, rcx
	xor	edi, edi
	movabs	rax, 0x8000000000000000
	movabs	rdx, 0x7FFFFFFFFFFFFFFF
	mov	rsi, qword ptr [rsi+0x8]
	jmp	$_051

$_049:	test	byte ptr [rsi+0x31], 0x20
	jz	$_050
	inc	edi
	mov	rcx, qword ptr [rsi+0x10]
	cmp	rcx, rax
	cmovg	rax, rcx
	cmp	rcx, rdx
	cmovl	rdx, rcx
$_050:	mov	rsi, qword ptr [rsi+0x8]
$_051:	test	rsi, rsi
	jnz	$_049
	test	edi, edi
	jnz	$_052
	xor	eax, eax
	xor	edx, edx
$_052:	mov	rbx, qword ptr [rbp+0x38]
	mov	rcx, qword ptr [rbp+0x30]
	mov	qword ptr [rbx], rax
	mov	qword ptr [rcx], rdx
	mov	rsi, qword ptr [rbp+0x28]
	mov	ecx, 1
	mov	eax, 8
	test	byte ptr [rsi+0x30], 0x20
	jz	$_053
	mov	eax, 1
	jmp	$_054

$_053:	test	byte ptr [rsi+0x30], 0x40
	jnz	$_054
	add	eax, 2
	add	ecx, 1
	test	byte ptr [rsi+0x31], 0x01
	jnz	$_054
	test	byte ptr [rsi+0x31], 0x02
	jnz	$_054
	test	byte ptr [rsi+0x31], 0x04
	jnz	$_054
	add	eax, 1
	test	byte ptr [r14+0x2], 0x01
	jnz	$_054
	add	eax, 10
$_054:	mov	rsi, qword ptr [rbp+0x40]
	mov	dword ptr [rsi], eax
	mov	rsi, qword ptr [rbp+0x48]
	mov	eax, edi
	shl	eax, cl
	mov	dword ptr [rsi], eax
	mov	rax, qword ptr [rbx]
	sub	rax, rdx
	mov	ecx, edi
	add	rax, 1
	leave
	pop	rbx
	pop	rdi
	pop	rsi
	ret

$_055:
	push	rsi
	push	rdi
	push	rbx
	push	rbp
	mov	rbp, rsp
	mov	rsi, rcx
	xor	edi, edi
	xor	edx, edx
	jmp	$_063

$_056:	mov	al, byte ptr [rsi]
	mov	ah, byte ptr [rsi-0x20]
	mov	ecx, dword ptr [rsi-0x1C]
	jmp	$_061

$_057:	inc	edx
	jmp	$_062

$_058:	dec	edx
	jmp	$_062

$_059:	test	edx, edx
	jnz	$_062
	cmp	ah, 2
	jnz	$_060
	cmp	ecx, 25
	jc	$_060
	cmp	ecx, 31
	jbe	$_062
$_060:	mov	byte ptr [rsi], 0
	mov	rdi, rsi
	jmp	$_064

$_061:	cmp	al, 40
	jz	$_057
	cmp	al, 41
	jz	$_058
	cmp	al, 58
	jz	$_059
$_062:	add	rsi, 32
$_063:	cmp	byte ptr [rsi], 0
	jnz	$_056
$_064:	mov	rax, rdi
	leave
	pop	rbx
	pop	rdi
	pop	rsi
	ret

$_065:
	mov	qword ptr [rsp+0x8], rcx
	mov	qword ptr [rsp+0x10], rdx
	mov	qword ptr [rsp+0x18], r8
	mov	qword ptr [rsp+0x20], r9
	push	rsi
	push	rdi
	push	rbx
	push	rbp
	mov	rbp, rsp
	sub	rsp, 56
	mov	rbx, r9
	add	rbx, 32
	mov	rax, rbx
	mov	rsi, rbx
	xor	edi, edi
	mov	dword ptr [rbp-0x4], edi
	mov	rcx, rbx
	call	$_055
	mov	qword ptr [rbp-0x10], rax
$_066:	mov	al, byte ptr [rbx]
	jmp	$_071

$_067:	jmp	$_073

$_068:	inc	edi
	jmp	$_072

$_069:	dec	edi
	jmp	$_072

$_070:	test	edi, edi
	jnz	$_072
	mov	rdi, qword ptr [rbx+0x18]
	mov	byte ptr [rdi], 0
	mov	rdx, qword ptr [rsi+0x18]
	mov	rcx, qword ptr [rbp+0x38]
	call	tstrcpy@PLT
	lea	rsi, [rbx+0x20]
	mov	byte ptr [rdi], 44
	xor	edi, edi
	inc	dword ptr [rbp-0x4]
	mov	rdx, qword ptr [rbp+0x38]
	lea	rcx, [DS0005+rip]
	call	AddLineQueueX@PLT
	mov	byte ptr [rbx], 0
	jmp	$_072

$_071:	cmp	al, 0
	jz	$_067
	cmp	al, 40
	jz	$_068
	cmp	al, 41
	jz	$_069
	cmp	al, 44
	jz	$_070
$_072:	add	rbx, 32
	jmp	$_066

$_073:
	mov	rbx, qword ptr [rbp-0x10]
	test	rbx, rbx
	jz	$_074
	mov	byte ptr [rbx], 58
$_074:	mov	eax, dword ptr [rbp-0x4]
	test	eax, eax
	jz	$_079
	mov	rdx, qword ptr [rsi+0x18]
	lea	rcx, [DS0005+rip]
	call	AddLineQueueX@PLT
	mov	rbx, qword ptr [rbp+0x40]
	xor	eax, eax
	jmp	$_076

$_075:	add	eax, 1
	add	rbx, 32
$_076:	cmp	byte ptr [rbx], 0
	jnz	$_075
	mov	rbx, qword ptr [rbp+0x30]
	mov	dword ptr [rbx], eax
	mov	rsi, qword ptr [rbp+0x28]
	test	byte ptr [rsi+0x32], 0x08
	jz	$_078
	and	byte ptr [rsi+0x32], 0xF7
	test	byte ptr [r14], 0x08
	jz	$_077
	call	GetCurrOffset@PLT
	xor	r8d, r8d
	mov	edx, eax
	mov	ecx, 4
	call	LstWrite@PLT
$_077:	call	RunLineQueue@PLT
	or	byte ptr [rsi+0x32], 0x08
$_078:	mov	eax, 1
$_079:	leave
	pop	rbx
	pop	rdi
	pop	rsi
	ret

$_080:
	mov	qword ptr [rsp+0x8], rcx
	mov	qword ptr [rsp+0x20], r9
	push	rbp
	mov	rbp, rsp
	sub	rsp, 64
	mov	rcx, r8
	test	rcx, rcx
	jnz	$_081
	cmp	rdx, 0
	jl	$_081
	mov	r9, qword ptr [rbp+0x28]
	mov	r8, rdx
	mov	rdx, qword ptr [rbp+0x10]
	lea	rcx, [DS0006+rip]
	call	AddLineQueueX@PLT
	jmp	$_082

$_081:	mov	rax, qword ptr [rbp+0x28]
	mov	qword ptr [rsp+0x30], rax
	mov	qword ptr [rsp+0x28], rdx
	mov	rax, qword ptr [rbp+0x10]
	mov	qword ptr [rsp+0x20], rax
	mov	r9, qword ptr [rbp+0x28]
	mov	r8, rcx
	mov	rdx, qword ptr [rbp+0x10]
	lea	rcx, [DS0007+rip]
	call	AddLineQueueX@PLT
$_082:	leave
	ret

$_083:
	push	rsi
	push	rdi
	push	rbx
	push	rbp
	mov	rbp, rsp
	sub	rsp, 120
	mov	edi, ecx
	mov	rsi, rdx
	mov	rbx, r8
	test	byte ptr [r14+0x2], 0x01
	jnz	$_084
	mov	r8d, edi
	mov	edx, 774
	lea	rcx, [DS0008+rip]
	call	AddLineQueueX@PLT
$_084:	lea	rdx, [rbp-0x40]
	mov	ecx, edi
	call	GetResWName@PLT
	xor	ecx, ecx
	mov	edx, 779
	test	byte ptr [rsi+0x31], 0x01
	jne	$_091
	test	byte ptr [rsi+0x31], 0x02
	jne	$_091
	test	byte ptr [rsi+0x31], 0x04
	jne	$_091
	movzx	eax, byte ptr [r14+0x14]
	and	eax, 0x9F
	test	eax, 0x80
	jz	$_085
	mov	eax, 128
	jmp	$_086

$_085:	cmp	eax, 6
	jc	$_086
	mov	eax, 6
$_086:	cmp	eax, 3
	jc	$_088
	mov	edx, 815
	test	byte ptr [rsi+0x30], 0x80
	jz	$_087
	mov	ecx, 269
$_087:	jmp	$_090

$_088:	mov	rdx, rbx
	lea	rcx, [DS0009+rip]
	call	tstricmp@PLT
	test	eax, eax
	jz	$_089
	mov	r9, rbx
	mov	r8d, 1
	mov	edx, 779
	lea	rcx, [DS000A+rip]
	call	AddLineQueueX@PLT
$_089:	mov	edx, 785
	lea	rcx, [DS0008+0x2+rip]
	call	AddLineQueueX@PLT
	xor	edx, edx
	xor	ecx, ecx
$_090:	jmp	$_104

$_091:	test	byte ptr [rsi+0x31], 0x01
	jz	$_096
	cmp	byte ptr [r14+0x4], 0
	jnz	$_093
	test	byte ptr [rsi+0x30], 0x80
	jz	$_092
	mov	ecx, 271
$_092:	jmp	$_095

$_093:	test	byte ptr [rsi+0x30], 0x80
	jz	$_094
	mov	ecx, 271
	mov	edx, 815
	jmp	$_095

$_094:	mov	edx, 815
$_095:	jmp	$_104

$_096:	test	byte ptr [rsi+0x31], 0x02
	jz	$_103
	cmp	byte ptr [r14+0x4], 1
	jnz	$_100
	test	byte ptr [rsi+0x30], 0x80
	jz	$_097
	mov	ecx, 274
	jmp	$_099

$_097:	lea	rdx, [rbp-0x40]
	mov	rcx, rbx
	call	tstricmp@PLT
	test	eax, eax
	jz	$_098
	mov	edx, 779
	xor	ecx, ecx
	jmp	$_099

$_098:	xor	edx, edx
	xor	ecx, ecx
$_099:	jmp	$_102

$_100:	test	byte ptr [rsi+0x30], 0x80
	jz	$_101
	mov	ecx, 274
	mov	edx, 1331
	jmp	$_102

$_101:	mov	edx, 1331
$_102:	jmp	$_104

$_103:	mov	ecx, 278
$_104:	test	edx, edx
	jz	$_106
	test	ecx, ecx
	jz	$_105
	mov	qword ptr [rsp+0x20], rbx
	mov	r9d, ecx
	mov	r8d, edi
	lea	rcx, [DS000B+rip]
	call	AddLineQueueX@PLT
	jmp	$_106

$_105:	mov	r9, rbx
	mov	r8d, edi
	lea	rcx, [DS000A+rip]
	call	AddLineQueueX@PLT
$_106:	leave
	pop	rbx
	pop	rdi
	pop	rsi
	ret

$_107:
	mov	qword ptr [rsp+0x8], rcx
	mov	qword ptr [rsp+0x10], rdx
	mov	qword ptr [rsp+0x18], r8
	mov	qword ptr [rsp+0x20], r9
	push	rbp
	mov	rbp, rsp
	sub	rsp, 80
	mov	ecx, 779
	mov	edx, 4
	cmp	dword ptr [rbp+0x10], 269
	jnz	$_108
	mov	edx, 1
	mov	ecx, 816
	jmp	$_109

$_108:	cmp	dword ptr [rbp+0x10], 271
	jnz	$_109
	mov	edx, 2
	mov	ecx, 816
$_109:	test	byte ptr [Options+0x3+rip], 0x01
	jz	$_110
	mov	dword ptr [rsp+0x30], edx
	mov	rax, qword ptr [rbp+0x20]
	mov	qword ptr [rsp+0x28], rax
	mov	dword ptr [rsp+0x20], edx
	mov	r9d, dword ptr [rbp+0x18]
	mov	r8d, dword ptr [rbp+0x10]
	mov	edx, ecx
	lea	rcx, [DS000C+rip]
	call	AddLineQueueX@PLT
	jmp	$_111

$_110:	mov	rax, qword ptr [rbp+0x30]
	mov	qword ptr [rsp+0x40], rax
	mov	rax, qword ptr [rbp+0x28]
	mov	qword ptr [rsp+0x38], rax
	mov	dword ptr [rsp+0x30], edx
	mov	rax, qword ptr [rbp+0x20]
	mov	qword ptr [rsp+0x28], rax
	mov	dword ptr [rsp+0x20], edx
	mov	r9d, dword ptr [rbp+0x18]
	mov	r8d, dword ptr [rbp+0x10]
	mov	edx, ecx
	lea	rcx, [DS000D+rip]
	call	AddLineQueueX@PLT
$_111:	leave
	ret

$_112:
	mov	qword ptr [rsp+0x8], rcx
	mov	qword ptr [rsp+0x10], rdx
	mov	qword ptr [rsp+0x18], r8
	mov	qword ptr [rsp+0x20], r9
	push	rsi
	push	rdi
	push	rbx
	push	rbp
	mov	rbp, rsp
	sub	rsp, 248
	lea	rax, [rbp-0x28]
	mov	qword ptr [rbp-0x48], rax
	lea	rax, [rbp-0x18]
	mov	qword ptr [rbp-0x50], rax
	mov	rax, qword ptr [rbp+0x40]
	mov	qword ptr [rbp-0x58], rax
	mov	rsi, rcx
	mov	rdi, r8
	lea	r9, [rbp-0x60]
	lea	r8, [rbp-0x5C]
	mov	rdx, qword ptr [rbp+0x30]
	mov	rcx, rsi
	call	$_031
	test	eax, eax
	jz	$_113
	test	byte ptr [rsi+0x30], 0x20
	jz	$_113
	add	eax, 8
$_113:	test	byte ptr [r14+0x1], 0x80
	jnz	$_114
	cmp	eax, 8
	jnc	$_115
$_114:	mov	rdx, rdi
	mov	rcx, rsi
	call	$_005
	jmp	$_240

$_115:	mov	dword ptr [rbp-0x64], 274
	cmp	byte ptr [r14+0x4], 0
	jnz	$_116
	mov	dword ptr [rbp-0x64], 271
$_116:	mov	rdx, rdi
	mov	rcx, qword ptr [rbp-0x50]
	call	tstrcpy@PLT
	mov	qword ptr [rbp-0x70], 0
	test	byte ptr [rsi+0x30], 0x01
	jz	$_119
	mov	rax, rsi
	mov	rbx, qword ptr [rsi+0x8]
$_117:	test	rbx, rbx
	jz	$_119
	test	byte ptr [rbx+0x30], 0x08
	jz	$_118
	mov	qword ptr [rax+0x8], 0
	mov	qword ptr [rbp-0x70], rbx
	mov	rdx, qword ptr [rbp+0x40]
	mov	ecx, dword ptr [rbx+0x18]
	call	GetLabelStr@PLT
	jmp	$_119

$_118:	mov	rax, rbx
	mov	rbx, qword ptr [rbx+0x8]
	jmp	$_117

$_119:	cmp	byte ptr [r14+0x28], 0
	jz	$_120
	test	byte ptr [rsi+0x32], 0x20
	jnz	$_120
	mov	cl, byte ptr [r14+0x28]
	mov	eax, 1
	shl	eax, cl
	mov	r8d, eax
	mov	edx, 611
	lea	rcx, [DS000E+rip]
	call	AddLineQueueX@PLT
	jmp	$_122

$_120:	test	byte ptr [rsi+0x30], 0x20
	jz	$_122
	test	byte ptr [rsi+0x32], 0x10
	jz	$_122
	cmp	byte ptr [r14+0x4], 1
	jc	$_122
	test	byte ptr [rsi+0x32], 0x20
	jnz	$_122
	mov	ecx, 274
	mov	edx, 611
	cmp	byte ptr [r14+0x4], 2
	jnz	$_121
	mov	ecx, 278
$_121:	mov	r8d, ecx
	lea	rcx, [DS000F+rip]
	call	AddLineQueueX@PLT
$_122:	lea	r8, [DS0002+rip]
	mov	rdx, qword ptr [rbp-0x50]
	lea	rcx, [DS0004+rip]
	call	AddLineQueueX@PLT
	cmp	dword ptr [rbp-0x5C], 0
	jz	$_125
	mov	rax, rsi
	mov	rbx, qword ptr [rsi+0x8]
$_123:	test	rbx, rbx
	jz	$_125
	test	byte ptr [rbx+0x31], 0x10
	jnz	$_124
	mov	rcx, qword ptr [rbx+0x8]
	mov	qword ptr [rax+0x8], rcx
	mov	r8, rdi
	mov	rdx, rbx
	mov	rcx, rsi
	call	$_001
$_124:	mov	rax, rbx
	mov	rbx, qword ptr [rbx+0x8]
	jmp	$_123

$_125:	jmp	$_236

$_126:	lea	rax, [rbp-0x88]
	mov	qword ptr [rsp+0x20], rax
	lea	r9, [rbp-0x84]
	lea	r8, [rbp-0x80]
	lea	rdx, [rbp-0x78]
	mov	rcx, rsi
	call	$_048
	mov	qword ptr [rbp-0x90], rax
	mov	dword ptr [rbp-0x94], ecx
	mov	dword ptr [rbp-0x98], 0
	cmp	ecx, dword ptr [rbp-0x84]
	jc	$_237
	mov	ebx, ecx
$_127:	cmp	ebx, dword ptr [rbp-0x84]
	jc	$_134
	cmp	qword ptr [rbp-0x80], rdx
	jle	$_134
	cmp	eax, dword ptr [rbp-0x88]
	jbe	$_134
	mov	r8d, dword ptr [rbp-0x88]
	mov	rdx, qword ptr [rbp-0x78]
	mov	rcx, rsi
	call	$_008
	mov	ebx, eax
	mov	r8d, dword ptr [rbp-0x88]
	mov	rdx, qword ptr [rbp-0x80]
	mov	rcx, rsi
	call	$_012
	jmp	$_132

$_128:	mov	rdx, qword ptr [rbp-0x78]
	mov	rcx, rsi
	call	$_029
	test	rax, rax
	je	$_134
	sub	dword ptr [rbp-0x94], eax
	jmp	$_133

$_129:	mov	rdx, qword ptr [rbp-0x80]
	mov	rcx, rsi
	call	$_029
	test	rax, rax
	je	$_134
	sub	dword ptr [rbp-0x94], eax
	jmp	$_133

$_130:	mov	ebx, dword ptr [rbp-0x94]
	mov	r9d, dword ptr [rbp-0x88]
	mov	r8, qword ptr [rbp-0x78]
	lea	rdx, [rbp-0x94]
	mov	rcx, rsi
	call	$_016
	jmp	$_133

$_131:	mov	ebx, dword ptr [rbp-0x94]
	mov	r9d, dword ptr [rbp-0x88]
	mov	r8, qword ptr [rbp-0x80]
	lea	rdx, [rbp-0x94]
	mov	rcx, rsi
	call	$_020
	jmp	$_133

$_132:	cmp	ebx, dword ptr [rbp-0x84]
	jc	$_128
	cmp	eax, dword ptr [rbp-0x84]
	jc	$_129
	cmp	ebx, eax
	jnc	$_130
	jmp	$_131

$_133:	add	dword ptr [rbp-0x98], eax
	lea	rax, [rbp-0x88]
	mov	qword ptr [rsp+0x20], rax
	lea	r9, [rbp-0x84]
	lea	r8, [rbp-0x80]
	lea	rdx, [rbp-0x78]
	mov	rcx, rsi
	call	$_048
	mov	qword ptr [rbp-0x90], rax
	cmp	ebx, dword ptr [rbp-0x94]
	jz	$_134
	mov	ebx, dword ptr [rbp-0x94]
	jmp	$_127

$_134:	mov	eax, dword ptr [rbp-0x94]
	cmp	eax, dword ptr [rbp-0x84]
	jc	$_237
	mov	byte ptr [rbp-0x39], 0
	cmp	rax, qword ptr [rbp-0x90]
	jge	$_135
	cmp	byte ptr [r14+0x4], 2
	jnz	$_135
	inc	byte ptr [rbp-0x39]
$_135:	test	byte ptr [rsi+0x30], 0x20
	jz	$_136
	test	byte ptr [rsi+0x32], 0x10
	jz	$_136
	mov	byte ptr [rbp-0x39], 0
	mov	rdx, qword ptr [rbp-0x50]
	mov	rcx, qword ptr [rbp-0x48]
	call	tstrcpy@PLT
	mov	r8, qword ptr [rbp-0x78]
	mov	rdx, rax
	lea	rcx, [DS0010+rip]
	call	AddLineQueueX@PLT
	jmp	$_137

$_136:	inc	dword ptr [r14+0x36C]
	mov	eax, dword ptr [r14+0x36C]
	mov	rdx, qword ptr [rbp-0x48]
	mov	ecx, eax
	call	GetLabelStr@PLT
$_137:	mov	rdi, qword ptr [rbp+0x40]
	cmp	dword ptr [rbp-0x98], 0
	jz	$_138
	inc	dword ptr [r14+0x36C]
	mov	eax, dword ptr [r14+0x36C]
	mov	rdx, qword ptr [rbp-0x50]
	mov	ecx, eax
	call	GetLabelStr@PLT
	mov	rdi, rax
$_138:	mov	rbx, qword ptr [rsi+0x20]
	test	byte ptr [rsi+0x30], 0x20
	jnz	$_139
	mov	r9, rdi
	mov	r8, qword ptr [rbp-0x78]
	mov	rdx, qword ptr [rbp-0x80]
	mov	rcx, rbx
	call	$_080
$_139:	mov	cl, byte ptr [r14+0x4]
	test	byte ptr [rsi+0x30], 0x20
	jz	$_142
	test	byte ptr [rsi+0x32], 0x10
	jz	$_142
	test	byte ptr [rsi+0x32], 0x20
	jz	$_140
	mov	rdx, qword ptr [rbp-0x48]
	lea	rcx, [DS0011+rip]
	call	AddLineQueueX@PLT
	jmp	$_141

$_140:	cmp	cl, 2
	jnz	$_141
	mov	dword ptr [rbp-0x64], 278
$_141:	jmp	$_206

$_142:	test	cl, cl
	jne	$_154
	test	byte ptr [r14+0x2], 0x01
	jnz	$_143
	lea	rcx, [DS0012+rip]
	call	AddLineQueue@PLT
$_143:	test	byte ptr [rsi+0x30], 0x40
	jz	$_147
	test	byte ptr [r14+0x2], 0x01
	jz	$_145
	mov	rdx, rbx
	lea	rcx, [DS0012+0x6+rip]
	call	tstricmp@PLT
	test	eax, eax
	jz	$_144
	mov	rdx, rbx
	lea	rcx, [DS0013+rip]
	call	AddLineQueueX@PLT
$_144:	lea	rcx, [DS0014+rip]
	call	AddLineQueue@PLT
	jmp	$_146

$_145:	lea	rcx, [DS0015+rip]
	call	AddLineQueue@PLT
	mov	rdx, rbx
	lea	rcx, [DS0014+0xA+rip]
	call	tstricmp@PLT
	test	eax, eax
	jz	$_146
	mov	rdx, rbx
	lea	rcx, [DS0016+rip]
	call	AddLineQueueX@PLT
$_146:	jmp	$_150

$_147:	test	byte ptr [r14+0x2], 0x01
	jnz	$_148
	lea	rcx, [DS0017+rip]
	call	AddLineQueue@PLT
$_148:	mov	r8, rbx
	mov	rdx, rsi
	mov	ecx, 9
	call	$_083
	test	byte ptr [r14+0x2], 0x01
	jz	$_149
	lea	rcx, [DS0014+rip]
	call	AddLineQueue@PLT
	jmp	$_150

$_149:	lea	rcx, [DS0018+rip]
	call	AddLineQueue@PLT
$_150:	cmp	qword ptr [rbp-0x78], 0
	jz	$_151
	mov	rdx, qword ptr [rbp-0x78]
	lea	rcx, [DS0019+rip]
	call	AddLineQueueX@PLT
$_151:	lea	rcx, [DS001A+rip]
	call	AddLineQueue@PLT
	test	byte ptr [r14+0x2], 0x01
	jz	$_152
	mov	rdx, qword ptr [rbp-0x48]
	lea	rcx, [DS001B+rip]
	call	AddLineQueueX@PLT
	jmp	$_153

$_152:	mov	rdx, qword ptr [rbp-0x48]
	lea	rcx, [DS001C+rip]
	call	AddLineQueueX@PLT
$_153:	jmp	$_202

$_154:	cmp	cl, 1
	jne	$_171
	test	byte ptr [rsi+0x30], 0x40
	jne	$_163
	mov	r8, rbx
	mov	rdx, rsi
	mov	ecx, 17
	call	$_083
	cmp	byte ptr [rbp-0x39], 0
	jz	$_159
	cmp	qword ptr [rbp-0x90], 256
	jge	$_155
	mov	r8, qword ptr [rbp-0x78]
	mov	rdx, qword ptr [rbp-0x48]
	lea	rcx, [DS001D+rip]
	call	AddLineQueueX@PLT
	jmp	$_156

$_155:	mov	r8, qword ptr [rbp-0x78]
	mov	rdx, qword ptr [rbp-0x48]
	lea	rcx, [DS001E+rip]
	call	AddLineQueueX@PLT
$_156:	test	byte ptr [r14+0x2], 0x01
	jz	$_157
	mov	rdx, qword ptr [rbp-0x48]
	lea	rcx, [DS001F+rip]
	call	AddLineQueueX@PLT
	jmp	$_158

$_157:	mov	rdx, qword ptr [rbp-0x48]
	lea	rcx, [DS0020+rip]
	call	AddLineQueueX@PLT
$_158:	jmp	$_161

$_159:	test	byte ptr [r14+0x2], 0x01
	jz	$_160
	mov	r8, qword ptr [rbp-0x78]
	mov	rdx, qword ptr [rbp-0x48]
	lea	rcx, [DS0021+rip]
	call	AddLineQueueX@PLT
	jmp	$_161

$_160:	mov	r8, qword ptr [rbp-0x78]
	mov	rdx, qword ptr [rbp-0x48]
	lea	rcx, [DS0022+rip]
	call	AddLineQueueX@PLT
$_161:	test	byte ptr [r14+0x2], 0x01
	jnz	$_162
	lea	rcx, [DS0023+rip]
	call	AddLineQueue@PLT
$_162:	jmp	$_170

$_163:	cmp	byte ptr [rbp-0x39], 0
	je	$_169
	test	byte ptr [r14+0x2], 0x01
	jnz	$_164
	mov	rdx, rbx
	lea	rcx, [DS0024+rip]
	call	AddLineQueueX@PLT
$_164:	cmp	qword ptr [rbp-0x90], 256
	jge	$_165
	mov	rax, qword ptr [rbp-0x78]
	mov	qword ptr [rsp+0x20], rax
	mov	r9, qword ptr [rbp-0x48]
	mov	r8, rbx
	mov	rdx, rbx
	lea	rcx, [DS0025+rip]
	call	AddLineQueueX@PLT
	jmp	$_166

$_165:	mov	rax, qword ptr [rbp-0x78]
	mov	qword ptr [rsp+0x20], rax
	mov	r9, qword ptr [rbp-0x48]
	mov	r8, rbx
	mov	rdx, rbx
	lea	rcx, [DS0026+rip]
	call	AddLineQueueX@PLT
$_166:	test	byte ptr [r14+0x2], 0x01
	jz	$_167
	mov	r8, qword ptr [rbp-0x48]
	mov	rdx, rbx
	lea	rcx, [DS0027+rip]
	call	AddLineQueueX@PLT
	jmp	$_168

$_167:	mov	qword ptr [rsp+0x20], rbx
	mov	r9, qword ptr [rbp-0x48]
	mov	r8, rbx
	mov	rdx, rbx
	lea	rcx, [DS0028+rip]
	call	AddLineQueueX@PLT
$_168:	jmp	$_170

$_169:	mov	r9, qword ptr [rbp-0x78]
	mov	r8, qword ptr [rbp-0x48]
	mov	rdx, rbx
	lea	rcx, [DS0029+rip]
	call	AddLineQueueX@PLT
$_170:	jmp	$_202

$_171:	mov	dword ptr [rbp-0x9C], 0
	mov	qword ptr [rbp-0xA8], rsi
	mov	rsi, qword ptr [rsi+0x8]
$_172:	test	rsi, rsi
	jz	$_175
	test	byte ptr [rsi+0x31], 0x20
	jz	$_174
	lea	rdx, [rbp-0x38]
	mov	ecx, dword ptr [rsi+0x18]
	call	GetLabelStr@PLT
	mov	rcx, rax
	call	SymFind@PLT
	test	rax, rax
	jz	$_173
	mov	eax, dword ptr [rax+0x30]
	mov	dword ptr [rbp-0x9C], eax
$_173:	jmp	$_175

$_174:	mov	rsi, qword ptr [rsi+0x8]
	jmp	$_172

$_175:	mov	rsi, qword ptr [rbp-0xA8]
	cmp	dword ptr [Parse_Pass+rip], 0
	jnz	$_176
	cmp	qword ptr [rbp-0x70], 0
	jnz	$_176
	call	GetCurrOffset@PLT
	add	rax, 34
	add	eax, dword ptr [rbp-0x60]
	jmp	$_177

$_176:	mov	rcx, qword ptr [rbp-0x58]
	call	SymFind@PLT
	test	rax, rax
	jz	$_177
	mov	eax, dword ptr [rax+0x30]
$_177:	cmp	dword ptr [rbp-0x9C], 0
	jz	$_181
	test	eax, eax
	jz	$_181
	cmp	eax, dword ptr [rbp-0x9C]
	jbe	$_178
	sub	eax, dword ptr [rbp-0x9C]
	jmp	$_179

$_178:	xor	eax, eax
$_179:	test	eax, 0xFFFFFF00
	jnz	$_180
	mov	dword ptr [rbp-0x64], 269
	jmp	$_181

$_180:	test	eax, 0xFFFF0000
	jnz	$_181
	mov	dword ptr [rbp-0x64], 271
$_181:	cmp	byte ptr [rbp-0x39], 0
	jne	$_186
	test	byte ptr [rsi+0x30], 0x40
	je	$_186
	test	byte ptr [rsi+0x31], 0x08
	je	$_186
	test	byte ptr [r14+0x2], 0x01
	je	$_186
	mov	ebx, dword ptr [rsi+0x2C]
	mov	edx, 8
	mov	ecx, ebx
	call	get_register@PLT
	cmp	eax, 173
	jz	$_182
	cmp	eax, 174
	jnz	$_183
$_182:	lea	rdx, [DS002A+rip]
	mov	ecx, 2008
	call	asmerr@PLT
$_183:	test	byte ptr [rsi+0x31], 0x08
	jz	$_185
	mov	rax, qword ptr [rbp-0x78]
	cmp	rax, 0
	jge	$_184
	mov	edx, ebx
	lea	rcx, [DS002B+rip]
	call	AddLineQueueX@PLT
	mov	ebx, 173
	jmp	$_185

$_184:	mov	ecx, ebx
	lea	ebx, [rbx+0x92]
	cmp	ecx, 139
	jc	$_185
	lea	ebx, [rcx+0x20]
$_185:	mov	rdx, qword ptr [rbp-0x58]
	lea	rcx, [DS002C+rip]
	call	AddLineQueueX@PLT
	mov	rax, qword ptr [rbp-0x58]
	mov	qword ptr [rsp+0x20], rax
	mov	r9, qword ptr [rbp-0x48]
	mov	r8, qword ptr [rbp-0x78]
	mov	edx, ebx
	mov	ecx, dword ptr [rbp-0x64]
	call	$_107
	lea	rcx, [DS002D+rip]
	call	AddLineQueueX@PLT
	jmp	$_202

$_186:	test	byte ptr [r14+0x2], 0x01
	je	$_195
	mov	rcx, rbx
	mov	ebx, dword ptr [rsi+0x2C]
	test	byte ptr [rsi+0x30], 0x40
	jnz	$_187
	test	byte ptr [rsi+0x31], 0x08
	jnz	$_187
	mov	r8, rcx
	mov	rdx, rsi
	mov	ecx, 173
	call	$_083
	mov	ebx, 173
	jmp	$_189

$_187:	test	byte ptr [rsi+0x31], 0x08
	jz	$_189
	mov	rax, qword ptr [rbp-0x78]
	cmp	rax, 0
	jge	$_188
	mov	edx, ebx
	lea	rcx, [DS002B+rip]
	call	AddLineQueueX@PLT
	mov	ebx, 163
	jmp	$_189

$_188:	mov	ecx, ebx
	lea	ebx, [rbx+0x92]
	cmp	ecx, 139
	jc	$_189
	lea	ebx, [rcx+0x20]
$_189:	mov	rdx, qword ptr [rbp-0x58]
	test	byte ptr [Options+0x3+rip], 0x01
	jz	$_190
	mov	rdx, qword ptr [rbp-0x48]
$_190:	lea	rcx, [DS002C+rip]
	call	AddLineQueueX@PLT
	mov	rcx, qword ptr [rbp-0x78]
	cmp	byte ptr [rbp-0x39], 0
	jz	$_193
	mov	rax, qword ptr [rbp-0x58]
	mov	edx, 271
	test	byte ptr [Options+0x3+rip], 0x01
	jz	$_191
	mov	rax, qword ptr [rbp-0x48]
$_191:	cmp	qword ptr [rbp-0x90], 256
	jge	$_192
	mov	edx, 269
$_192:	mov	qword ptr [rsp+0x38], rax
	mov	rax, qword ptr [rbp-0x48]
	mov	qword ptr [rsp+0x30], rax
	mov	dword ptr [rsp+0x28], edx
	mov	qword ptr [rsp+0x20], rcx
	mov	r9d, edx
	mov	r8d, ebx
	lea	rcx, [DS002E+rip]
	call	AddLineQueueX@PLT
	xor	ecx, ecx
	mov	ebx, 173
$_193:	mov	rax, qword ptr [rbp-0x58]
	mov	qword ptr [rsp+0x20], rax
	mov	r9, qword ptr [rbp-0x48]
	mov	r8, rcx
	mov	edx, ebx
	mov	ecx, dword ptr [rbp-0x64]
	call	$_107
	test	byte ptr [Options+0x3+rip], 0x01
	jz	$_194
	mov	rdx, qword ptr [rbp-0x58]
	lea	rcx, [DS002C+rip]
	call	AddLineQueueX@PLT
$_194:	lea	rcx, [DS002D+rip]
	call	AddLineQueue@PLT
	jmp	$_202

$_195:	mov	rcx, rbx
	mov	ebx, dword ptr [rsi+0x2C]
	test	byte ptr [rsi+0x30], 0x40
	jnz	$_196
	test	byte ptr [rsi+0x31], 0x08
	jnz	$_196
	mov	r8, rcx
	mov	rdx, rsi
	mov	ecx, 163
	call	$_083
	mov	ebx, 163
	jmp	$_198

$_196:	lea	rcx, [DS002F+rip]
	call	AddLineQueue@PLT
	test	byte ptr [rsi+0x31], 0x08
	jz	$_198
	mov	rax, qword ptr [rbp-0x78]
	cmp	rax, 0
	jge	$_197
	mov	edx, ebx
	lea	rcx, [DS0030+rip]
	call	AddLineQueueX@PLT
	mov	ebx, 163
	jmp	$_198

$_197:	mov	ecx, ebx
	lea	ebx, [rbx+0x92]
	cmp	ecx, 139
	jc	$_198
	lea	ebx, [rcx+0x20]
$_198:	mov	rdx, qword ptr [rbp-0x58]
	lea	rcx, [DS0031+rip]
	call	AddLineQueueX@PLT
	mov	rcx, qword ptr [rbp-0x78]
	cmp	byte ptr [rbp-0x39], 0
	jz	$_201
	cmp	qword ptr [rbp-0x90], 256
	jge	$_199
	mov	rax, qword ptr [rbp-0x58]
	mov	qword ptr [rsp+0x20], rax
	mov	r9, qword ptr [rbp-0x48]
	mov	r8, rcx
	mov	edx, ebx
	lea	rcx, [DS0032+rip]
	call	AddLineQueueX@PLT
	jmp	$_200

$_199:	mov	rax, qword ptr [rbp-0x58]
	mov	qword ptr [rsp+0x20], rax
	mov	r9, qword ptr [rbp-0x48]
	mov	r8, rcx
	mov	edx, ebx
	lea	rcx, [DS0033+rip]
	call	AddLineQueueX@PLT
$_200:	xor	ecx, ecx
	mov	ebx, 163
$_201:	mov	rax, qword ptr [rbp-0x58]
	mov	qword ptr [rsp+0x20], rax
	mov	r9, qword ptr [rbp-0x48]
	mov	r8, rcx
	mov	edx, ebx
	mov	ecx, dword ptr [rbp-0x64]
	call	$_107
	lea	rcx, [DS0034+rip]
	call	AddLineQueue@PLT
$_202:	test	byte ptr [Options+0x3+rip], 0x01
	jz	$_203
	test	byte ptr [rsi+0x32], 0x20
	jnz	$_203
	lea	rcx, [DS0035+rip]
	call	AddLineQueue@PLT
$_203:	cmp	dword ptr [rbp-0x64], 269
	jz	$_204
	mov	edx, dword ptr [rbp-0x64]
	lea	rcx, [DS0036+rip]
	call	AddLineQueueX@PLT
$_204:	test	byte ptr [Options+0x3+rip], 0x01
	jz	$_205
	test	byte ptr [rsi+0x32], 0x20
	jnz	$_205
	mov	r9d, dword ptr [rbp-0x64]
	mov	r8d, 608
	mov	rdx, qword ptr [rbp-0x48]
	lea	rcx, [DS0037+rip]
	call	AddLineQueueX@PLT
	jmp	$_206

$_205:	lea	r8, [DS0002+rip]
	mov	rdx, qword ptr [rbp-0x48]
	lea	rcx, [DS0004+rip]
	call	AddLineQueueX@PLT
$_206:	cmp	byte ptr [rbp-0x39], 0
	je	$_225
	mov	qword ptr [rbp-0xA8], rdi
	mov	ebx, 4294967295
	mov	edi, 4294967295
	mov	rsi, qword ptr [rsi+0x8]
$_207:	test	rsi, rsi
	jz	$_210
	test	byte ptr [rsi+0x31], 0x20
	jz	$_209
	lea	rdx, [rbp-0x38]
	mov	ecx, dword ptr [rsi+0x18]
	call	GetLabelStr@PLT
	mov	rcx, rax
	call	SymFind@PLT
	test	rax, rax
	jz	$_210
	cmp	ebx, dword ptr [rax+0x30]
	jz	$_208
	mov	ebx, dword ptr [rax+0x30]
	inc	edi
$_208:	mov	qword ptr [rsi], rdi
$_209:	mov	rsi, qword ptr [rsi+0x8]
	jmp	$_207

$_210:	inc	edi
	mov	dword ptr [rbp-0x4], edi
	mov	rdi, qword ptr [rbp-0xA8]
	mov	rsi, qword ptr [rbp+0x28]
	mov	ebx, 4294967295
	mov	rsi, qword ptr [rsi+0x8]
$_211:	test	rsi, rsi
	jz	$_215
	test	byte ptr [rsi+0x31], 0x20
	jz	$_214
	cmp	rbx, qword ptr [rsi]
	jz	$_214
	cmp	byte ptr [r14+0x4], 2
	jnz	$_212
	mov	r9d, dword ptr [rsi+0x18]
	mov	r8, qword ptr [rbp-0x58]
	mov	edx, dword ptr [rbp-0x64]
	lea	rcx, [DS0038+rip]
	call	AddLineQueueX@PLT
	jmp	$_213

$_212:	mov	r8d, dword ptr [rsi+0x18]
	mov	edx, dword ptr [rbp-0x64]
	lea	rcx, [DS0039+rip]
	call	AddLineQueueX@PLT
$_213:	mov	rbx, qword ptr [rsi]
$_214:	mov	rsi, qword ptr [rsi+0x8]
	jmp	$_211

$_215:	mov	rsi, qword ptr [rbp+0x28]
	cmp	byte ptr [r14+0x4], 2
	jnz	$_216
	mov	edx, dword ptr [rbp-0x64]
	lea	rcx, [DS003A+rip]
	call	AddLineQueueX@PLT
	jmp	$_217

$_216:	mov	r8, qword ptr [rbp+0x40]
	mov	edx, dword ptr [rbp-0x64]
	lea	rcx, [DS003B+rip]
	call	AddLineQueueX@PLT
$_217:	mov	rax, qword ptr [rbp-0x80]
	sub	rax, qword ptr [rbp-0x78]
	inc	eax
	mov	dword ptr [rbp-0x8], eax
	mov	ecx, 269
	cmp	eax, 256
	jle	$_219
	cmp	byte ptr [r14+0x4], 0
	jnz	$_218
	mov	r8d, 2
	mov	edx, 1
	mov	ecx, 2022
	call	asmerr@PLT
	jmp	$_240

$_218:	mov	ecx, 271
$_219:	mov	dword ptr [rbp-0xAC], ecx
	mov	r8d, ecx
	mov	rdx, qword ptr [rbp-0x48]
	lea	rcx, [DS003C+rip]
	call	AddLineQueueX@PLT
	xor	ebx, ebx
$_220:	cmp	ebx, dword ptr [rbp-0x8]
	jnc	$_223
	mov	rax, qword ptr [rbp-0x78]
	add	rax, rbx
	mov	rdx, rax
	mov	rcx, rsi
	call	$_024
	test	rax, rax
	jz	$_221
	mov	rdx, qword ptr [rax+0x8]
	mov	qword ptr [rcx+0x8], rdx
	mov	r8, qword ptr [rax]
	mov	edx, dword ptr [rbp-0xAC]
	lea	rcx, [DS000E+rip]
	call	AddLineQueueX@PLT
	jmp	$_222

$_221:	mov	r8d, dword ptr [rbp-0x4]
	mov	edx, dword ptr [rbp-0xAC]
	lea	rcx, [DS000E+rip]
	call	AddLineQueueX@PLT
$_222:	inc	ebx
	jmp	$_220

$_223:	cmp	dword ptr [rbp-0x64], 269
	jz	$_224
	mov	edx, dword ptr [rbp-0x64]
	lea	rcx, [DS0036+rip]
	call	AddLineQueueX@PLT
$_224:	jmp	$_232

$_225:	xor	ebx, ebx
$_226:	cmp	rbx, qword ptr [rbp-0x90]
	jge	$_232
	mov	rax, qword ptr [rbp-0x78]
	add	rax, rbx
	mov	rdx, rax
	mov	rcx, rsi
	call	$_024
	test	rax, rax
	jz	$_229
	mov	rdx, qword ptr [rax+0x8]
	mov	qword ptr [rcx+0x8], rdx
	mov	ecx, dword ptr [rax+0x18]
	cmp	byte ptr [r14+0x4], 2
	jnz	$_227
	mov	r9d, ecx
	mov	r8, qword ptr [rbp-0x58]
	mov	edx, dword ptr [rbp-0x64]
	lea	rcx, [DS0038+rip]
	call	AddLineQueueX@PLT
	jmp	$_228

$_227:	mov	r8d, ecx
	mov	edx, dword ptr [rbp-0x64]
	lea	rcx, [DS0039+rip]
	call	AddLineQueueX@PLT
$_228:	jmp	$_231

$_229:	cmp	byte ptr [r14+0x4], 2
	jnz	$_230
	mov	edx, dword ptr [rbp-0x64]
	lea	rcx, [DS003A+rip]
	call	AddLineQueueX@PLT
	jmp	$_231

$_230:	mov	r8, qword ptr [rbp+0x40]
	mov	edx, dword ptr [rbp-0x64]
	lea	rcx, [DS003B+rip]
	call	AddLineQueueX@PLT
$_231:	inc	ebx
	jmp	$_226

$_232:	test	byte ptr [Options+0x3+rip], 0x01
	jnz	$_233
	test	byte ptr [rsi+0x32], 0x20
	jz	$_234
$_233:	lea	rcx, [DS003D+rip]
	call	AddLineQueue@PLT
$_234:	cmp	dword ptr [rbp-0x98], 0
	jz	$_236
	lea	r8, [DS0002+rip]
	mov	rdx, qword ptr [rbp-0x50]
	lea	rcx, [DS0004+rip]
	call	AddLineQueueX@PLT
	mov	rbx, qword ptr [rsi+0x8]
$_235:	test	rbx, rbx
	jz	$_236
	or	byte ptr [rbx+0x31], 0x20
	mov	rbx, qword ptr [rbx+0x8]
	jmp	$_235

$_236:	cmp	qword ptr [rsi+0x20], 0
	jne	$_126
$_237:	mov	rbx, qword ptr [rsi+0x8]
$_238:	test	rbx, rbx
	jz	$_239
	mov	r8, qword ptr [rbp+0x38]
	mov	rdx, rbx
	mov	rcx, rsi
	call	$_001
	mov	rbx, qword ptr [rbx+0x8]
	jmp	$_238

$_239:	cmp	qword ptr [rbp-0x70], 0
	jz	$_240
	cmp	qword ptr [rsi+0x8], 0
	jz	$_240
	mov	rdx, qword ptr [rbp+0x40]
	lea	rcx, [DS003E+rip]
	call	AddLineQueueX@PLT
$_240:	leave
	pop	rbx
	pop	rdi
	pop	rsi
	ret

$_241:
	push	rsi
	push	rdi
	push	rbx
	push	rbp
	mov	rbp, rsp
	sub	rsp, 168
	mov	rsi, rcx
	lea	rdi, [rbp-0x20]
	cmp	dword ptr [rsi+0x14], 0
	jnz	$_242
	inc	dword ptr [r14+0x36C]
	mov	eax, dword ptr [r14+0x36C]
	mov	dword ptr [rsi+0x14], eax
$_242:	cmp	dword ptr [rsi+0x1C], 0
	jnz	$_243
	inc	dword ptr [r14+0x36C]
	mov	eax, dword ptr [r14+0x36C]
	mov	dword ptr [rsi+0x1C], eax
$_243:	lea	r8, [DS0002+rip]
	mov	edx, dword ptr [rsi+0x1C]
	lea	rcx, [DS0001+0x2F+rip]
	call	AddLineQueueX@PLT
	mov	rdx, rdi
	mov	ecx, dword ptr [rsi+0x18]
	call	GetLabelStr@PLT
	lea	rdx, [rbp-0x10]
	mov	ecx, dword ptr [rsi+0x14]
	call	GetLabelStr@PLT
	mov	ebx, dword ptr [rsi+0x2C]
	mov	cl, byte ptr [r14+0x4]
	test	cl, cl
	jnz	$_248
	test	byte ptr [r14+0x2], 0x01
	jz	$_245
	cmp	ebx, 9
	jz	$_244
	mov	edx, ebx
	lea	rcx, [DS003F+rip]
	call	AddLineQueueX@PLT
$_244:	mov	rdx, rdi
	lea	rcx, [DS0040+rip]
	call	AddLineQueueX@PLT
	jmp	$_247

$_245:	lea	rcx, [DS0041+rip]
	call	AddLineQueue@PLT
	cmp	ebx, 12
	jz	$_246
	mov	edx, ebx
	lea	rcx, [DS0042+rip]
	call	AddLineQueueX@PLT
$_246:	mov	rdx, rdi
	lea	rcx, [DS0043+rip]
	call	AddLineQueueX@PLT
$_247:	jmp	$_259

$_248:	cmp	cl, 1
	jnz	$_251
	test	byte ptr [rsi+0x32], 0x20
	jz	$_249
	mov	r9, rdi
	mov	r8, rdi
	mov	edx, ebx
	lea	rcx, [DS0044+rip]
	call	AddLineQueueX@PLT
	jmp	$_250

$_249:	mov	r9, rdi
	mov	r8, rdi
	mov	edx, ebx
	lea	rcx, [DS0045+rip]
	call	AddLineQueueX@PLT
$_250:	jmp	$_259

$_251:	test	byte ptr [rsi+0x31], 0x08
	jz	$_254
	mov	r8, rdi
	lea	rdx, [DS0046+rip]
	lea	rcx, [rbp-0x40]
	call	tsprintf@PLT
	lea	rcx, [rbp-0x40]
	call	SymFind@PLT
	test	rax, rax
	jz	$_252
	mov	rcx, rax
	xor	eax, eax
	cmp	dword ptr [rcx+0x34], 0
	jge	$_252
	inc	eax
$_252:	mov	ecx, ebx
	lea	ebx, [rbx+0x92]
	cmp	ecx, 139
	jc	$_253
	lea	ebx, [rcx+0x20]
$_253:	test	eax, eax
	jz	$_254
	mov	r8d, ecx
	mov	edx, ebx
	lea	rcx, [DS0047+rip]
	call	AddLineQueueX@PLT
$_254:	test	byte ptr [r14+0x2], 0x01
	jz	$_257
	cmp	ebx, 174
	jz	$_255
	cmp	ebx, 142
	jnz	$_256
$_255:	lea	rdx, [DS0048+rip]
	mov	ecx, 2008
	call	asmerr@PLT
$_256:	lea	rax, [rbp-0x10]
	mov	qword ptr [rsp+0x28], rax
	mov	qword ptr [rsp+0x20], rdi
	mov	r9, rdi
	mov	r8d, ebx
	lea	rdx, [rbp-0x10]
	lea	rcx, [DS0049+rip]
	call	AddLineQueueX@PLT
	jmp	$_259

$_257:	mov	esi, 163
	cmp	ebx, esi
	jnz	$_258
	mov	esi, 165
$_258:	mov	dword ptr [rsp+0x50], esi
	lea	rax, [rbp-0x10]
	mov	qword ptr [rsp+0x48], rax
	mov	qword ptr [rsp+0x40], rdi
	mov	qword ptr [rsp+0x38], rdi
	mov	dword ptr [rsp+0x30], ebx
	mov	dword ptr [rsp+0x28], esi
	mov	dword ptr [rsp+0x20], esi
	lea	r9, [rbp-0x10]
	mov	r8d, esi
	mov	edx, esi
	lea	rcx, [DS004A+rip]
	call	AddLineQueueX@PLT
$_259:	leave
	pop	rbx
	pop	rdi
	pop	rsi
	ret

$_260:
	mov	qword ptr [rsp+0x8], rcx
	mov	qword ptr [rsp+0x10], rdx
	push	rsi
	push	rdi
	push	rbx
	push	rbp
	mov	rbp, rsp
	sub	rsp, 2216
	mov	dword ptr [rbp-0x870], 0
	imul	ebx, dword ptr [rbp+0x28], 32
	add	rbx, qword ptr [rbp+0x30]
	mov	eax, dword ptr [rbx+0x4]
	mov	dword ptr [rbp-0x86C], eax
	inc	dword ptr [rbp+0x28]
	add	rbx, 32
	mov	rsi, qword ptr [r14+0x2E8]
	test	rsi, rsi
	jnz	$_261
	mov	ecx, 56
	call	LclAlloc@PLT
	mov	rsi, rax
	jmp	$_262

$_261:	xor	eax, eax
	mov	ecx, 56
	mov	rdi, rsi
	rep stosb
$_262:	mov	rcx, qword ptr [rbp+0x30]
	call	ExpandCStrings@PLT
	lea	rdi, [rbp-0x800]
	mov	dword ptr [rsi+0x28], 4
	mov	dword ptr [rsi+0x30], 0
	or	byte ptr [rsi+0x30], 0x02
	mov	byte ptr [rbp-0x871], 0
$_263:	cmp	byte ptr [rbx], 40
	jnz	$_264
	inc	dword ptr [rbp+0x28]
	inc	byte ptr [rbp-0x871]
	add	rbx, 32
	jmp	$_263

$_264:
	cmp	dword ptr [rbx+0x4], 629
	jnz	$_265
	inc	dword ptr [rbp+0x28]
	add	rbx, 32
	or	byte ptr [rsi+0x30], 0x20
$_265:	cmp	byte ptr [rbx], 8
	jnz	$_266
	mov	rcx, qword ptr [rbx+0x10]
	mov	ecx, dword ptr [rcx]
	or	cl, 0x20
	cmp	cx, 99
	jnz	$_266
	mov	dword ptr [rbx+0x4], 343
	mov	byte ptr [rbx], 7
	mov	byte ptr [rbx+0x1], 1
$_266:	cmp	dword ptr [rbx+0x4], 343
	jnz	$_267
	inc	dword ptr [rbp+0x28]
	add	rbx, 32
	jmp	$_269

$_267:	cmp	dword ptr [rbx+0x4], 346
	jnz	$_268
	inc	dword ptr [rbp+0x28]
	add	rbx, 32
	or	byte ptr [rsi+0x32], 0x08
	jmp	$_269

$_268:	test	byte ptr [r14+0x1], 0x40
	jz	$_269
	or	byte ptr [rsi+0x32], 0x08
$_269:	cmp	byte ptr [rbx], 0
	je	$_291
	mov	r8, qword ptr [rbp+0x30]
	mov	edx, dword ptr [rbp+0x28]
	mov	rcx, rdi
	call	ExpandHllProc@PLT
	cmp	eax, -1
	jnz	$_270
	jmp	$_294

$_270:	cmp	byte ptr [rdi], 0
	jz	$_271
	mov	rcx, rdi
	call	AddLineQueue@PLT
$_271:	mov	eax, dword ptr [rbx+0x4]
	mov	dword ptr [rsi+0x2C], eax
	cmp	byte ptr [rbx], 2
	jne	$_278
	add	eax, eax
	mov	eax, dword ptr [r12+rax*8+0x4]
	and	eax, 0x7F
	cmp	eax, 2
	jnz	$_273
	or	byte ptr [rsi+0x31], 0x01
	cmp	byte ptr [r14+0x4], 0
	jnz	$_272
	or	byte ptr [rsi+0x30], 0x40
	test	byte ptr [rsi+0x30], 0x20
	jz	$_272
	or	byte ptr [rsi+0x32], 0x10
$_272:	jmp	$_277

$_273:	cmp	eax, 4
	jnz	$_276
	or	byte ptr [rsi+0x31], 0x02
	cmp	byte ptr [r14+0x4], 1
	jnz	$_274
	or	byte ptr [rsi+0x30], 0x40
	test	byte ptr [rsi+0x30], 0x20
	jz	$_274
	or	byte ptr [rsi+0x32], 0x10
	test	byte ptr [rsi+0x32], 0x08
	jnz	$_274
	or	byte ptr [rsi+0x32], 0x20
$_274:	cmp	byte ptr [r14+0x4], 2
	jnz	$_275
	or	byte ptr [rsi+0x31], 0x08
	test	byte ptr [rsi+0x30], 0x20
	jz	$_275
	or	byte ptr [rsi+0x30], 0x40
	or	byte ptr [rsi+0x32], 0x10
$_275:	jmp	$_277

$_276:	cmp	eax, 8
	jnz	$_277
	or	byte ptr [rsi+0x31], 0x04
	or	byte ptr [rsi+0x30], 0x40
	test	byte ptr [rsi+0x30], 0x20
	jz	$_277
	or	byte ptr [rsi+0x32], 0x10
$_277:	jmp	$_284

$_278:	mov	eax, dword ptr [rbp+0x28]
	mov	dword ptr [rbp-0x878], eax
	or	byte ptr [rsi+0x30], 0x80
	mov	byte ptr [rsp+0x20], 1
	lea	r9, [rbp-0x868]
	mov	r8d, dword ptr [r14+0x64]
	mov	rdx, qword ptr [rbp+0x30]
	lea	rcx, [rbp-0x878]
	call	EvalOperand@PLT
	cmp	eax, -1
	jz	$_284
	mov	eax, 8
	cmp	byte ptr [r14+0x4], 0
	jnz	$_279
	mov	eax, 2
	jmp	$_280

$_279:	cmp	byte ptr [r14+0x4], 1
	jnz	$_280
	mov	eax, 4
$_280:	cmp	dword ptr [rbp-0x82C], 1
	jnz	$_281
	cmp	byte ptr [rbp-0x824], 192
	jz	$_281
	mov	r8, qword ptr [rbp-0x808]
	movzx	edx, byte ptr [rbp-0x822]
	movzx	ecx, byte ptr [rbp-0x824]
	call	SizeFromMemtype@PLT
$_281:	cmp	eax, 2
	jnz	$_282
	or	byte ptr [rsi+0x31], 0x01
	jmp	$_284

$_282:	cmp	eax, 4
	jnz	$_283
	or	byte ptr [rsi+0x31], 0x02
	jmp	$_284

$_283:	cmp	eax, 8
	jnz	$_284
	or	byte ptr [rsi+0x31], 0x04
$_284:	imul	ecx, dword ptr [r14+0x64], 32
	add	rcx, qword ptr [rbp+0x30]
	jmp	$_286

$_285:	sub	rcx, 32
	dec	byte ptr [rbp-0x871]
$_286:	cmp	byte ptr [rbp-0x871], 0
	jz	$_287
	cmp	byte ptr [rcx-0x20], 41
	jz	$_285
$_287:	mov	rcx, qword ptr [rcx+0x18]
	jmp	$_289

$_288:	dec	rcx
$_289:	cmp	rcx, rdi
	jbe	$_290
	cmp	byte ptr [rcx-0x1], 32
	jbe	$_288
$_290:	sub	rcx, qword ptr [rbx+0x18]
	mov	edi, ecx
	inc	ecx
	call	LclAlloc@PLT
	mov	qword ptr [rsi+0x20], rax
	mov	r8d, edi
	mov	rdx, qword ptr [rbx+0x18]
	mov	rcx, rax
	call	tmemcpy@PLT
	mov	byte ptr [rax+rdi], 0
$_291:	imul	eax, dword ptr [rbp+0x28], 32
	cmp	dword ptr [rsi+0x30], 0
	jnz	$_292
	cmp	byte ptr [rbx+rax], 0
	jz	$_292
	cmp	dword ptr [rbp-0x870], 0
	jnz	$_292
	mov	rdx, qword ptr [rbx+rax+0x18]
	mov	ecx, 2008
	call	asmerr@PLT
	mov	dword ptr [rbp-0x870], eax
$_292:	cmp	rsi, qword ptr [r14+0x2E8]
	jnz	$_293
	mov	rax, qword ptr [rsi]
	mov	qword ptr [r14+0x2E8], rax
$_293:	mov	rax, qword ptr [r14+0x2E0]
	mov	qword ptr [rsi], rax
	mov	qword ptr [r14+0x2E0], rsi
	mov	eax, dword ptr [rbp-0x870]
$_294:	leave
	pop	rbx
	pop	rdi
	pop	rsi
	ret

$_295:
	mov	qword ptr [rsp+0x8], rcx
	mov	qword ptr [rsp+0x10], rdx
	push	rsi
	push	rdi
	push	rbx
	push	rbp
	mov	rbp, rsp
	sub	rsp, 2120
	mov	dword ptr [rbp-0x4], 0
	mov	rsi, qword ptr [r14+0x2E0]
	test	rsi, rsi
	jnz	$_296
	mov	ecx, 1011
	call	asmerr@PLT
	jmp	$_312

$_296:	mov	rax, qword ptr [rsi]
	mov	rcx, qword ptr [r14+0x2E8]
	mov	qword ptr [r14+0x2E0], rax
	mov	qword ptr [rsi], rcx
	mov	qword ptr [r14+0x2E8], rsi
	lea	rdi, [rbp-0x808]
	mov	rbx, qword ptr [rbp+0x30]
	mov	ecx, dword ptr [rsi+0x28]
	cmp	ecx, 4
	jz	$_297
	mov	ecx, 1011
	call	asmerr@PLT
	jmp	$_312

$_297:	inc	dword ptr [rbp+0x28]
	cmp	dword ptr [rsi+0x10], 0
	je	$_310
	cmp	dword ptr [rsi+0x18], 0
	jnz	$_298
	inc	dword ptr [r14+0x36C]
	mov	eax, dword ptr [r14+0x36C]
	mov	dword ptr [rsi+0x18], eax
$_298:	cmp	dword ptr [rsi+0x14], 0
	jnz	$_299
	inc	dword ptr [r14+0x36C]
	mov	eax, dword ptr [r14+0x36C]
	mov	dword ptr [rsi+0x14], eax
$_299:	lea	rdx, [rbp-0x818]
	mov	ecx, dword ptr [rsi+0x14]
	call	GetLabelStr@PLT
	mov	rdx, rdi
	mov	ecx, dword ptr [rsi+0x18]
	call	GetLabelStr@PLT
	mov	rax, rsi
	jmp	$_301

$_300:	mov	rax, qword ptr [rax+0x8]
$_301:	cmp	qword ptr [rax+0x8], 0
	jnz	$_300
	cmp	rax, rsi
	jz	$_302
	test	byte ptr [rax+0x31], 0x40
	jnz	$_302
	test	byte ptr [rsi+0x32], 0x20
	jnz	$_302
	mov	edx, dword ptr [rsi+0x14]
	lea	rcx, [DS0000+rip]
	call	AddLineQueueX@PLT
$_302:	mov	cl, byte ptr [r14+0x28]
	test	cl, cl
	jz	$_303
	mov	eax, 1
	shl	eax, cl
	mov	edx, eax
	lea	rcx, [DS004B+rip]
	call	AddLineQueueX@PLT
$_303:	cmp	qword ptr [rsi+0x20], 0
	jne	$_309
	mov	rbx, qword ptr [rsi+0x8]
	lea	r8, [DS0002+rip]
	mov	rdx, rdi
	lea	rcx, [DS0004+rip]
	call	AddLineQueueX@PLT
	jmp	$_308

$_304:	cmp	qword ptr [rbx+0x20], 0
	jnz	$_305
	mov	edx, dword ptr [rbx+0x18]
	lea	rcx, [DS0000+rip]
	call	AddLineQueueX@PLT
	jmp	$_307

$_305:	test	byte ptr [rbx+0x30], 0x04
	jz	$_306
	mov	dword ptr [rbp+0x28], 1
	or	byte ptr [rbx+0x30], 0x02
	mov	qword ptr [rsp+0x28], rdi
	mov	dword ptr [rsp+0x20], 1
	mov	r9d, 2
	mov	r8, qword ptr [rbp+0x30]
	lea	rdx, [rbp+0x28]
	mov	rcx, rbx
	call	ExpandHllExpression@PLT
	jmp	$_307

$_306:	mov	rcx, qword ptr [rbx+0x20]
	call	AddLineQueue@PLT
$_307:	mov	rbx, qword ptr [rbx+0x8]
$_308:	test	rbx, rbx
	jnz	$_304
	jmp	$_310

$_309:	lea	r9, [rbp-0x818]
	mov	r8, rdi
	mov	rdx, qword ptr [rbp+0x30]
	mov	rcx, rsi
	call	$_112
$_310:	mov	eax, dword ptr [rsi+0x14]
	test	eax, eax
	jz	$_311
	lea	r8, [DS0002+rip]
	mov	edx, eax
	lea	rcx, [DS0001+0x2F+rip]
	call	AddLineQueueX@PLT
$_311:	mov	eax, dword ptr [rbp-0x4]
$_312:	leave
	pop	rbx
	pop	rdi
	pop	rsi
	ret

$_313:
	mov	qword ptr [rsp+0x8], rcx
	mov	qword ptr [rsp+0x10], rdx
	push	rsi
	push	rdi
	push	rbx
	push	rbp
	mov	rbp, rsp
	sub	rsp, 2184
	mov	dword ptr [rbp-0x4], 0
	mov	rax, qword ptr [r14+0x2E0]
	mov	qword ptr [rbp-0x828], rax
	mov	rsi, rax
	test	rsi, rsi
	jnz	$_314
	mov	ecx, 1011
	call	asmerr@PLT
	jmp	$_385

$_314:	mov	rcx, qword ptr [rbp+0x30]
	call	ExpandCStrings@PLT
	imul	ebx, dword ptr [rbp+0x28], 32
	add	rbx, qword ptr [rbp+0x30]
	lea	rdi, [rbp-0x818]
	mov	eax, dword ptr [rbx+0x4]
	mov	dword ptr [rbp-0x8], eax
	xor	ecx, ecx
	cmp	eax, 511
	jnz	$_315
	cmp	byte ptr [rbx+0x20], 40
	jnz	$_315
	cmp	byte ptr [rbx+0x60], 41
	jnz	$_315
	mov	rdx, qword ptr [rbx+0x50]
	mov	dl, byte ptr [rdx]
	cmp	dl, 48
	jc	$_315
	cmp	dl, 57
	ja	$_315
	sub	dl, 48
	mov	cl, dl
	add	dword ptr [rbp+0x28], 3
	add	rbx, 96
$_315:	jmp	$_382

$_316:	test	byte ptr [rsi+0x30], 0x01
	jz	$_317
	mov	ecx, 2142
	call	asmerr@PLT
	jmp	$_385

$_317:	cmp	byte ptr [rbx+0x20], 0
	jz	$_318
	mov	rdx, qword ptr [rbx+0x18]
	mov	ecx, 2008
	call	asmerr@PLT
	jmp	$_385

$_318:	or	byte ptr [rsi+0x30], 0x01
$_319:	jmp	$_321

$_320:	mov	rsi, qword ptr [rsi]
$_321:	test	rsi, rsi
	jz	$_322
	cmp	dword ptr [rsi+0x28], 4
	jnz	$_320
$_322:	cmp	dword ptr [rsi+0x28], 4
	jz	$_323
	mov	rdx, qword ptr [rbx+0x10]
	mov	ecx, 1010
	call	asmerr@PLT
	jmp	$_385

$_323:	cmp	dword ptr [rsi+0x18], 0
	jnz	$_326
	inc	dword ptr [r14+0x36C]
	mov	eax, dword ptr [r14+0x36C]
	mov	dword ptr [rsi+0x18], eax
	test	byte ptr [rsi+0x30], 0x20
	jz	$_324
	test	byte ptr [rsi+0x32], 0x10
	jz	$_324
	mov	rcx, rsi
	call	$_241
	jmp	$_325

$_324:	mov	edx, eax
	lea	rcx, [DS0000+rip]
	call	AddLineQueueX@PLT
$_325:	jmp	$_330

$_326:	test	byte ptr [rsi+0x32], 0x08
	jz	$_330
	cmp	dword ptr [rsi+0x14], 0
	jnz	$_327
	inc	dword ptr [r14+0x36C]
	mov	eax, dword ptr [r14+0x36C]
	mov	dword ptr [rsi+0x14], eax
$_327:	mov	rax, rsi
	jmp	$_329

$_328:	mov	rax, qword ptr [rax+0x8]
$_329:	cmp	qword ptr [rax+0x8], 0
	jnz	$_328
	cmp	rax, rsi
	jz	$_330
	test	byte ptr [rax+0x31], 0x40
	jnz	$_330
	mov	edx, dword ptr [rsi+0x14]
	lea	rcx, [DS0000+rip]
	call	AddLineQueueX@PLT
$_330:	mov	qword ptr [rbp-0x830], 0
	cmp	byte ptr [rbx+0x20], 9
	jnz	$_331
	cmp	byte ptr [rbx+0x40], 8
	jnz	$_331
	cmp	byte ptr [rbx+0x60], 9
	jnz	$_331
	mov	rax, qword ptr [rbx+0x50]
	mov	qword ptr [rbp-0x830], rax
	add	rbx, 96
	add	dword ptr [rbp+0x28], 3
$_331:	mov	r9, rbx
	mov	r8, rdi
	lea	rdx, [rbp+0x28]
	mov	rcx, rsi
	call	$_065
	test	rax, rax
	jne	$_383
	mov	cl, byte ptr [r14+0x28]
	test	cl, cl
	jz	$_332
	mov	eax, 1
	shl	eax, cl
	mov	edx, eax
	lea	rcx, [DS004B+rip]
	call	AddLineQueueX@PLT
$_332:	inc	dword ptr [rsi+0x10]
	inc	dword ptr [r14+0x36C]
	mov	eax, dword ptr [r14+0x36C]
	mov	dword ptr [rbp-0x834], eax
	lea	r8, [DS0002+rip]
	mov	edx, eax
	lea	rcx, [DS0001+0x2F+rip]
	call	AddLineQueueX@PLT
	cmp	qword ptr [rbp-0x830], 0
	jz	$_333
	mov	rdx, qword ptr [rbp-0x830]
	lea	rcx, [DS004C+rip]
	call	AddLineQueueX@PLT
$_333:	mov	ecx, 56
	call	LclAlloc@PLT
	mov	ecx, dword ptr [rbp-0x834]
	mov	rdx, rsi
	mov	rsi, rax
	mov	rax, qword ptr [rdx+0x20]
	mov	dword ptr [rsi+0x18], ecx
	jmp	$_335

$_334:	mov	rdx, qword ptr [rdx+0x8]
$_335:	cmp	qword ptr [rdx+0x8], 0
	jnz	$_334
	mov	qword ptr [rdx+0x8], rsi
	inc	dword ptr [rbp+0x28]
	add	rbx, 32
	mov	qword ptr [rbp-0x840], rax
	mov	qword ptr [rbp-0x848], rbx
	mov	qword ptr [rbp-0x850], rsi
	xor	esi, esi
$_336:	mov	rcx, rbx
	call	$_055
	test	rax, rax
	jz	$_339
	mov	rbx, rax
	test	rsi, rsi
	jz	$_337
	mov	rax, qword ptr [rbx+0x18]
	mov	byte ptr [rax], 0
	mov	rcx, rsi
	call	AddLineQueue@PLT
	mov	rax, qword ptr [rbx+0x18]
	mov	byte ptr [rax], 58
	jmp	$_338

$_337:	sub	rax, qword ptr [rbp+0x30]
	mov	ecx, 32
	xor	edx, edx
	div	ecx
	mov	dword ptr [r14+0x64], eax
$_338:	add	rbx, 32
	mov	rsi, qword ptr [rbx+0x18]
	jmp	$_336

$_339:	test	rsi, rsi
	jz	$_340
	mov	rcx, rsi
	call	AddLineQueue@PLT
$_340:	mov	rsi, qword ptr [rbp-0x850]
	cmp	qword ptr [rbp-0x840], 0
	je	$_351
	cmp	dword ptr [rbp-0x8], 513
	je	$_351
	mov	rbx, qword ptr [rbp-0x848]
	mov	qword ptr [rbp-0x850], rdi
	xor	edi, edi
$_341:	movzx	eax, byte ptr [rbx]
	jmp	$_348

	cmp	edi, 1
	jnz	$_342
	cmp	byte ptr [rbx+0x20], 0
	jnz	$_342
	or	byte ptr [rsi+0x31], 0x10
	jmp	$_350

$_342:	sub	edi, 2
	inc	edi
	jmp	$_349

$_343:	cmp	byte ptr [rbx+0x20], 0
	jnz	$_344
	or	byte ptr [rsi+0x31], 0x10
	jmp	$_350

$_344:	jmp	$_349

	cmp	dword ptr [rbx+0x24], 335
	jz	$_350
	jmp	$_343

	cmp	byte ptr [rbx+0x20], 46
	jz	$_350
	jmp	$_343

	cmp	dword ptr [rbx+0x4], 313
	jnz	$_350
	jmp	$_343

	mov	rcx, rbx
	call	SymFindID@PLT
	test	rax, rax
	jz	$_346
	cmp	byte ptr [rax+0x1D], 1
	jnz	$_350
	cmp	byte ptr [rax+0x1E], 129
	jz	$_345
	cmp	byte ptr [rax+0x1E], 192
	jnz	$_350
$_345:	jmp	$_347

$_346:	cmp	dword ptr [Parse_Pass+rip], 0
	jz	$_347
	jmp	$_350

$_347:	jmp	$_343

LC01B0: jmp	$_350

$_348:	cmp	eax, 1
	jl	LC01B0
	cmp	eax, 47
	jg	LC01B0
	lea	r11, [LC01B1+rip]
	movzx	r10, byte ptr [r11+rax+0x8]
	movzx	r10, byte ptr [r11+r10]
	lea	r11, [LC01B0+rip]
	sub	r11, r10
	jmp	r11

$_349:	add	rbx, 32
	jmp	$_341

$_350:	mov	rdi, qword ptr [rbp-0x850]
$_351:	mov	rax, qword ptr [rbp-0x840]
	mov	rbx, qword ptr [rbp-0x848]
	cmp	dword ptr [rbp-0x8], 513
	jnz	$_352
	or	byte ptr [rsi+0x30], 0x08
	jmp	$_356

$_352:	cmp	byte ptr [rbx], 0
	jnz	$_353
	mov	rdx, qword ptr [rbx-0x8]
	mov	ecx, 2008
	call	asmerr@PLT
	jmp	$_385

$_353:	test	eax, eax
	jnz	$_354
	mov	ebx, dword ptr [rbp+0x28]
	mov	qword ptr [rsp+0x28], rdi
	mov	dword ptr [rsp+0x20], 1
	mov	r9d, 2
	mov	r8, qword ptr [rbp+0x30]
	lea	rdx, [rbp+0x28]
	mov	rcx, rsi
	call	EvaluateHllExpression@PLT
	mov	dword ptr [rbp+0x28], ebx
	mov	dword ptr [rbp-0x4], eax
	cmp	eax, -1
	je	$_383
	jmp	$_355

$_354:	imul	eax, dword ptr [r14+0x64], 32
	add	rax, qword ptr [rbp+0x30]
	mov	rax, qword ptr [rax+0x18]
	sub	rax, qword ptr [rbx+0x18]
	mov	word ptr [rdi+rax], 0
	mov	r8d, eax
	mov	rdx, qword ptr [rbx+0x18]
	mov	rcx, rdi
	call	tmemcpy@PLT
$_355:	mov	rcx, rdi
	call	LclDup@PLT
	mov	qword ptr [rsi+0x20], rax
$_356:	mov	eax, dword ptr [r14+0x64]
	mov	dword ptr [rbp+0x28], eax
	jmp	$_383

$_357:	test	rsi, rsi
	jz	$_358
	cmp	dword ptr [rsi+0x28], 4
	jz	$_358
	mov	rsi, qword ptr [rsi]
	jmp	$_357

$_358:	test	rsi, rsi
	jz	$_361
	test	ecx, ecx
	jz	$_361
	mov	rsi, qword ptr [rsi]
$_359:	test	rsi, rsi
	jz	$_360
	cmp	dword ptr [rsi+0x28], 4
	jz	$_360
	mov	rsi, qword ptr [rsi]
	jmp	$_359

$_360:	dec	ecx
	jmp	$_358

$_361:	test	rsi, rsi
	jnz	$_362
	mov	ecx, 1011
	call	asmerr@PLT
	jmp	$_385

$_362:	cmp	dword ptr [rsi+0x14], 0
	jnz	$_363
	inc	dword ptr [r14+0x36C]
	mov	eax, dword ptr [r14+0x36C]
	mov	dword ptr [rsi+0x14], eax
$_363:	mov	ecx, 1
	cmp	dword ptr [rbp-0x8], 511
	jz	$_364
	mov	ecx, 2
$_364:	inc	dword ptr [rbp+0x28]
	add	rbx, 32
	mov	dword ptr [rbp-0x81C], 0
	cmp	ecx, 2
	jne	$_377
	cmp	byte ptr [rbx], 40
	jne	$_377
	cmp	byte ptr [rbx+0x20], 0
	jz	$_365
	cmp	byte ptr [rbx+0x40], 58
	jnz	$_365
	add	dword ptr [rbp+0x28], 2
	add	rbx, 64
$_365:	mov	rax, qword ptr [rbx+0x38]
	inc	dword ptr [rbp+0x28]
	add	rbx, 32
	mov	ecx, 1
$_366:	cmp	byte ptr [rbx], 0
	jz	$_369
	cmp	byte ptr [rbx], 40
	jnz	$_367
	inc	ecx
	jmp	$_368

$_367:	cmp	byte ptr [rbx], 41
	jnz	$_368
	dec	ecx
	jz	$_369
$_368:	inc	dword ptr [rbp+0x28]
	add	rbx, 32
	jmp	$_366

$_369:	cmp	byte ptr [rbx], 41
	jne	$_383
	inc	dword ptr [rbp+0x28]
	add	rbx, 32
	cmp	byte ptr [rbx-0x40], 40
	je	$_376
	cmp	byte ptr [rbx-0x40], 58
	je	$_376
	mov	rcx, qword ptr [rbx-0x8]
	sub	rcx, rax
	je	$_376
	cmp	ecx, 2016
	ja	$_383
	mov	qword ptr [rbp-0x850], rsi
	mov	qword ptr [rbp-0x840], rcx
	mov	r8d, ecx
	mov	rdx, rax
	mov	rcx, rdi
	call	tmemcpy@PLT
	mov	rcx, qword ptr [rbp-0x840]
	add	rcx, rax
	mov	byte ptr [rcx], 0
	dec	rcx
$_370:	cmp	rcx, rax
	jbe	$_371
	cmp	byte ptr [rcx], 32
	ja	$_371
	mov	byte ptr [rcx], 0
	dec	rcx
	jmp	$_370

$_371:	mov	rsi, qword ptr [rsi+0x8]
$_372:	test	rsi, rsi
	jz	$_374
	cmp	qword ptr [rsi+0x20], 0
	jz	$_373
	mov	rdx, qword ptr [rsi+0x20]
	mov	rcx, rdi
	call	tstrcmp@PLT
	test	eax, eax
	jnz	$_373
	mov	ecx, dword ptr [rsi+0x18]
	jmp	$_374

$_373:	mov	rsi, qword ptr [rsi+0x8]
	jmp	$_372

$_374:	mov	rax, rsi
	mov	rsi, qword ptr [rbp-0x850]
	test	rax, rax
	jz	$_375
	mov	edx, dword ptr [rsi+0x18]
	mov	dword ptr [rsi+0x18], ecx
	mov	dword ptr [rbp-0x81C], edx
	jmp	$_376

$_375:	cmp	qword ptr [rsi+0x20], 0
	jz	$_376
	mov	r8, rdi
	mov	rdx, qword ptr [rsi+0x20]
	lea	rcx, [DS004D+rip]
	call	AddLineQueueX@PLT
	mov	eax, dword ptr [rsi+0x1C]
	test	eax, eax
	jz	$_376
	mov	edx, dword ptr [rsi+0x18]
	mov	dword ptr [rsi+0x18], eax
	mov	dword ptr [rbp-0x81C], edx
$_376:	mov	ecx, 2
	jmp	$_378

$_377:	cmp	ecx, 2
	jnz	$_378
	cmp	dword ptr [rsi+0x1C], 0
	jz	$_378
	mov	eax, dword ptr [rsi+0x1C]
	mov	edx, dword ptr [rsi+0x18]
	mov	dword ptr [rsi+0x18], eax
	mov	dword ptr [rbp-0x81C], edx
$_378:	mov	dword ptr [rsp+0x28], 1
	mov	rax, qword ptr [rbp-0x828]
	mov	qword ptr [rsp+0x20], rax
	mov	r9d, ecx
	mov	r8, qword ptr [rbp+0x30]
	lea	rdx, [rbp+0x28]
	mov	rcx, rsi
	call	HllContinueIf@PLT
	cmp	dword ptr [rbp-0x81C], 0
	jz	$_379
	mov	eax, dword ptr [rbp-0x81C]
	mov	dword ptr [rsi+0x18], eax
$_379:	jmp	$_383

$_380:	cmp	byte ptr [rbx+0x20], 40
	jnz	$_381
	cmp	byte ptr [rbx+0x60], 58
	jnz	$_381
	mov	rax, qword ptr [rbx+0x50]
	mov	al, byte ptr [rax]
	cmp	al, 48
	jc	$_381
	cmp	al, 57
	ja	$_381
	sub	al, 48
	movzx	ecx, al
$_381:	jmp	$_357

$_382:	cmp	eax, 513
	je	$_316
	cmp	eax, 510
	je	$_319
	cmp	eax, 511
	je	$_357
	cmp	eax, 512
	jz	$_380
$_383:	imul	ebx, dword ptr [rbp+0x28], 32
	add	rbx, qword ptr [rbp+0x30]
	cmp	byte ptr [rbx], 0
	jz	$_384
	cmp	dword ptr [rbp-0x4], 0
	jnz	$_384
	mov	rdx, qword ptr [rbx+0x18]
	mov	ecx, 2008
	call	asmerr@PLT
	mov	dword ptr [rbp-0x4], -1
$_384:	mov	eax, dword ptr [rbp-0x4]
$_385:	leave
	pop	rbx
	pop	rdi
	pop	rsi
	ret

SwitchDirective:
	mov	qword ptr [rsp+0x8], rcx
	mov	qword ptr [rsp+0x10], rdx
	push	rbp
	mov	rbp, rsp
	sub	rsp, 48
	mov	dword ptr [rbp-0x4], 0
	imul	eax, dword ptr [rbp+0x10], 32
	add	rax, qword ptr [rbp+0x18]
	mov	eax, dword ptr [rax+0x4]
	jmp	$_389

$_386:	mov	rdx, qword ptr [rbp+0x18]
	mov	ecx, dword ptr [rbp+0x10]
	call	$_313
	mov	dword ptr [rbp-0x4], eax
	jmp	$_390

$_387:	mov	rdx, qword ptr [rbp+0x18]
	mov	ecx, dword ptr [rbp+0x10]
	call	$_295
	mov	dword ptr [rbp-0x4], eax
	jmp	$_390

$_388:	mov	rdx, qword ptr [rbp+0x18]
	mov	ecx, dword ptr [rbp+0x10]
	call	$_260
	mov	dword ptr [rbp-0x4], eax
	jmp	$_390

$_389:	cmp	eax, 510
	jz	$_386
	cmp	eax, 512
	jz	$_386
	cmp	eax, 513
	jz	$_386
	cmp	eax, 511
	jz	$_386
	cmp	eax, 514
	jz	$_387
	cmp	eax, 509
	jz	$_388
$_390:	test	byte ptr [r14], 0x08
	jz	$_391
	call	GetCurrOffset@PLT
	xor	r8d, r8d
	mov	edx, eax
	mov	ecx, 4
	call	LstWrite@PLT
$_391:	cmp	qword ptr [r14+0x2B0], 0
	jz	$_392
	call	RunLineQueue@PLT
$_392:	mov	eax, dword ptr [rbp-0x4]
	leave
	ret


.SECTION .data
	.ALIGN	16

DS0000:
	.byte  0x20, 0x6A, 0x6D, 0x70, 0x20, 0x40, 0x43, 0x25
	.byte  0x30, 0x34, 0x58, 0x00

DS0001:
	.byte  0x20, 0x63, 0x6D, 0x70, 0x20, 0x25, 0x73, 0x2C
	.byte  0x20, 0x25, 0x73, 0x0A, 0x20, 0x6A, 0x62, 0x20
	.byte  0x40, 0x43, 0x25, 0x30, 0x34, 0x58, 0x0A, 0x20
	.byte  0x63, 0x6D, 0x70, 0x20, 0x25, 0x73, 0x2C, 0x20
	.byte  0x25, 0x73, 0x0A, 0x20, 0x6A, 0x62, 0x65, 0x20
	.byte  0x40, 0x43, 0x25, 0x30, 0x34, 0x58, 0x0A, 0x40
	.byte  0x43, 0x25, 0x30, 0x34, 0x58, 0x25, 0x73, 0x00

DS0002:
	.byte  0x3A, 0x00

DS0003:
	.byte  0x20, 0x63, 0x6D, 0x70, 0x20, 0x25, 0x73, 0x2C
	.byte  0x20, 0x25, 0x73, 0x0A, 0x20, 0x6A, 0x65, 0x20
	.byte  0x40, 0x43, 0x25, 0x30, 0x34, 0x58, 0x00

DS0004:
	.byte  0x25, 0x73, 0x25, 0x73, 0x00

DS0005:
	.byte  0x20, 0x2E, 0x63, 0x61, 0x73, 0x65, 0x20, 0x25
	.byte  0x73, 0x00

DS0006:
	.byte  0x63, 0x6D, 0x70, 0x20, 0x25, 0x73, 0x2C, 0x20
	.byte  0x25, 0x64, 0x0A, 0x6A, 0x61, 0x20, 0x20, 0x25
	.byte  0x73, 0x00

DS0007:
	.byte  0x63, 0x6D, 0x70, 0x20, 0x25, 0x73, 0x2C, 0x20
	.byte  0x25, 0x64, 0x0A, 0x6A, 0x6C, 0x20, 0x20, 0x25
	.byte  0x73, 0x0A, 0x63, 0x6D, 0x70, 0x20, 0x25, 0x73
	.byte  0x2C, 0x20, 0x25, 0x64, 0x0A, 0x6A, 0x67, 0x20
	.byte  0x20, 0x25, 0x73, 0x00

DS0008:
	.byte  0x25, 0x72, 0x20, 0x25, 0x72, 0x00

DS0009:
	.byte  0x61, 0x6C, 0x00

DS000A:
	.byte  0x20, 0x25, 0x72, 0x20, 0x25, 0x72, 0x2C, 0x20
	.byte  0x25, 0x73, 0x00

DS000B:
	.byte  0x20, 0x25, 0x72, 0x20, 0x25, 0x72, 0x2C, 0x20
	.byte  0x25, 0x72, 0x20, 0x70, 0x74, 0x72, 0x20, 0x25
	.byte  0x73, 0x00

DS000C:
	.byte  0x20, 0x25, 0x72, 0x20, 0x72, 0x31, 0x30, 0x2C
	.byte  0x20, 0x25, 0x72, 0x20, 0x70, 0x74, 0x72, 0x20
	.byte  0x5B, 0x72, 0x31, 0x31, 0x2B, 0x25, 0x72, 0x2A
	.byte  0x25, 0x64, 0x2D, 0x28, 0x25, 0x64, 0x2A, 0x25
	.byte  0x64, 0x29, 0x5D, 0x00

DS000D:
	.byte  0x20, 0x25, 0x72, 0x20, 0x72, 0x31, 0x30, 0x2C
	.byte  0x20, 0x25, 0x72, 0x20, 0x70, 0x74, 0x72, 0x20
	.byte  0x5B, 0x72, 0x31, 0x31, 0x2B, 0x25, 0x72, 0x2A
	.byte  0x25, 0x64, 0x2D, 0x28, 0x25, 0x64, 0x2A, 0x25
	.byte  0x64, 0x29, 0x2B, 0x28, 0x25, 0x73, 0x2D, 0x25
	.byte  0x73, 0x29, 0x5D, 0x00

DS000E:
	.byte  0x20, 0x25, 0x72, 0x20, 0x25, 0x64, 0x00

DS000F:
	.byte  0x20, 0x25, 0x72, 0x20, 0x25, 0x72, 0x00

DS0010:
	.byte  0x4D, 0x49, 0x4E, 0x25, 0x73, 0x20, 0x65, 0x71
	.byte  0x75, 0x20, 0x25, 0x64, 0x00

DS0011:
	.byte  0x2E, 0x64, 0x61, 0x74, 0x61, 0x0A, 0x41, 0x4C
	.byte  0x49, 0x47, 0x4E, 0x20, 0x34, 0x0A, 0x54, 0x24
	.byte  0x25, 0x73, 0x20, 0x6C, 0x61, 0x62, 0x65, 0x6C
	.byte  0x20, 0x64, 0x77, 0x6F, 0x72, 0x64, 0x00

DS0012:
	.byte  0x20, 0x70, 0x75, 0x73, 0x68, 0x20, 0x61, 0x78
	.byte  0x00

DS0013:
	.byte  0x20, 0x6D, 0x6F, 0x76, 0x20, 0x61, 0x78, 0x2C
	.byte  0x20, 0x25, 0x73, 0x00

DS0014:
	.byte  0x20, 0x78, 0x63, 0x68, 0x67, 0x20, 0x61, 0x78
	.byte  0x2C, 0x20, 0x62, 0x78, 0x00

DS0015:
	.byte  0x20, 0x70, 0x75, 0x73, 0x68, 0x20, 0x62, 0x78
	.byte  0x0A, 0x20, 0x70, 0x75, 0x73, 0x68, 0x20, 0x61
	.byte  0x78, 0x00

DS0016:
	.byte  0x20, 0x6D, 0x6F, 0x76, 0x20, 0x62, 0x78, 0x2C
	.byte  0x20, 0x25, 0x73, 0x00

DS0017:
	.byte  0x20, 0x70, 0x75, 0x73, 0x68, 0x20, 0x62, 0x78
	.byte  0x00

DS0018:
	.byte  0x20, 0x6D, 0x6F, 0x76, 0x20, 0x62, 0x78, 0x2C
	.byte  0x20, 0x61, 0x78, 0x00

DS0019:
	.byte  0x20, 0x73, 0x75, 0x62, 0x20, 0x62, 0x78, 0x2C
	.byte  0x20, 0x25, 0x64, 0x00

DS001A:
	.byte  0x20, 0x61, 0x64, 0x64, 0x20, 0x62, 0x78, 0x2C
	.byte  0x20, 0x62, 0x78, 0x00

DS001B:
	.byte  0x20, 0x6D, 0x6F, 0x76, 0x20, 0x62, 0x78, 0x2C
	.byte  0x20, 0x63, 0x73, 0x3A, 0x5B, 0x62, 0x78, 0x2B
	.byte  0x25, 0x73, 0x5D, 0x0A, 0x20, 0x78, 0x63, 0x68
	.byte  0x67, 0x20, 0x61, 0x78, 0x2C, 0x20, 0x62, 0x78
	.byte  0x0A, 0x20, 0x6A, 0x6D, 0x70, 0x20, 0x61, 0x78
	.byte  0x00

DS001C:
	.byte  0x20, 0x6D, 0x6F, 0x76, 0x20, 0x61, 0x78, 0x2C
	.byte  0x20, 0x63, 0x73, 0x3A, 0x5B, 0x62, 0x78, 0x2B
	.byte  0x25, 0x73, 0x5D, 0x0A, 0x20, 0x6D, 0x6F, 0x76
	.byte  0x20, 0x62, 0x78, 0x2C, 0x20, 0x73, 0x70, 0x0A
	.byte  0x20, 0x6D, 0x6F, 0x76, 0x20, 0x73, 0x73, 0x3A
	.byte  0x5B, 0x62, 0x78, 0x2B, 0x34, 0x5D, 0x2C, 0x20
	.byte  0x61, 0x78, 0x0A, 0x20, 0x70, 0x6F, 0x70, 0x20
	.byte  0x61, 0x78, 0x0A, 0x20, 0x70, 0x6F, 0x70, 0x20
	.byte  0x62, 0x78, 0x0A, 0x20, 0x72, 0x65, 0x74, 0x6E
	.byte  0x00

DS001D:
	.byte  0x20, 0x6D, 0x6F, 0x76, 0x7A, 0x78, 0x20, 0x65
	.byte  0x61, 0x78, 0x2C, 0x20, 0x62, 0x79, 0x74, 0x65
	.byte  0x20, 0x70, 0x74, 0x72, 0x20, 0x5B, 0x65, 0x61
	.byte  0x78, 0x2B, 0x49, 0x24, 0x25, 0x73, 0x2D, 0x28
	.byte  0x25, 0x64, 0x29, 0x5D, 0x00

DS001E:
	.byte  0x20, 0x6D, 0x6F, 0x76, 0x7A, 0x78, 0x20, 0x65
	.byte  0x61, 0x78, 0x2C, 0x20, 0x77, 0x6F, 0x72, 0x64
	.byte  0x20, 0x70, 0x74, 0x72, 0x20, 0x5B, 0x65, 0x61
	.byte  0x78, 0x2A, 0x32, 0x2B, 0x49, 0x24, 0x25, 0x73
	.byte  0x2D, 0x28, 0x25, 0x64, 0x2A, 0x32, 0x29, 0x5D
	.byte  0x00

DS001F:
	.byte  0x20, 0x6A, 0x6D, 0x70, 0x20, 0x5B, 0x65, 0x61
	.byte  0x78, 0x2A, 0x34, 0x2B, 0x25, 0x73, 0x5D, 0x00

DS0020:
	.byte  0x20, 0x6D, 0x6F, 0x76, 0x20, 0x65, 0x61, 0x78
	.byte  0x2C, 0x20, 0x5B, 0x65, 0x61, 0x78, 0x2A, 0x34
	.byte  0x2B, 0x25, 0x73, 0x5D, 0x00

DS0021:
	.byte  0x20, 0x6A, 0x6D, 0x70, 0x20, 0x5B, 0x65, 0x61
	.byte  0x78, 0x2A, 0x34, 0x2B, 0x25, 0x73, 0x2D, 0x28
	.byte  0x25, 0x64, 0x2A, 0x34, 0x29, 0x5D, 0x00

DS0022:
	.byte  0x20, 0x6D, 0x6F, 0x76, 0x20, 0x65, 0x61, 0x78
	.byte  0x2C, 0x20, 0x5B, 0x65, 0x61, 0x78, 0x2A, 0x34
	.byte  0x2B, 0x25, 0x73, 0x2D, 0x28, 0x25, 0x64, 0x2A
	.byte  0x34, 0x29, 0x5D, 0x00

DS0023:
	.byte  0x20, 0x78, 0x63, 0x68, 0x67, 0x20, 0x65, 0x61
	.byte  0x78, 0x2C, 0x20, 0x5B, 0x65, 0x73, 0x70, 0x5D
	.byte  0x0A, 0x20, 0x72, 0x65, 0x74, 0x6E, 0x00

DS0024:
	.byte  0x20, 0x70, 0x75, 0x73, 0x68, 0x20, 0x25, 0x73
	.byte  0x00

DS0025:
	.byte  0x20, 0x6D, 0x6F, 0x76, 0x7A, 0x78, 0x20, 0x25
	.byte  0x73, 0x2C, 0x20, 0x62, 0x79, 0x74, 0x65, 0x20
	.byte  0x70, 0x74, 0x72, 0x20, 0x5B, 0x25, 0x73, 0x2B
	.byte  0x49, 0x24, 0x25, 0x73, 0x2D, 0x28, 0x25, 0x64
	.byte  0x29, 0x5D, 0x00

DS0026:
	.byte  0x20, 0x6D, 0x6F, 0x76, 0x7A, 0x78, 0x20, 0x25
	.byte  0x73, 0x2C, 0x20, 0x77, 0x6F, 0x72, 0x64, 0x20
	.byte  0x70, 0x74, 0x72, 0x20, 0x5B, 0x25, 0x73, 0x2A
	.byte  0x32, 0x2B, 0x49, 0x24, 0x25, 0x73, 0x2D, 0x28
	.byte  0x25, 0x64, 0x2A, 0x32, 0x29, 0x5D, 0x00

DS0027:
	.byte  0x20, 0x6A, 0x6D, 0x70, 0x20, 0x5B, 0x25, 0x73
	.byte  0x2A, 0x34, 0x2B, 0x25, 0x73, 0x5D, 0x00

DS0028:
	.byte  0x20, 0x6D, 0x6F, 0x76, 0x20, 0x25, 0x73, 0x2C
	.byte  0x20, 0x5B, 0x25, 0x73, 0x2A, 0x34, 0x2B, 0x25
	.byte  0x73, 0x5D, 0x0A, 0x20, 0x78, 0x63, 0x68, 0x67
	.byte  0x20, 0x25, 0x73, 0x2C, 0x20, 0x5B, 0x65, 0x73
	.byte  0x70, 0x5D, 0x0A, 0x20, 0x72, 0x65, 0x74, 0x6E
	.byte  0x00

DS0029:
	.byte  0x20, 0x6A, 0x6D, 0x70, 0x20, 0x5B, 0x25, 0x73
	.byte  0x2A, 0x34, 0x2B, 0x25, 0x73, 0x2D, 0x28, 0x25
	.byte  0x64, 0x2A, 0x34, 0x29, 0x5D, 0x00

DS002A:
	.byte  0x72, 0x65, 0x67, 0x69, 0x73, 0x74, 0x65, 0x72
	.byte  0x20, 0x72, 0x31, 0x30, 0x2F, 0x72, 0x31, 0x31
	.byte  0x20, 0x6F, 0x76, 0x65, 0x72, 0x77, 0x72, 0x69
	.byte  0x74, 0x74, 0x65, 0x6E, 0x20, 0x62, 0x79, 0x20
	.byte  0x2E, 0x53, 0x57, 0x49, 0x54, 0x43, 0x48, 0x00

DS002B:
	.byte  0x20, 0x6D, 0x6F, 0x76, 0x73, 0x78, 0x64, 0x20
	.byte  0x72, 0x31, 0x30, 0x2C, 0x20, 0x25, 0x72, 0x00

DS002C:
	.byte  0x20, 0x6C, 0x65, 0x61, 0x20, 0x72, 0x31, 0x31
	.byte  0x2C, 0x20, 0x25, 0x73, 0x00

DS002D:
	.byte  0x20, 0x73, 0x75, 0x62, 0x20, 0x72, 0x31, 0x31
	.byte  0x2C, 0x20, 0x72, 0x31, 0x30, 0x0A, 0x20, 0x6A
	.byte  0x6D, 0x70, 0x20, 0x72, 0x31, 0x31, 0x00

DS002E:
	.byte  0x20, 0x6D, 0x6F, 0x76, 0x7A, 0x78, 0x20, 0x72
	.byte  0x31, 0x30, 0x2C, 0x20, 0x25, 0x72, 0x20, 0x70
	.byte  0x74, 0x72, 0x20, 0x5B, 0x72, 0x31, 0x31, 0x2B
	.byte  0x25, 0x72, 0x2A, 0x25, 0x72, 0x2D, 0x28, 0x25
	.byte  0x64, 0x2A, 0x25, 0x72, 0x29, 0x2B, 0x28, 0x49
	.byte  0x24, 0x25, 0x73, 0x2D, 0x25, 0x73, 0x29, 0x5D
	.byte  0x00

DS002F:
	.byte  0x20, 0x70, 0x75, 0x73, 0x68, 0x20, 0x72, 0x61
	.byte  0x78, 0x00

DS0030:
	.byte  0x20, 0x6D, 0x6F, 0x76, 0x73, 0x78, 0x64, 0x20
	.byte  0x72, 0x61, 0x78, 0x2C, 0x20, 0x25, 0x72, 0x00

DS0031:
	.byte  0x20, 0x70, 0x75, 0x73, 0x68, 0x20, 0x72, 0x31
	.byte  0x31, 0x0A, 0x20, 0x6C, 0x65, 0x61, 0x20, 0x72
	.byte  0x31, 0x31, 0x2C, 0x20, 0x25, 0x73, 0x00

DS0032:
	.byte  0x20, 0x6D, 0x6F, 0x76, 0x7A, 0x78, 0x20, 0x65
	.byte  0x61, 0x78, 0x2C, 0x20, 0x62, 0x79, 0x74, 0x65
	.byte  0x20, 0x70, 0x74, 0x72, 0x20, 0x5B, 0x72, 0x31
	.byte  0x31, 0x2B, 0x25, 0x72, 0x2D, 0x28, 0x25, 0x64
	.byte  0x29, 0x2B, 0x28, 0x49, 0x24, 0x25, 0x73, 0x2D
	.byte  0x25, 0x73, 0x29, 0x5D, 0x00

DS0033:
	.byte  0x20, 0x6D, 0x6F, 0x76, 0x7A, 0x78, 0x20, 0x65
	.byte  0x61, 0x78, 0x2C, 0x20, 0x77, 0x6F, 0x72, 0x64
	.byte  0x20, 0x70, 0x74, 0x72, 0x20, 0x5B, 0x72, 0x31
	.byte  0x31, 0x2B, 0x25, 0x72, 0x2A, 0x32, 0x2D, 0x28
	.byte  0x25, 0x64, 0x2A, 0x32, 0x29, 0x2B, 0x28, 0x49
	.byte  0x24, 0x25, 0x73, 0x2D, 0x25, 0x73, 0x29, 0x5D
	.byte  0x00

DS0034:
	.byte  0x20, 0x73, 0x75, 0x62, 0x20, 0x72, 0x31, 0x31
	.byte  0x2C, 0x20, 0x72, 0x61, 0x78, 0x0A, 0x20, 0x6D
	.byte  0x6F, 0x76, 0x20, 0x72, 0x61, 0x78, 0x2C, 0x20
	.byte  0x5B, 0x72, 0x73, 0x70, 0x2B, 0x38, 0x5D, 0x0A
	.byte  0x20, 0x6D, 0x6F, 0x76, 0x20, 0x5B, 0x72, 0x73
	.byte  0x70, 0x2B, 0x38, 0x5D, 0x2C, 0x20, 0x72, 0x31
	.byte  0x31, 0x0A, 0x20, 0x70, 0x6F, 0x70, 0x20, 0x72
	.byte  0x31, 0x31, 0x0A, 0x20, 0x72, 0x65, 0x74, 0x6E
	.byte  0x00

DS0035:
	.byte  0x2E, 0x64, 0x61, 0x74, 0x61, 0x00

DS0036:
	.byte  0x41, 0x4C, 0x49, 0x47, 0x4E, 0x20, 0x25, 0x72
	.byte  0x00

DS0037:
	.byte  0x25, 0x73, 0x20, 0x25, 0x72, 0x20, 0x25, 0x72
	.byte  0x00

DS0038:
	.byte  0x20, 0x25, 0x72, 0x20, 0x25, 0x73, 0x2D, 0x40
	.byte  0x43, 0x25, 0x30, 0x34, 0x58, 0x00

DS0039:
	.byte  0x20, 0x25, 0x72, 0x20, 0x40, 0x43, 0x25, 0x30
	.byte  0x34, 0x58, 0x00

DS003A:
	.byte  0x20, 0x25, 0x72, 0x20, 0x30, 0x00

DS003B:
	.byte  0x20, 0x25, 0x72, 0x20, 0x25, 0x73, 0x00

DS003C:
	.byte  0x49, 0x24, 0x25, 0x73, 0x20, 0x6C, 0x61, 0x62
	.byte  0x65, 0x6C, 0x20, 0x25, 0x72, 0x00

DS003D:
	.byte  0x2E, 0x63, 0x6F, 0x64, 0x65, 0x00

DS003E:
	.byte  0x20, 0x6A, 0x6D, 0x70, 0x20, 0x25, 0x73, 0x00

DS003F:
	.byte  0x20, 0x6D, 0x6F, 0x76, 0x20, 0x61, 0x78, 0x2C
	.byte  0x20, 0x25, 0x72, 0x00

DS0040:
	.byte  0x20, 0x78, 0x63, 0x68, 0x67, 0x20, 0x61, 0x78
	.byte  0x2C, 0x20, 0x62, 0x78, 0x0A, 0x20, 0x61, 0x64
	.byte  0x64, 0x20, 0x62, 0x78, 0x2C, 0x20, 0x62, 0x78
	.byte  0x0A, 0x20, 0x6D, 0x6F, 0x76, 0x20, 0x62, 0x78
	.byte  0x2C, 0x20, 0x63, 0x73, 0x3A, 0x5B, 0x62, 0x78
	.byte  0x2B, 0x25, 0x73, 0x5D, 0x0A, 0x20, 0x78, 0x63
	.byte  0x68, 0x67, 0x20, 0x61, 0x78, 0x2C, 0x20, 0x62
	.byte  0x78, 0x0A, 0x20, 0x6A, 0x6D, 0x70, 0x20, 0x61
	.byte  0x78, 0x00

DS0041:
	.byte  0x20, 0x70, 0x75, 0x73, 0x68, 0x20, 0x61, 0x78
	.byte  0x0A, 0x20, 0x70, 0x75, 0x73, 0x68, 0x20, 0x62
	.byte  0x78, 0x0A, 0x20, 0x70, 0x75, 0x73, 0x68, 0x20
	.byte  0x61, 0x78, 0x00

DS0042:
	.byte  0x20, 0x6D, 0x6F, 0x76, 0x20, 0x62, 0x78, 0x2C
	.byte  0x20, 0x25, 0x72, 0x00

DS0043:
	.byte  0x20, 0x61, 0x64, 0x64, 0x20, 0x62, 0x78, 0x2C
	.byte  0x20, 0x62, 0x78, 0x0A, 0x20, 0x6D, 0x6F, 0x76
	.byte  0x20, 0x61, 0x78, 0x2C, 0x20, 0x63, 0x73, 0x3A
	.byte  0x5B, 0x62, 0x78, 0x2B, 0x25, 0x73, 0x5D, 0x0A
	.byte  0x20, 0x6D, 0x6F, 0x76, 0x20, 0x62, 0x78, 0x2C
	.byte  0x20, 0x73, 0x70, 0x0A, 0x20, 0x6D, 0x6F, 0x76
	.byte  0x20, 0x73, 0x73, 0x3A, 0x5B, 0x62, 0x78, 0x2B
	.byte  0x34, 0x5D, 0x2C, 0x20, 0x61, 0x78, 0x0A, 0x20
	.byte  0x70, 0x6F, 0x70, 0x20, 0x61, 0x78, 0x0A, 0x20
	.byte  0x70, 0x6F, 0x70, 0x20, 0x62, 0x78, 0x0A, 0x20
	.byte  0x72, 0x65, 0x74, 0x6E, 0x00

DS0044:
	.byte  0x20, 0x6A, 0x6D, 0x70, 0x20, 0x5B, 0x25, 0x72
	.byte  0x2A, 0x34, 0x2B, 0x54, 0x24, 0x25, 0x73, 0x2D
	.byte  0x28, 0x4D, 0x49, 0x4E, 0x25, 0x73, 0x2A, 0x34
	.byte  0x29, 0x5D, 0x00

DS0045:
	.byte  0x20, 0x6A, 0x6D, 0x70, 0x20, 0x5B, 0x25, 0x72
	.byte  0x2A, 0x34, 0x2B, 0x25, 0x73, 0x2D, 0x28, 0x4D
	.byte  0x49, 0x4E, 0x25, 0x73, 0x2A, 0x34, 0x29, 0x5D
	.byte  0x00

DS0046:
	.byte  0x4D, 0x49, 0x4E, 0x25, 0x73, 0x00

DS0047:
	.byte  0x20, 0x6D, 0x6F, 0x76, 0x73, 0x78, 0x64, 0x20
	.byte  0x25, 0x72, 0x2C, 0x20, 0x25, 0x72, 0x00

DS0048:
	.byte  0x72, 0x65, 0x67, 0x69, 0x73, 0x74, 0x65, 0x72
	.byte  0x20, 0x72, 0x31, 0x31, 0x20, 0x6F, 0x76, 0x65
	.byte  0x72, 0x77, 0x72, 0x69, 0x74, 0x74, 0x65, 0x6E
	.byte  0x20, 0x62, 0x79, 0x20, 0x2E, 0x53, 0x57, 0x49
	.byte  0x54, 0x43, 0x48, 0x00

DS0049:
	.byte  0x20, 0x6C, 0x65, 0x61, 0x20, 0x72, 0x31, 0x31
	.byte  0x2C, 0x20, 0x25, 0x73, 0x0A, 0x20, 0x73, 0x75
	.byte  0x62, 0x20, 0x72, 0x31, 0x31, 0x2C, 0x20, 0x5B
	.byte  0x25, 0x72, 0x2A, 0x38, 0x2B, 0x72, 0x31, 0x31
	.byte  0x2D, 0x28, 0x4D, 0x49, 0x4E, 0x25, 0x73, 0x2A
	.byte  0x38, 0x29, 0x2B, 0x28, 0x25, 0x73, 0x2D, 0x25
	.byte  0x73, 0x29, 0x5D, 0x0A, 0x20, 0x6A, 0x6D, 0x70
	.byte  0x20, 0x72, 0x31, 0x31, 0x00

DS004A:
	.byte  0x20, 0x70, 0x75, 0x73, 0x68, 0x20, 0x25, 0x72
	.byte  0x0A, 0x20, 0x6C, 0x65, 0x61, 0x20, 0x20, 0x25
	.byte  0x72, 0x2C, 0x20, 0x25, 0x73, 0x0A, 0x20, 0x73
	.byte  0x75, 0x62, 0x20, 0x20, 0x25, 0x72, 0x2C, 0x20
	.byte  0x5B, 0x25, 0x72, 0x2B, 0x25, 0x72, 0x2A, 0x38
	.byte  0x2D, 0x28, 0x4D, 0x49, 0x4E, 0x25, 0x73, 0x2A
	.byte  0x38, 0x29, 0x2B, 0x28, 0x25, 0x73, 0x2D, 0x25
	.byte  0x73, 0x29, 0x5D, 0x0A, 0x20, 0x78, 0x63, 0x68
	.byte  0x67, 0x20, 0x25, 0x72, 0x2C, 0x20, 0x5B, 0x72
	.byte  0x73, 0x70, 0x5D, 0x0A, 0x20, 0x72, 0x65, 0x74
	.byte  0x6E, 0x00

DS004B:
	.byte  0x41, 0x4C, 0x49, 0x47, 0x4E, 0x20, 0x25, 0x64
	.byte  0x00

DS004C:
	.byte  0x25, 0x73, 0x3A, 0x00

LC01B1:
	.byte  0x7B, 0x64, 0x62, 0x5D, 0x4C, 0x41, 0x39, 0x2E
	.byte  0x00, 0x02, 0x08, 0x08, 0x06, 0x08, 0x04, 0x08
	.byte  0x07, 0x03, 0x03, 0x05, 0x08, 0x08, 0x08, 0x08
	.byte  0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08
	.byte  0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08
	.byte  0x08, 0x08, 0x08, 0x08, 0x08, 0x02, 0x08, 0x08
	.byte  0x01, 0x00, 0x02, 0x02, 0x08, 0x02, 0x08, 0x02

DS004D:
	.byte  0x20, 0x6D, 0x6F, 0x76, 0x20, 0x25, 0x73, 0x2C
	.byte  0x20, 0x25, 0x73, 0x00


.att_syntax prefix
