
.intel_syntax noprefix

.global ProcType
.global MacroInline
.global ClassDirective
.global ClassInit
.global ClassCheckOpen

.extern RunLineQueue
.extern AddLineQueueX
.extern AddLineQueue
.extern OperatorParam
.extern GetOpType
.extern GetOperator
.extern Tokenize
.extern MacroLineQueue
.extern GetQualifiedType
.extern SearchNameInStruct
.extern CurrStruct
.extern LclAlloc
.extern MemFree
.extern MemAlloc
.extern LstWrite
.extern GetResWName
.extern GetCurrOffset
.extern NameSpace_
.extern tsprintf
.extern asmerr
.extern Parse_Pass
.extern SymFind
.extern tstrcmp
.extern tstrcat
.extern tstrcpy
.extern tstrchr
.extern tstrlen
.extern tmemicmp


.SECTION .text
	.ALIGN	16

$_001:	mov	qword ptr [rsp+0x8], rcx
	mov	qword ptr [rsp+0x10], rdx
	mov	qword ptr [rsp+0x20], r9
	push	rsi
	push	rdi
	push	rbp
	mov	rbp, rsp
	sub	rsp, 1072
	mov	rsi, r8
	lea	rdi, [rbp-0x400]
	lea	rcx, [rdi+0x3FF]
	mov	al, 1
	jmp	$_007

$_002:	lodsb
	cmp	al, 61
	jnz	$_006
	lodsb
	jmp	$_004

$_003:	lodsb
$_004:	test	al, al
	jz	$_005
	cmp	al, 62
	jnz	$_003
$_005:	test	al, al
	jz	$_006
	lodsb
$_006:	stosb
$_007:	test	al, al
	jz	$_008
	cmp	rdi, rcx
	jc	$_002
$_008:	cmp	dword ptr [rbp+0x28], 0
	jz	$_009
	lea	rax, [rbp-0x400]
	mov	qword ptr [rsp+0x20], rax
	mov	r9d, dword ptr [rbp+0x28]
	mov	r8d, dword ptr [rbp+0x38]
	mov	rdx, qword ptr [rbp+0x20]
	lea	rcx, [DS0000+rip]
	call	AddLineQueueX@PLT
	jmp	$_010

$_009:	lea	r9, [rbp-0x400]
	mov	r8d, dword ptr [rbp+0x38]
	mov	rdx, qword ptr [rbp+0x20]
	lea	rcx, [DS0001+rip]
	call	AddLineQueueX@PLT
$_010:	leave
	pop	rdi
	pop	rsi
	ret

$_011:
	mov	qword ptr [rsp+0x8], rcx
	mov	qword ptr [rsp+0x10], rdx
	mov	qword ptr [rsp+0x20], r9
	push	rsi
	push	rdi
	push	rbx
	push	rbp
	mov	rbp, rsp
	sub	rsp, 1064
	mov	rsi, r8
	mov	rdi, qword ptr [rbp+0x40]
	mov	rbx, qword ptr [rbp+0x48]
	test	rbx, rbx
	jnz	$_012
	lea	rbx, [rbp-0x200]
	mov	r8, qword ptr [rbp+0x28]
	lea	rdx, [DS0002+rip]
	mov	rcx, rbx
	call	tsprintf@PLT
$_012:	mov	r9, qword ptr [rbp+0x30]
	mov	r8, qword ptr [rbp+0x28]
	lea	rdx, [DS0003+rip]
	lea	rcx, [rbp-0x100]
	call	tsprintf@PLT
	cmp	dword ptr [rsi+0x20], 501
	jz	$_015
	cmp	byte ptr [rdi], 0
	jz	$_013
	mov	r9, rdi
	mov	r8, rbx
	lea	rdx, [DS0004+rip]
	lea	rcx, [rbp-0x400]
	call	tsprintf@PLT
	jmp	$_014

$_013:	mov	r8, rbx
	lea	rdx, [DS0005+rip]
	lea	rcx, [rbp-0x400]
	call	tsprintf@PLT
$_014:	lea	rdi, [rbp-0x400]
$_015:	mov	r9d, 604
	mov	r8, rdi
	mov	edx, dword ptr [rsi+0x10]
	lea	rcx, [rbp-0x100]
	call	$_001
	leave
	pop	rbx
	pop	rdi
	pop	rsi
	ret

$_016:
	push	rsi
	push	rdi
	push	rbx
	push	rbp
	mov	rbp, rsp
	sub	rsp, 552
	mov	rsi, rcx
	mov	rbx, rdx
	cmp	dword ptr [rbx+0x60], 0
	je	$_022
	cmp	dword ptr [Parse_Pass+rip], 0
	jne	$_022
	mov	rdx, qword ptr [rbx+0x78]
	mov	rdi, qword ptr [rdx]
$_017:	test	rdi, rdi
	je	$_022
	cmp	qword ptr [rdi+0x28], 0
	je	$_021
	mov	rdx, qword ptr [rdi+0x28]
	cmp	word ptr [rdx+0x6E], 1
	jnz	$_018
	mov	rcx, rsi
	call	$_016
	jmp	$_021

$_018:	mov	rdx, qword ptr [rbx+0x8]
	lea	rcx, [rbp-0x200]
	call	tstrcpy@PLT
	mov	ecx, dword ptr [rbx+0x14]
	mov	word ptr [rax+rcx-0x4], 95
	mov	rdx, qword ptr [rdi+0x8]
	mov	rcx, rax
	call	tstrcat@PLT
	mov	rcx, rax
	call	SymFind@PLT
	test	rax, rax
	jz	$_021
	mov	rdx, qword ptr [rax+0x8]
	cmp	byte ptr [rax+0x1D], 10
	jnz	$_019
	mov	rdx, qword ptr [rax+0x30]
$_019:	test	byte ptr [rax+0x13], 0x08
	jnz	$_020
	test	byte ptr [rax+0x11], 0x02
	jnz	$_020
	cmp	byte ptr [rax+0x1D], 9
	jnz	$_021
$_020:	mov	qword ptr [rbp-0x208], rdx
	mov	rdx, qword ptr [rsi+0x8]
	lea	rcx, [rbp-0x200]
	call	tstrcpy@PLT
	lea	rdx, [DS0006+rip]
	mov	rcx, rax
	call	tstrcat@PLT
	mov	rdx, qword ptr [rdi+0x8]
	mov	rcx, rax
	call	tstrcat@PLT
	mov	rcx, rax
	call	SymFind@PLT
	test	rax, rax
	jnz	$_021
	mov	r8, qword ptr [rbp-0x208]
	lea	rdx, [rbp-0x200]
	lea	rcx, [DS0007+rip]
	call	AddLineQueueX@PLT
$_021:	mov	rdi, qword ptr [rdi+0x80]
	jmp	$_017

$_022:
	leave
	pop	rbx
	pop	rdi
	pop	rsi
	ret

$_023:
	push	rsi
	push	rbx
	push	rbp
	mov	rbp, rsp
	sub	rsp, 544
	mov	rsi, rcx
	mov	rdx, qword ptr [rsi+0x8]
	lea	rcx, [DS0008+rip]
	call	AddLineQueueX@PLT
	mov	rdx, qword ptr [rsi+0x18]
	test	rdx, rdx
	jnz	$_024
	xor	eax, eax
	jmp	$_026

$_024:	mov	rdx, qword ptr [rdx+0x8]
	lea	rcx, [rbp-0x200]
	call	tstrcpy@PLT
	lea	rdx, [DS0009+rip]
	mov	rcx, rax
	call	tstrcat@PLT
	mov	rcx, rax
	call	SymFind@PLT
	test	rax, rax
	jnz	$_025
	mov	eax, 1
	jmp	$_026

$_025:	mov	rbx, rax
	xor	eax, eax
	cmp	dword ptr [rbx+0x60], 0
	jz	$_026
	lea	rdx, [rbp-0x200]
	lea	rcx, [DS000A+rip]
	call	AddLineQueueX@PLT
	mov	rdx, rbx
	mov	rcx, rsi
	call	$_016
	mov	eax, 1
$_026:	leave
	pop	rbx
	pop	rsi
	ret

$_027:
	mov	qword ptr [rsp+0x10], rdx
	mov	qword ptr [rsp+0x18], r8
	mov	qword ptr [rsp+0x20], r9
	push	rsi
	push	rdi
	push	rbx
	push	rbp
	mov	rbp, rsp
	sub	rsp, 40
	mov	byte ptr [rbp-0x1], 0
	mov	rdi, rdx
	mov	rbx, rcx
	mov	rsi, qword ptr [rbx+0x18]
	xor	eax, eax
	mov	rcx, qword ptr [rbp+0x48]
	mov	qword ptr [rcx], rax
	mov	rcx, qword ptr [rbp+0x40]
	mov	dword ptr [rcx], eax
	mov	rdx, rdi
	mov	rcx, rbx
	call	GetOpType@PLT
	cmp	eax, -1
	jnz	$_029
	cmp	byte ptr [rbx], 8
	jz	$_028
	mov	ecx, 1011
	call	asmerr@PLT
	jmp	$_036

$_028:	mov	rdx, qword ptr [rbx+0x10]
	mov	rcx, rdi
	call	tstrcpy@PLT
	mov	rcx, qword ptr [rbp+0x40]
	inc	dword ptr [rcx]
	add	rbx, 32
	jmp	$_030

$_029:	mov	rbx, rax
	inc	byte ptr [rbp-0x1]
$_030:	cmp	byte ptr [rbx], 7
	jnz	$_031
	mov	rcx, qword ptr [rbp+0x50]
	mov	eax, dword ptr [rbx+0x4]
	mov	dword ptr [rcx], eax
	add	rbx, 32
$_031:	mov	rdi, rbx
	mov	esi, 1
$_032:	cmp	byte ptr [rbx], 0
	jz	$_035
	cmp	byte ptr [rbx], 9
	jnz	$_033
	cmp	byte ptr [rbx+0x1], 123
	jnz	$_033
	mov	rcx, qword ptr [rbp+0x48]
	mov	qword ptr [rcx], rbx
	jmp	$_035

	jmp	$_034

$_033:	cmp	byte ptr [rbx], 58
	jnz	$_034
	inc	esi
	cmp	byte ptr [rbp-0x1], 0
	jz	$_034
	mov	rdx, qword ptr [rbp+0x30]
	lea	rcx, [rbx+0x20]
	call	OperatorParam@PLT
$_034:	add	rbx, 32
	jmp	$_032

$_035:	mov	rcx, qword ptr [rbp+0x38]
	mov	dword ptr [rcx], esi
	mov	rax, rdi
$_036:	leave
	pop	rbx
	pop	rdi
	pop	rsi
	ret

$_037:
	mov	qword ptr [rsp+0x18], r8
	push	rsi
	push	rdi
	push	rbx
	push	rbp
	mov	rbp, rsp
	sub	rsp, 88
	mov	dword ptr [rbp-0x4], 3
	mov	dword ptr [rbp-0x28], 0
	mov	rsi, rcx
	mov	rcx, rdx
	mov	rdi, r8
	mov	edx, r9d
	xor	ebx, ebx
	mov	dword ptr [rbp-0x24], edx
	mov	r9d, 1
	mov	r8, qword ptr [rbp+0x38]
	xor	edx, edx
	call	Tokenize@PLT
	mov	dword ptr [r14+0x64], eax
	add	rdi, 96
	cmp	byte ptr [rdi], 7
	jnz	$_038
	cmp	dword ptr [rdi+0x4], 343
	jc	$_038
	cmp	dword ptr [rdi+0x4], 352
	ja	$_038
	mov	eax, dword ptr [rdi+0x4]
	lea	eax, [rax-0x156]
	mov	dword ptr [rbp-0x24], eax
	inc	dword ptr [rbp-0x4]
	add	rdi, 32
$_038:	mov	eax, dword ptr [r14+0x64]
	cmp	dword ptr [rbp-0x4], eax
	jge	$_050
	cmp	byte ptr [rdi], 0
	je	$_050
	cmp	byte ptr [rdi], 58
	jne	$_049
	inc	dword ptr [rbp-0x4]
	add	rdi, 32
	inc	dword ptr [rbp-0x28]
	cmp	byte ptr [rdi], 7
	jnz	$_039
	cmp	dword ptr [rdi+0x4], 341
	jnz	$_039
	imul	ebx, ebx, 16777619
	xor	bl, 0x56
	jmp	$_050

$_039:	xor	eax, eax
	cmp	byte ptr [rdi], 8
	jnz	$_040
	mov	rcx, qword ptr [rdi+0x10]
	mov	eax, dword ptr [rcx]
	or	eax, 0x202020
$_040:	cmp	eax, 7561825
	jnz	$_041
	imul	ebx, ebx, 16777619
	xor	bl, 0x41
	inc	dword ptr [rbp-0x4]
	add	rdi, 32
	jmp	$_049

$_041:	mov	qword ptr [rbp-0x18], 0
	mov	byte ptr [rbp-0x10], 192
	mov	byte ptr [rbp-0xC], 192
	mov	byte ptr [rbp-0xF], 0
	lea	r8, [rbp-0x20]
	mov	rdx, qword ptr [rbp+0x38]
	lea	rcx, [rbp-0x4]
	call	GetQualifiedType@PLT
	cmp	eax, -1
	jnz	$_042
	jmp	$_050

$_042:	cmp	byte ptr [rbp-0xF], 0
	jz	$_043
	imul	ebx, ebx, 16777619
	xor	bl, 0x50
$_043:	mov	rdx, qword ptr [rbp-0x18]
	test	rdx, rdx
	jz	$_046
	mov	al, byte ptr [rdx+0x1E]
	cmp	byte ptr [rbp-0xF], 0
	jnz	$_044
	cmp	byte ptr [rbp-0x10], 196
	jnz	$_044
	test	al, 0x80
	jnz	$_044
	xor	edx, edx
	mov	byte ptr [rbp-0x10], al
	jmp	$_046

$_044:	mov	ecx, dword ptr [rdx+0x14]
	mov	rdx, qword ptr [rdx+0x8]
$_045:	test	ecx, ecx
	jz	$_046
	imul	ebx, ebx, 16777619
	xor	bl, byte ptr [rdx]
	dec	ecx
	inc	rdx
	jmp	$_045

$_046:	movzx	ecx, byte ptr [rbp-0x10]
	cmp	ecx, 195
	jnz	$_047
	cmp	byte ptr [rbp-0xC], 192
	jz	$_047
	mov	cl, byte ptr [rbp-0xC]
$_047:	test	rdx, rdx
	jnz	$_048
	test	ecx, 0x80
	jnz	$_048
	imul	ebx, ebx, 16777619
	xor	bl, cl
$_048:	imul	edi, dword ptr [rbp-0x4], 32
	add	rdi, qword ptr [rbp+0x38]
$_049:	add	rdi, 32
	inc	dword ptr [rbp-0x4]
	jmp	$_038

$_050:
	mov	edx, dword ptr [rbp-0x28]
	cmp	edx, 9
	jbe	$_051
	add	edx, 7
$_051:	add	edx, 48
	and	ebx, 0x7FFF
	mov	dword ptr [rsp+0x20], ebx
	mov	r9d, edx
	mov	r8d, dword ptr [rbp-0x24]
	lea	rdx, [DS000B+rip]
	mov	rcx, rsi
	call	tsprintf@PLT
	leave
	pop	rbx
	pop	rdi
	pop	rsi
	ret

ProcType:
	mov	qword ptr [rsp+0x8], rcx
	mov	qword ptr [rsp+0x10], rdx
	push	rsi
	push	rdi
	push	rbx
	push	rbp
	mov	rbp, rsp
	sub	rsp, 616
	mov	ecx, dword ptr [r14+0x234]
	call	MemAlloc@PLT
	mov	qword ptr [rbp-0x8], rax
	imul	ebx, dword ptr [rbp+0x28], 32
	add	rbx, qword ptr [rbp+0x30]
	mov	dword ptr [rbp-0x234], 0
	mov	dword ptr [rbp-0x230], 0
	mov	dword ptr [rbp-0x22C], 0
	mov	rsi, qword ptr [r14+0x2F0]
	mov	rdx, qword ptr [rbx-0x10]
	lea	rcx, [rbp-0x108]
	call	tstrcpy@PLT
	test	rsi, rsi
	jz	$_052
	mov	eax, dword ptr [rsi+0x10]
	mov	dword ptr [rbp-0x230], eax
	lea	rdx, [rbp-0x108]
	lea	rax, [rbp-0x108]
	call	NameSpace_@PLT
	mov	rdi, rax
	mov	rdx, qword ptr [rsi+0x8]
	mov	rcx, rdi
	call	tstrcmp@PLT
	test	rax, rax
	jnz	$_052
	mov	qword ptr [rsp+0x20], 0
	mov	r9, qword ptr [rbx+0x38]
	mov	r8, rsi
	mov	rdx, rdi
	mov	rcx, rdi
	call	$_011
	mov	dword ptr [rbp-0x234], 1
	jmp	$_074

$_052:	mov	byte ptr [rbp-0x235], 0
	mov	rax, qword ptr [CurrStruct+rip]
	test	rax, rax
	jz	$_053
	mov	rdi, qword ptr [rax+0x8]
	mov	eax, dword ptr [rax+0x14]
	cmp	eax, 4
	jbe	$_053
	mov	eax, dword ptr [rdi+rax-0x4]
$_053:	mov	rdi, qword ptr [rbp-0x8]
	cmp	eax, 1818391638
	jnz	$_054
	inc	byte ptr [rbp-0x235]
	jmp	$_056

$_054:	test	rsi, rsi
	jz	$_056
	cmp	dword ptr [r14+0x64], 2
	jle	$_055
	cmp	dword ptr [rbx+0x24], 607
	jnz	$_055
	add	rbx, 32
	jmp	$_056

$_055:	mov	rdx, qword ptr [rsi+0x8]
	lea	rcx, [DS000C+rip]
	call	AddLineQueueX@PLT
	mov	rcx, rsi
	call	$_023
	mov	dword ptr [rbp-0x22C], eax
	inc	byte ptr [rbp-0x235]
	cmp	dword ptr [Parse_Pass+rip], 0
	jbe	$_056
	call	RunLineQueue@PLT
$_056:	cmp	dword ptr [Parse_Pass+rip], 0
	jbe	$_057
	xor	r9d, r9d
	xor	r8d, r8d
	lea	rdx, [rbp-0x108]
	mov	rcx, qword ptr [CurrStruct+rip]
	call	SearchNameInStruct@PLT
	test	rax, rax
	jz	$_057
	mov	rcx, qword ptr [rax+0x28]
	test	rcx, rcx
	jz	$_057
	cmp	byte ptr [rax+0x1E], 196
	jnz	$_057
	mov	r8, qword ptr [rcx+0x8]
	lea	rdx, [rbp-0x108]
	lea	rcx, [DS000D+rip]
	call	AddLineQueueX@PLT
	jmp	$_074

$_057:	lea	rdx, [DS000E+rip]
	mov	rcx, rdi
	call	tstrcpy@PLT
	test	rsi, rsi
	jz	$_058
	cmp	dword ptr [rsi], 497
	jnz	$_058
	cmp	byte ptr [r14+0x4], 1
	jnz	$_058
	cmp	byte ptr [r14+0x9], 3
	jz	$_058
	lea	rdx, [DS000F+rip]
	mov	rcx, rdi
	call	tstrcat@PLT
$_058:	add	rbx, 32
	xor	esi, esi
	cmp	byte ptr [rbx], 0
	je	$_067
	cmp	byte ptr [rbp-0x235], 0
	je	$_063
	cmp	dword ptr [rbx+0x4], 343
	jc	$_059
	cmp	dword ptr [rbx+0x4], 352
	ja	$_059
	inc	esi
$_059:	cmp	byte ptr [rbx+0x20], 0
	jz	$_060
	test	esi, esi
	jnz	$_060
	cmp	byte ptr [rbx], 58
	jz	$_061
	cmp	byte ptr [rbx+0x20], 58
	jz	$_061
$_060:	lea	rdx, [DS0010+rip]
	mov	rcx, rdi
	call	tstrcat@PLT
	mov	rdx, qword ptr [rbx+0x10]
	mov	rcx, rdi
	call	tstrcat@PLT
	add	rbx, 32
	jmp	$_062

$_061:	test	esi, esi
	jnz	$_062
	cmp	dword ptr [rbp-0x230], 0
	jz	$_062
	lea	rdx, [rbp-0x228]
	mov	ecx, dword ptr [rbp-0x230]
	call	GetResWName@PLT
	lea	rdx, [DS0010+rip]
	mov	rcx, rdi
	call	tstrcat@PLT
	lea	rdx, [rbp-0x228]
	mov	rcx, rdi
	call	tstrcat@PLT
$_062:	xor	esi, esi
$_063:	mov	rax, rbx
$_064:	cmp	byte ptr [rax], 0
	jz	$_066
	cmp	byte ptr [rax], 58
	jnz	$_065
	inc	esi
	jmp	$_066

$_065:	add	rax, 32
	jmp	$_064

$_066:	jmp	$_068

$_067:	cmp	byte ptr [rbp-0x235], 0
	jz	$_068
	cmp	qword ptr [r14+0x2F0], 0
	jz	$_068
	mov	rax, qword ptr [r14+0x2F0]
	mov	ecx, dword ptr [rax+0x10]
	test	ecx, ecx
	jz	$_068
	lea	rdx, [rbp-0x228]
	call	GetResWName@PLT
	lea	rdx, [DS0010+rip]
	mov	rcx, rdi
	call	tstrcat@PLT
	lea	rdx, [rbp-0x228]
	mov	rcx, rdi
	call	tstrcat@PLT
$_068:	mov	rax, qword ptr [r14+0x2F0]
	test	rax, rax
	jz	$_069
	cmp	dword ptr [rax+0x20], 501
	jz	$_069
	xor	eax, eax
$_069:	cmp	byte ptr [rbp-0x235], 0
	jz	$_071
	test	rax, rax
	jnz	$_071
	lea	rdx, [DS0011+rip]
	mov	rcx, rdi
	call	tstrcat@PLT
	mov	rax, qword ptr [r14+0x2F0]
	test	rax, rax
	jz	$_070
	cmp	dword ptr [rax], 496
	jnz	$_070
	lea	rdx, [DS0010+rip]
	mov	rcx, rdi
	call	tstrcat@PLT
	mov	rax, qword ptr [r14+0x2F0]
	mov	rdx, qword ptr [rax+0x8]
	mov	rcx, rdi
	call	tstrcat@PLT
$_070:	test	rsi, rsi
	jz	$_071
	lea	rdx, [DS0012+rip]
	mov	rcx, rdi
	call	tstrcat@PLT
$_071:	test	rsi, rsi
	jz	$_072
	lea	rdx, [DS0010+rip]
	mov	rcx, rdi
	call	tstrcat@PLT
	mov	rdx, qword ptr [rbx+0x18]
	mov	rcx, rdi
	call	tstrcat@PLT
$_072:	mov	r9d, dword ptr [rbp-0x230]
	mov	r8, qword ptr [rbp+0x30]
	mov	rdx, rdi
	lea	rcx, [rbp-0x208]
	call	$_037
	lea	rcx, [rbp-0x208]
	call	SymFind@PLT
	test	rax, rax
	jnz	$_073
	lea	r8, [rdi+0x6]
	lea	rdx, [rbp-0x208]
	lea	rcx, [DS0013+rip]
	call	AddLineQueueX@PLT
	lea	r8, [rbp-0x208]
	lea	rdx, [rbp-0x207]
	lea	rcx, [DS0014+rip]
	call	AddLineQueueX@PLT
$_073:	lea	r8, [rbp-0x207]
	lea	rdx, [rbp-0x108]
	lea	rcx, [DS0015+rip]
	call	AddLineQueueX@PLT
$_074:	test	byte ptr [r14], 0x08
	jz	$_075
	call	GetCurrOffset@PLT
	xor	r8d, r8d
	mov	edx, eax
	mov	ecx, 4
	call	LstWrite@PLT
$_075:	cmp	qword ptr [r14+0x2B0], 0
	jz	$_076
	call	RunLineQueue@PLT
$_076:	cmp	dword ptr [rbp-0x234], 0
	jz	$_077
	mov	rdx, rdi
	mov	rcx, qword ptr [rbp-0x8]
	call	tstrcpy@PLT
	lea	rdx, [DS0006+rip]
	mov	rcx, rax
	call	tstrcat@PLT
	mov	rdx, rdi
	mov	rcx, rax
	call	tstrcat@PLT
	mov	rcx, rax
	call	SymFind@PLT
	test	rax, rax
	jz	$_077
	or	byte ptr [rax+0x11], 0x01
$_077:	mov	rcx, qword ptr [rbp-0x8]
	call	MemFree@PLT
	mov	eax, dword ptr [rbp-0x22C]
	leave
	pop	rbx
	pop	rdi
	pop	rsi
	ret

$_078:
	mov	qword ptr [rsp+0x8], rcx
	mov	qword ptr [rsp+0x10], rdx
	mov	qword ptr [rsp+0x18], r8
	push	rsi
	push	rdi
	push	rbx
	push	rbp
	mov	rbp, rsp
	sub	rsp, 40
	mov	rbx, qword ptr [rbp+0x38]
	mov	rdi, qword ptr [rbp+0x28]
	mov	esi, 1
$_079:	cmp	esi, dword ptr [rbp+0x30]
	jge	$_090
	mov	rcx, rbx
	jmp	$_081

$_080:	add	rcx, 1
$_081:	movzx	eax, byte ptr [rcx]
	test	byte ptr [r15+rax], 0x08
	jnz	$_080
	xchg	rcx, rax
	mov	rbx, rax
	movzx	eax, cl
	test	byte ptr [r15+rax], 0x44
	jnz	$_082
	mov	r8d, esi
	lea	rdx, [DS0016+rip]
	mov	rcx, rdi
	call	tsprintf@PLT
	add	rdi, rax
	jmp	$_085

$_082:	jmp	$_084

$_083:	stosb
	inc	rbx
$_084:	movzx	eax, byte ptr [rbx]
	test	byte ptr [r15+rax], 0x44
	jnz	$_083
	mov	eax, 8236
	stosw
	mov	byte ptr [rdi], 0
$_085:	mov	edx, 44
	mov	rcx, rbx
	call	tstrchr@PLT
	test	rax, rax
	jz	$_086
	inc	rax
	jmp	$_087

$_086:	mov	rcx, rbx
	call	tstrlen@PLT
	add	rax, rbx
$_087:	xchg	rbx, rax
	mov	edx, 61
	mov	rcx, rax
	call	tstrchr@PLT
	test	rax, rax
	jz	$_089
	cmp	rax, rbx
	jnc	$_089
	dec	rdi
	mov	byte ptr [rdi-0x1], 58
	mov	rcx, rbx
	sub	rcx, rax
	cmp	byte ptr [rbx-0x1], 44
	jnz	$_088
	dec	ecx
$_088:	mov	rdx, rsi
	mov	rsi, rax
	rep movsb
	mov	rsi, rdx
	mov	dword ptr [rdi], 8236
	add	rdi, 2
$_089:	inc	esi
	jmp	$_079

$_090:
	mov	rax, rdi
	leave
	pop	rbx
	pop	rdi
	pop	rsi
	ret

MacroInline:
	mov	qword ptr [rsp+0x8], rcx
	mov	qword ptr [rsp+0x10], rdx
	mov	qword ptr [rsp+0x18], r8
	mov	qword ptr [rsp+0x20], r9
	push	rsi
	push	rdi
	push	rbx
	push	rbp
	mov	rbp, rsp
	sub	rsp, 1064
	cmp	dword ptr [Parse_Pass+rip], 0
	jbe	$_091
	xor	eax, eax
	jmp	$_105

$_091:	mov	rdx, qword ptr [rbp+0x38]
	lea	rcx, [rbp-0x200]
	call	tstrcpy@PLT
	mov	byte ptr [rbp-0x400], 0
	lea	rdi, [rbp-0x400]
	mov	rbx, qword ptr [r14+0x1D0]
	cmp	dword ptr [rbx+0x24], 604
	jnz	$_093
	mov	edx, dword ptr [rbp+0x30]
	test	edx, edx
	jz	$_092
	inc	edx
	lea	r8, [rbp-0x200]
	mov	rcx, rdi
	call	$_078
	mov	rdi, rax
	sub	rdi, 2
$_092:	mov	byte ptr [rdi], 0
	jmp	$_094

$_093:	lea	rdx, [DS0017+rip]
	mov	rcx, rdi
	call	tstrcpy@PLT
	lea	rdi, [rax+0x4]
	cmp	dword ptr [rbp+0x30], 1
	jle	$_094
	lea	rdx, [DS0016+0x3+rip]
	mov	rcx, rdi
	call	tstrcpy@PLT
	lea	rdi, [rax+0x2]
	lea	r8, [rbp-0x200]
	mov	edx, dword ptr [rbp+0x30]
	mov	rcx, rdi
	call	$_078
	mov	rdi, rax
	sub	rdi, 2
	mov	byte ptr [rdi], 0
$_094:	cmp	dword ptr [rbp+0x48], 0
	jz	$_095
	lea	rdx, [DS0018+rip]
	mov	rcx, rdi
	call	tstrcpy@PLT
$_095:	lea	r8, [rbp-0x400]
	mov	rdx, qword ptr [rbp+0x28]
	lea	rcx, [DS0019+rip]
	call	AddLineQueueX@PLT
	mov	rsi, qword ptr [rbp+0x40]
	jmp	$_097

$_096:	inc	rsi
$_097:	movzx	eax, byte ptr [rsi]
	test	byte ptr [r15+rax], 0x08
	jnz	$_096
	xor	rdi, rdi
$_098:	mov	edx, 10
	mov	rcx, rsi
	call	tstrchr@PLT
	test	rax, rax
	jz	$_100
	mov	rbx, rax
	mov	byte ptr [rbx], 0
	cmp	byte ptr [rsi], 0
	jz	$_099
	mov	rdi, rsi
	mov	rcx, rsi
	call	AddLineQueue@PLT
$_099:	mov	byte ptr [rbx], 10
	lea	rsi, [rbx+0x1]
	jmp	$_098

$_100:	cmp	byte ptr [rsi], 0
	jz	$_101
	mov	rdi, rsi
	mov	rcx, rsi
	call	AddLineQueue@PLT
$_101:	test	rdi, rdi
	jnz	$_102
	lea	rcx, [DS001A+rip]
	call	AddLineQueue@PLT
	jmp	$_104

$_102:	mov	r8d, 5
	lea	rdx, [DS001B+rip]
	mov	rcx, rdi
	call	tmemicmp@PLT
	test	eax, eax
	jz	$_103
	mov	r8d, 4
	lea	rdx, [DS001C+rip]
	mov	rcx, rdi
	call	tmemicmp@PLT
$_103:	test	eax, eax
	jz	$_104
	lea	rcx, [DS001A+rip]
	call	AddLineQueue@PLT
$_104:	lea	rcx, [DS001D+rip]
	call	AddLineQueue@PLT
	call	MacroLineQueue@PLT
$_105:	leave
	pop	rbx
	pop	rdi
	pop	rsi
	ret

ClassDirective:
	mov	qword ptr [rsp+0x8], rcx
	push	rsi
	push	rdi
	push	rbx
	push	rbp
	mov	rbp, rsp
	sub	rsp, 1656
	mov	dword ptr [rbp-0x4], 0
	mov	dword ptr [rbp-0x10], 0
	mov	dword ptr [rbp-0x14], 0
	mov	word ptr [rbp-0x40], 0
	mov	rbx, rdx
	lea	rdi, [rbp-0x140]
	imul	edx, dword ptr [rbp+0x28], 32
	mov	eax, dword ptr [rbx+rdx+0x4]
	mov	dword ptr [rbp-0xC], eax
	inc	dword ptr [rbp+0x28]
	jmp	$_152

$_106:	mov	rdi, qword ptr [r14+0x2F0]
	mov	rsi, qword ptr [CurrStruct+rip]
	test	rdi, rdi
	jnz	$_108
	test	rsi, rsi
	jz	$_107
	mov	ecx, 1011
	call	asmerr@PLT
	mov	dword ptr [rbp-0x4], eax
$_107:	mov	eax, dword ptr [rbp-0x4]
	jmp	$_158

$_108:	test	rsi, rsi
	jnz	$_109
	mov	ecx, 1011
	call	asmerr@PLT
	jmp	$_158

$_109:	mov	dword ptr [rbp-0x14], 1
	mov	rdx, qword ptr [rsi+0x8]
	lea	rcx, [DS000C+rip]
	call	AddLineQueueX@PLT
	mov	rdx, qword ptr [rdi+0x18]
	test	rdx, rdx
	jz	$_110
	mov	rdx, qword ptr [rsi+0x8]
	mov	rcx, qword ptr [rdi+0x8]
	call	tstrcmp@PLT
	test	rax, rax
	jnz	$_110
	mov	rdx, qword ptr [rdi+0x18]
	mov	rdx, qword ptr [rdx+0x8]
	lea	rcx, [rbp-0x140]
	call	tstrcpy@PLT
	lea	rdx, [DS0009+rip]
	mov	rcx, rax
	call	tstrcat@PLT
	mov	rcx, rax
	call	SymFind@PLT
	test	rax, rax
	jz	$_110
	mov	rcx, rdi
	call	$_023
	mov	rdx, qword ptr [rsi+0x8]
	lea	rcx, [DS001E+rip]
	call	AddLineQueueX@PLT
$_110:	jmp	$_153

$_111:	mov	qword ptr [rbp-0x648], 0
	mov	rsi, qword ptr [r14+0x2F0]
	mov	rcx, qword ptr [CurrStruct+rip]
	test	rcx, rcx
	jz	$_112
	test	rsi, rsi
	jnz	$_113
$_112:	mov	ecx, 1011
	call	asmerr@PLT
	jmp	$_158

$_113:	mov	dword ptr [rsi+0x20], eax
	mov	rax, qword ptr [rsi+0x28]
	lea	rbx, [rbx+rdx+0x20]
	test	rax, rax
	jnz	$_114
	mov	rcx, qword ptr [rsi+0x8]
	call	SymFind@PLT
$_114:	test	rax, rax
	jz	$_115
	movzx	eax, word ptr [rax+0x5A]
$_115:	test	eax, eax
	jz	$_116
	mov	r8d, eax
	lea	rdx, [DS001F+rip]
	lea	rcx, [rbp-0x640]
	call	tsprintf@PLT
	lea	rax, [rbp-0x640]
	mov	qword ptr [rbp-0x648], rax
$_116:	mov	eax, dword ptr [rsi+0x10]
	mov	dword ptr [rbp-0x3C], eax
	mov	dword ptr [rbp-0x1C], 0
	cmp	byte ptr [rbx], 9
	jnz	$_117
	mov	rcx, rbx
	call	GetOperator@PLT
	test	rax, rax
	jnz	$_117
	mov	rax, qword ptr [rbx+0x10]
	mov	qword ptr [rbp-0x648], rax
	add	rbx, 32
$_117:	lea	rax, [rbp-0x3C]
	mov	qword ptr [rsp+0x28], rax
	lea	rax, [rbp-0x28]
	mov	qword ptr [rsp+0x20], rax
	lea	r9, [rbp-0x18]
	lea	r8, [rbp-0x8]
	lea	rdx, [rbp-0x340]
	mov	rcx, rbx
	call	$_027
	mov	rbx, rax
	cmp	eax, -1
	je	$_158
	cmp	qword ptr [rbp-0x28], 0
	jz	$_123
	mov	rcx, qword ptr [rbp-0x28]
	mov	qword ptr [rbp-0x28], 0
	cmp	byte ptr [rcx], 9
	jnz	$_122
	cmp	byte ptr [rcx+0x1], 123
	jnz	$_122
	cmp	byte ptr [rcx-0x20], 7
	jnz	$_118
	cmp	dword ptr [rcx-0x1C], 341
	jnz	$_118
	inc	dword ptr [rbp-0x1C]
$_118:	mov	rax, qword ptr [rcx+0x10]
	mov	qword ptr [rbp-0x28], rax
	mov	rax, qword ptr [rcx+0x18]
	mov	byte ptr [rax], 0
	jmp	$_120

$_119:	cmp	rax, qword ptr [rcx-0x8]
	jbe	$_121
	sub	rax, 1
$_120:	cmp	byte ptr [rax-0x1], 32
	jbe	$_119
$_121:	mov	byte ptr [rax], 0
	mov	byte ptr [rcx], 0
$_122:	jmp	$_124

$_123:	cmp	dword ptr [rbp-0xC], 499
	jnz	$_124
	cmp	dword ptr [Parse_Pass+rip], 0
	jnz	$_124
	mov	rdx, qword ptr [rbx+0x18]
	mov	ecx, 2008
	call	asmerr@PLT
$_124:	lea	rdx, [rbp-0x340]
	lea	rcx, [rbp-0x540]
	call	tstrcpy@PLT
	mov	rdi, rax
	mov	rcx, qword ptr [rsi+0x8]
	mov	qword ptr [rbp-0x30], rcx
	cmp	qword ptr [rsi+0x18], 0
	jz	$_125
	mov	rcx, qword ptr [rsi+0x18]
	mov	rcx, qword ptr [rcx+0x8]
$_125:	mov	rdx, rcx
	lea	rcx, [rbp-0x140]
	call	tstrcpy@PLT
	lea	rdx, [DS0009+rip]
	mov	rcx, rax
	call	tstrcat@PLT
	mov	rcx, rax
	call	SymFind@PLT
	mov	qword ptr [rbp-0x38], rax
	test	rax, rax
	jnz	$_126
	mov	rax, qword ptr [CurrStruct+rip]
$_126:	test	rax, rax
	jz	$_129
	mov	rcx, rax
	xor	r9d, r9d
	xor	r8d, r8d
	mov	rdx, rdi
	call	SearchNameInStruct@PLT
	test	rax, rax
	jz	$_127
	cmp	qword ptr [rbp-0x38], 0
	jnz	$_129
$_127:	mov	rdx, qword ptr [rbp-0x30]
	mov	rcx, rdi
	call	tstrcmp@PLT
	test	rax, rax
	jz	$_128
	cmp	dword ptr [rsi+0x20], 499
	jz	$_128
	mov	r9d, 605
	mov	r8, qword ptr [rbx+0x18]
	mov	edx, dword ptr [rbp-0x3C]
	mov	rcx, rdi
	call	$_001
	jmp	$_129

$_128:	mov	rax, qword ptr [rbp-0x648]
	mov	qword ptr [rsp+0x20], rax
	mov	r9, qword ptr [rbx+0x18]
	mov	r8, rsi
	mov	rdx, rdi
	mov	rcx, qword ptr [rbp-0x30]
	call	$_011
	cmp	dword ptr [rbp-0xC], 499
	jz	$_129
	inc	dword ptr [rbp-0x10]
$_129:	cmp	qword ptr [rbp-0x28], 0
	je	$_153
	cmp	dword ptr [Parse_Pass+rip], 0
	ja	$_153
	lea	r9, [rbp-0x540]
	mov	r8, qword ptr [rbp-0x30]
	lea	rdx, [DS0003+rip]
	lea	rcx, [rbp-0x340]
	call	tsprintf@PLT
	test	byte ptr [r14], 0x08
	jz	$_130
	call	GetCurrOffset@PLT
	xor	r8d, r8d
	mov	edx, eax
	mov	ecx, 4
	call	LstWrite@PLT
$_130:	call	RunLineQueue@PLT
	cmp	dword ptr [rbp-0x10], 0
	jz	$_133
	lea	rcx, [rbp-0x340]
	call	SymFind@PLT
	test	rax, rax
	jz	$_132
	cmp	dword ptr [rbp-0xC], 501
	jz	$_131
	or	byte ptr [rax+0x11], 0x01
$_131:	cmp	dword ptr [rbp-0xC], 501
	jnz	$_132
	cmp	dword ptr [rbp-0x1C], 0
	jnz	$_132
	or	byte ptr [rax+0x12], 0x80
$_132:	jmp	$_134

$_133:	cmp	dword ptr [rbp-0xC], 499
	jnz	$_134
	mov	rax, qword ptr [rsi+0x28]
	test	rax, rax
	jz	$_134
	or	byte ptr [rax+0x12], 0x04
$_134:	mov	eax, dword ptr [rbp-0x1C]
	mov	dword ptr [rsp+0x20], eax
	mov	r9, qword ptr [rbp-0x28]
	mov	r8, qword ptr [rbx+0x18]
	mov	edx, dword ptr [rbp-0x8]
	lea	rcx, [rbp-0x340]
	call	MacroInline
	cmp	dword ptr [rbp-0x10], 0
	jnz	$_135
	cmp	dword ptr [rbp-0xC], 501
	jnz	$_135
	cmp	dword ptr [rbp-0x1C], 0
	jnz	$_135
	lea	rcx, [rbp-0x340]
	call	SymFind@PLT
	test	rax, rax
	jz	$_135
	or	byte ptr [rax+0x12], 0x80
$_135:	mov	eax, dword ptr [rbp-0x4]
	jmp	$_158

$_136:	cmp	qword ptr [r14+0x2F0], 0
	jz	$_137
	mov	ecx, 1011
	call	asmerr@PLT
	jmp	$_158

$_137:	lea	rbx, [rbx+rdx+0x20]
	cmp	byte ptr [rbx], 9
	jnz	$_139
	mov	eax, dword ptr [rbx+0x24]
	mov	word ptr [rbp-0x40], ax
	cmp	byte ptr [rbx+0x40], 44
	jz	$_138
	lea	rdx, [DS0012+rip]
	mov	ecx, 2065
	call	asmerr@PLT
	jmp	$_158

$_138:	mov	eax, dword ptr [rbx+0x64]
	mov	word ptr [rbp-0x3E], ax
	add	rbx, 160
$_139:	mov	ecx, 48
	call	LclAlloc@PLT
	mov	qword ptr [r14+0x2F0], rax
	mov	ecx, dword ptr [rbp-0xC]
	mov	dword ptr [rax], ecx
	xor	edx, edx
	mov	rax, qword ptr [rbx+0x10]
	call	NameSpace_@PLT
	mov	rsi, rax
	mov	rcx, qword ptr [r14+0x2F0]
	mov	qword ptr [rcx+0x8], rax
	mov	rdx, rsi
	mov	rcx, rdi
	call	tstrcpy@PLT
	add	rbx, 32
	cmp	byte ptr [rbx], 8
	jnz	$_140
	mov	rax, qword ptr [rbx+0x10]
	mov	eax, dword ptr [rax]
	or	al, 0x20
	cmp	ax, 99
	jnz	$_140
	mov	byte ptr [rbx], 7
	mov	dword ptr [rbx+0x4], 343
	mov	byte ptr [rbx+0x1], 1
$_140:	mov	edx, dword ptr [rbx+0x4]
	cmp	byte ptr [rbx], 0
	jz	$_141
	cmp	edx, 343
	jc	$_141
	cmp	edx, 352
	ja	$_141
	mov	rcx, qword ptr [r14+0x2F0]
	mov	dword ptr [rcx+0x10], edx
	add	rbx, 32
$_141:	cmp	byte ptr [rbx], 58
	jnz	$_144
	cmp	byte ptr [rbx+0x20], 3
	jnz	$_143
	cmp	dword ptr [rbx+0x24], 603
	jnz	$_143
	mov	rbx, qword ptr [rbx+0x50]
	mov	rcx, rbx
	call	SymFind@PLT
	test	rax, rax
	jnz	$_142
	mov	rdx, rbx
	mov	ecx, 2006
	call	asmerr@PLT
	jmp	$_158

$_142:	mov	rcx, qword ptr [r14+0x2F0]
	mov	qword ptr [rcx+0x18], rax
	jmp	$_144

$_143:	mov	rdx, qword ptr [rbx+0x30]
	mov	ecx, 2006
	call	asmerr@PLT
$_144:	cmp	dword ptr [rbp-0xC], 496
	jnz	$_147
	movzx	eax, byte ptr [r14+0x4]
	shl	eax, 2
	mov	cl, byte ptr [r14+0xA]
	mov	edx, 1
	shl	edx, cl
	test	eax, eax
	jz	$_145
	cmp	edx, eax
	jnc	$_145
	mov	r8d, eax
	mov	rdx, rsi
	lea	rcx, [DS0020+rip]
	call	AddLineQueueX@PLT
	jmp	$_146

$_145:	mov	rdx, rsi
	lea	rcx, [DS0021+rip]
	call	AddLineQueueX@PLT
$_146:	jmp	$_148

$_147:	mov	rdx, rsi
	lea	rcx, [DS0021+rip]
	call	AddLineQueueX@PLT
$_148:	mov	rcx, qword ptr [r14+0x2F0]
	mov	rsi, qword ptr [rcx+0x18]
	test	rsi, rsi
	jz	$_150
	cmp	dword ptr [rbp-0xC], 498
	jz	$_149
	xor	r9d, r9d
	xor	r8d, r8d
	lea	rdx, [DS0022+rip]
	mov	rcx, rsi
	call	SearchNameInStruct@PLT
	test	rax, rax
	jnz	$_149
	lea	rdx, [rbp-0x140]
	lea	rcx, [DS0023+rip]
	call	AddLineQueueX@PLT
$_149:	mov	rdx, qword ptr [rsi+0x8]
	lea	rcx, [DS000A+rip]
	call	AddLineQueueX@PLT
	jmp	$_151

$_150:	cmp	dword ptr [rbp-0xC], 498
	jz	$_151
	lea	rdx, [rbp-0x140]
	lea	rcx, [DS0023+rip]
	call	AddLineQueueX@PLT
$_151:	jmp	$_153

$_152:	cmp	eax, 502
	je	$_106
	cmp	eax, 500
	je	$_111
	cmp	eax, 501
	je	$_111
	cmp	eax, 499
	je	$_111
	cmp	eax, 497
	je	$_136
	cmp	eax, 496
	je	$_136
	cmp	eax, 498
	je	$_136
$_153:	test	byte ptr [r14], 0x08
	jz	$_154
	call	GetCurrOffset@PLT
	xor	r8d, r8d
	mov	edx, eax
	mov	ecx, 4
	call	LstWrite@PLT
$_154:	cmp	qword ptr [r14+0x2B0], 0
	jz	$_155
	call	RunLineQueue@PLT
$_155:	cmp	word ptr [rbp-0x40], 0
	jz	$_156
	mov	rcx, qword ptr [r14+0x2F0]
	mov	rsi, qword ptr [rcx+0x28]
	test	rsi, rsi
	jz	$_156
	movzx	eax, word ptr [rbp-0x40]
	movzx	ecx, word ptr [rbp-0x3E]
	mov	word ptr [rsi+0x58], ax
	mov	word ptr [rsi+0x5A], cx
	or	byte ptr [rsi+0x4B], 0x08
	mov	eax, ecx
	add	eax, eax
	mov	al, byte ptr [r12+rax*8+0xC]
	mov	byte ptr [rsi+0x1E], al
$_156:	cmp	dword ptr [rbp-0x14], 0
	jz	$_157
	mov	qword ptr [r14+0x2F0], 0
$_157:	mov	eax, dword ptr [rbp-0x4]
$_158:	leave
	pop	rbx
	pop	rdi
	pop	rsi
	ret

ClassInit:
	mov	dword ptr [r14+0x1C4], 0
	ret

ClassCheckOpen:
	sub	rsp, 40
	cmp	qword ptr [r14+0x2F0], 0
	jz	$_159
	lea	rdx, [DS0024+rip]
	mov	ecx, 1010
	call	asmerr@PLT
$_159:	add	rsp, 40
	ret


.SECTION .data
	.ALIGN	16

DS0000:
	.byte  0x25, 0x73, 0x20, 0x25, 0x72, 0x20, 0x25, 0x72
	.byte  0x20, 0x25, 0x73, 0x00

DS0001:
	.byte  0x25, 0x73, 0x20, 0x25, 0x72, 0x20, 0x25, 0x73
	.byte  0x00

DS0002:
	.byte  0x70, 0x74, 0x72, 0x20, 0x25, 0x73, 0x00

DS0003:
	.byte  0x25, 0x73, 0x5F, 0x25, 0x73, 0x00

DS0004:
	.byte  0x3A, 0x25, 0x73, 0x2C, 0x20, 0x25, 0x73, 0x00

DS0005:
	.byte  0x3A, 0x25, 0x73, 0x00

DS0006:
	.byte  0x5F, 0x00

DS0007:
	.byte  0x25, 0x73, 0x20, 0x65, 0x71, 0x75, 0x20, 0x3C
	.byte  0x25, 0x73, 0x3E, 0x00

DS0008:
	.byte  0x25, 0x73, 0x56, 0x74, 0x62, 0x6C, 0x20, 0x73
	.byte  0x74, 0x72, 0x75, 0x63, 0x74, 0x00

DS0009:
	.byte  0x56, 0x74, 0x62, 0x6C, 0x00

DS000A:
	.byte  0x25, 0x73, 0x20, 0x3C, 0x3E, 0x00

DS000B:
	.byte  0x54, 0x24, 0x25, 0x75, 0x25, 0x63, 0x25, 0x58
	.byte  0x00

DS000C:
	.byte  0x25, 0x73, 0x20, 0x65, 0x6E, 0x64, 0x73, 0x00

DS000D:
	.byte  0x25, 0x73, 0x20, 0x25, 0x73, 0x20, 0x3F, 0x00

DS000E:
	.byte  0x54, 0x24, 0x30, 0x30, 0x30, 0x30, 0x20, 0x74
	.byte  0x79, 0x70, 0x65, 0x64, 0x65, 0x66, 0x20, 0x70
	.byte  0x72, 0x6F, 0x74, 0x6F, 0x00

DS000F:
	.byte  0x20, 0x73, 0x74, 0x64, 0x63, 0x61, 0x6C, 0x6C
	.byte  0x00

DS0010:
	.byte  0x20, 0x00

DS0011:
	.byte  0x20, 0x3A, 0x70, 0x74, 0x72, 0x00

DS0012:
	.byte  0x2C, 0x00

DS0013:
	.byte  0x25, 0x73, 0x25, 0x73, 0x00

DS0014:
	.byte  0x50, 0x25, 0x73, 0x20, 0x74, 0x79, 0x70, 0x65
	.byte  0x64, 0x65, 0x66, 0x20, 0x70, 0x74, 0x72, 0x20
	.byte  0x25, 0x73, 0x00

DS0015:
	.byte  0x25, 0x73, 0x20, 0x50, 0x25, 0x73, 0x20, 0x3F
	.byte  0x00

DS0016:
	.byte  0x5F, 0x25, 0x75, 0x2C, 0x20, 0x00

DS0017:
	.byte  0x74, 0x68, 0x69, 0x73, 0x00

DS0018:
	.byte  0x3A, 0x76, 0x61, 0x72, 0x61, 0x72, 0x67, 0x00

DS0019:
	.byte  0x25, 0x73, 0x20, 0x6D, 0x61, 0x63, 0x72, 0x6F
	.byte  0x20, 0x25, 0x73, 0x00

DS001A:
	.byte  0x65, 0x78, 0x69, 0x74, 0x6D, 0x3C, 0x3E, 0x00

DS001B:
	.byte  0x65, 0x78, 0x69, 0x74, 0x6D, 0x00

DS001C:
	.byte  0x72, 0x65, 0x74, 0x6D, 0x00

DS001D:
	.byte  0x65, 0x6E, 0x64, 0x6D, 0x00

DS001E:
	.byte  0x25, 0x73, 0x56, 0x74, 0x62, 0x6C, 0x20, 0x65
	.byte  0x6E, 0x64, 0x73, 0x00

DS001F:
	.byte  0x25, 0x72, 0x00

DS0020:
	.byte  0x25, 0x73, 0x20, 0x73, 0x74, 0x72, 0x75, 0x63
	.byte  0x74, 0x20, 0x25, 0x64, 0x00

DS0021:
	.byte  0x25, 0x73, 0x20, 0x73, 0x74, 0x72, 0x75, 0x63
	.byte  0x74, 0x00

DS0022:
	.byte  0x6C, 0x70, 0x56, 0x74, 0x62, 0x6C, 0x00

DS0023:
	.byte  0x6C, 0x70, 0x56, 0x74, 0x62, 0x6C, 0x20, 0x70
	.byte  0x74, 0x72, 0x20, 0x25, 0x73, 0x56, 0x74, 0x62
	.byte  0x6C, 0x20, 0x3F, 0x00

DS0024:
	.byte  0x2E, 0x63, 0x6F, 0x6D, 0x64, 0x65, 0x66, 0x2D
	.byte  0x2E, 0x63, 0x6C, 0x61, 0x73, 0x73, 0x64, 0x65
	.byte  0x66, 0x2D, 0x2E, 0x65, 0x6E, 0x64, 0x73, 0x00


.att_syntax prefix
