

.intel_syntax noprefix

.global LstWrite
.global LstWriteSrcLine
.global LstPrintf
.global LstNL
.global LstSetPosition
.global LstWriteCRef
.global ListingDirective
.global ListMacroDirective
.global LstInit
.global list_pos

.extern szTime
.extern szDate
.extern cp_logo
.extern SetBitMask
.extern CurrStruct
.extern UseSavedState
.extern LineStoreCurr
.extern GetFName
.extern get_curr_srcfile
.extern GetCurrOffset
.extern GetSymOfssize
.extern GetResWName
.extern MemFree
.extern MemAlloc
.extern tvfprintf
.extern tsprintf
.extern asmerr
.extern LastCodeBufSize
.extern MacroLevel
.extern Options
.extern Parse_Pass
.extern SymGetCount
.extern SymGetAll
.extern SymLookup
.extern tstrcmp
.extern tstrcpy
.extern tstrlen
.extern tmemset
.extern qsort
.extern fseek
.extern fwrite


.SECTION .text
	.ALIGN	16

LstWrite:
	mov	qword ptr [rsp+0x8], rcx
	mov	qword ptr [rsp+0x10], rdx
	mov	qword ptr [rsp+0x18], r8
	push	rsi
	push	rdi
	push	rbx
	push	rbp
	mov	rbp, rsp
	sub	rsp, 152
	mov	rax, qword ptr [rbp+0x38]
	mov	qword ptr [rbp-0x10], rax
	test	byte ptr [r14], 0x08
	jz	$_001
	cmp	qword ptr [r14+0x1F8], 0
	jz	$_001
	test	byte ptr [r14+0x16], 0x01
	jz	$_002
$_001:	jmp	$_053

$_002:	cmp	dword ptr [r14+0x60], 0
	jz	$_003
	test	byte ptr [r14], 0x20
	jnz	$_003
	jmp	$_053

$_003:	cmp	dword ptr [MacroLevel+rip], 0
	jz	$_007
	jmp	$_006

$_004:	jmp	$_053

$_005:	jmp	$_007

$_006:	cmp	dword ptr [r14+0x1CC], 0
	jz	$_004
	cmp	dword ptr [r14+0x1CC], 1
	jz	$_005
$_007:	or	byte ptr [r14+0x16], 0x01
	mov	rax, qword ptr [r14+0x1D8]
	mov	qword ptr [rbp-0x38], rax
	cmp	dword ptr [Parse_Pass+rip], 0
	jbe	$_011
	cmp	dword ptr [UseSavedState+rip], 0
	jz	$_011
	cmp	dword ptr [r14+0x60], 0
	jnz	$_010
	mov	rcx, qword ptr [LineStoreCurr+rip]
	test	byte ptr [r14+0x16], 0x02
	jnz	$_009
	cmp	dword ptr [Parse_Pass+rip], 1
	jnz	$_008
	test	byte ptr [Options+0x6+rip], 0x02
	jz	$_008
	mov	eax, dword ptr [list_pos+rip]
	mov	dword ptr [rcx+0x1C], eax
	jmp	$_009

$_008:	mov	eax, dword ptr [rcx+0x1C]
	mov	dword ptr [list_pos+rip], eax
$_009:	lea	rax, [rcx+0x20]
	mov	qword ptr [rbp-0x38], rax
	cmp	qword ptr [r14+0x48], 0
	jz	$_010
	mov	rbx, rax
	mov	rcx, rax
	call	tstrlen@PLT
	mov	byte ptr [rbx+rax], 59
	mov	qword ptr [r14+0x48], 0
$_010:	xor	edx, edx
	mov	esi, dword ptr [list_pos+rip]
	mov	rdi, qword ptr [r14+0x1F8]
	call	fseek@PLT
$_011:	mov	qword ptr [rbp-0x70], 0
	mov	r8d, 32
	mov	edx, 32
	lea	rcx, [rbp-0x68]
	call	tmemset@PLT
	call	get_curr_srcfile@PLT
	mov	dword ptr [rbp-0x20], eax
	mov	rbx, qword ptr [r14+0x38]
	mov	eax, dword ptr [rbp+0x28]
	jmp	$_044

$_012:	cmp	dword ptr [Parse_Pass+rip], 0
	jnz	$_013
	test	byte ptr [Options+0x6+rip], 0x02
	je	$_045
$_013:	call	GetCurrOffset@PLT
	mov	dword ptr [rbp-0x4], eax
	mov	r8d, dword ptr [rbp+0x30]
	lea	rdx, [DS0000+rip]
	lea	rcx, [rbp-0x68]
	call	tsprintf@PLT
	mov	byte ptr [rbp-0x60], 32
	test	rbx, rbx
	je	$_045
	cmp	dword ptr [Parse_Pass+rip], 0
	je	$_045
	mov	dword ptr [rbp-0x14], 9
	lea	rdi, [rbp-0x5E]
	mov	rdx, qword ptr [rbx+0x78]
	cmp	qword ptr [rdx+0x10], 0
	jz	$_014
	test	byte ptr [rdx+0x1C], 0x20
	jnz	$_018
$_014:	mov	eax, 12336
	mov	ecx, dword ptr [rbp-0x4]
	jmp	$_016

$_015:	stosw
	inc	dword ptr [rbp+0x30]
	dec	dword ptr [rbp-0x14]
$_016:	cmp	dword ptr [rbp+0x30], ecx
	jnc	$_017
	cmp	dword ptr [rbp-0x14], 0
	jnz	$_015
$_017:	jmp	$_045

$_018:	mov	eax, dword ptr [rdx+0xC]
	sub	eax, dword ptr [rdx+0x8]
	mov	ecx, dword ptr [rbp-0x4]
	sub	ecx, dword ptr [rbp+0x30]
	sub	eax, ecx
	mov	dword ptr [rbp-0x1C], eax
	cmp	dword ptr [Options+0x8C+rip], 1
	jnz	$_022
	add	eax, dword ptr [LastCodeBufSize+rip]
	cmp	eax, 0
	jl	$_045
	mov	rsi, qword ptr [rdx+0x10]
	add	rsi, rax
	jmp	$_020

$_019:	movzx	eax, byte ptr [rsi]
	inc	rsi
	mov	r8d, eax
	lea	rdx, [DS0001+rip]
	mov	rcx, rdi
	call	tsprintf@PLT
	add	rdi, 2
	inc	dword ptr [rbp-0x1C]
	inc	dword ptr [rbp+0x30]
	dec	dword ptr [rbp-0x14]
$_020:	cmp	dword ptr [rbp-0x1C], 0
	jge	$_021
	cmp	dword ptr [rbp-0x14], 0
	jnz	$_019
$_021:	jmp	$_023

$_022:	cmp	dword ptr [rbp-0x1C], 0
	jge	$_023
	mov	dword ptr [rbp-0x1C], 0
$_023:	mov	rdx, qword ptr [rbx+0x78]
	mov	rsi, qword ptr [rdx+0x10]
	mov	eax, dword ptr [rbp-0x1C]
	add	rsi, rax
	jmp	$_025

$_024:	movzx	eax, byte ptr [rsi]
	inc	rsi
	mov	r8d, eax
	lea	rdx, [DS0001+rip]
	mov	rcx, rdi
	call	tsprintf@PLT
	add	rdi, 2
	inc	dword ptr [rbp-0x1C]
	inc	dword ptr [rbp+0x30]
	dec	dword ptr [rbp-0x14]
$_025:	mov	eax, dword ptr [rbp-0x4]
	cmp	dword ptr [rbp+0x30], eax
	jnc	$_026
	cmp	dword ptr [rbp-0x14], 0
	jnz	$_024
$_026:	mov	byte ptr [rdi], 32
	jmp	$_045

$_027:	mov	edi, 1
	mov	rsi, qword ptr [rbp-0x10]
	cmp	qword ptr [rsi+0x40], 0
	jz	$_028
	cmp	qword ptr [rsi+0x40], rbx
	jnz	$_028
	call	GetCurrOffset@PLT
	mov	r8, rax
	lea	rdx, [DS0000+rip]
	lea	rcx, [rbp-0x68]
	call	tsprintf@PLT
	mov	edi, 10
$_028:	mov	byte ptr [rbp+rdi-0x68], 61
	cmp	dword ptr [rsi+0x34], 0
	jz	$_030
	cmp	dword ptr [rsi+0x34], -1
	jnz	$_029
	cmp	dword ptr [rsi+0x30], 0
	jl	$_030
$_029:	mov	r8, qword ptr [rsi+0x30]
	lea	rdx, [DS0002+rip]
	lea	rcx, [rbp+rdi-0x66]
	call	tsprintf@PLT
	jmp	$_031

$_030:	mov	r8d, dword ptr [rsi+0x30]
	lea	rdx, [DS0003+rip]
	lea	rcx, [rbp+rdi-0x66]
	call	tsprintf@PLT
$_031:	mov	byte ptr [rbp+rdi-0x52], 32
	jmp	$_045

$_032:	mov	byte ptr [rbp-0x67], 61
	mov	rcx, qword ptr [rbp-0x10]
	mov	rsi, qword ptr [rcx+0x30]
	lea	rdi, [rbp-0x65]
	lea	rbx, [rbp-0x70]
$_033:	cmp	byte ptr [rsi], 0
	jz	$_035
	lea	rax, [rbx+0x24]
	cmp	rdi, rax
	jc	$_034
	mov	eax, 48
	add	eax, 15
	and	eax, 0xFFFFFFF0
	sub	rsp, rax
	lea	rax, [rsp+0x20]
	mov	qword ptr [rbx], rax
	mov	rbx, rax
	mov	qword ptr [rbx], 0
	mov	r8d, 32
	mov	edx, 32
	lea	rcx, [rbx+0x8]
	call	tmemset@PLT
	lea	rdi, [rbx+0xB]
$_034:	movsb
	jmp	$_033

$_035:	jmp	$_045

$_036:	mov	byte ptr [rbp-0x67], 62
	mov	rax, qword ptr [rbp+0x38]
	mov	qword ptr [rbp-0x38], rax
	jmp	$_045

$_037:	call	GetCurrOffset@PLT
	mov	dword ptr [rbp+0x30], eax
$_038:	mov	r8d, dword ptr [rbp+0x30]
	lea	rdx, [DS0000+rip]
	lea	rcx, [rbp-0x68]
	call	tsprintf@PLT
	mov	byte ptr [rbp-0x60], 32
	jmp	$_045

$_039:	test	rbx, rbx
	jnz	$_040
	cmp	qword ptr [rbp+0x38], 0
	jz	$_041
$_040:	mov	r8d, dword ptr [rbp+0x30]
	lea	rdx, [DS0000+rip]
	lea	rcx, [rbp-0x68]
	call	tsprintf@PLT
	mov	byte ptr [rbp-0x60], 32
$_041:	jmp	$_045

$_042:	mov	rcx, qword ptr [rbp-0x38]
	mov	dl, byte ptr [rcx]
	test	dl, dl
	jnz	$_043
	cmp	qword ptr [r14+0x48], 0
	jnz	$_043
	mov	eax, dword ptr [r14+0x10]
	cmp	dword ptr [rbp-0x20], eax
	jnz	$_043
	mov	rcx, qword ptr [r14+0x1F8]
	mov	edx, 1
	mov	esi, 1
	lea	rdi, [DS0004+rip]
	call	fwrite@PLT
	add	dword ptr [list_pos+rip], 1
	jmp	$_053

$_043:	jmp	$_045

$_044:	cmp	eax, 0
	je	$_012
	cmp	eax, 1
	je	$_013
	cmp	eax, 2
	je	$_027
	cmp	eax, 3
	je	$_032
	cmp	eax, 8
	je	$_036
	cmp	eax, 7
	je	$_037
	cmp	eax, 6
	je	$_038
	cmp	eax, 4
	je	$_039
	jmp	$_042

$_045:	mov	dword ptr [rbp-0x1C], 32
	cmp	dword ptr [r14+0x60], 0
	jz	$_046
	mov	byte ptr [rbp-0x4C], 42
$_046:	cmp	dword ptr [MacroLevel+rip], 0
	jz	$_047
	mov	r8d, dword ptr [MacroLevel+rip]
	lea	rdx, [DS0005+rip]
	lea	rcx, [rbp-0x4B]
	call	tsprintf@PLT
	mov	dword ptr [rbp-0x14], eax
	mov	byte ptr [rbp+rax-0x4B], 32
$_047:	mov	eax, dword ptr [r14+0x10]
	cmp	dword ptr [rbp-0x20], eax
	jz	$_048
	mov	byte ptr [rbp-0x4A], 67
$_048:	mov	rcx, qword ptr [r14+0x1F8]
	mov	edx, dword ptr [rbp-0x1C]
	mov	esi, 1
	lea	rdi, [rbp-0x68]
	call	fwrite@PLT
	mov	rcx, qword ptr [rbp-0x38]
	call	tstrlen@PLT
	mov	dword ptr [rbp-0x14], eax
	mov	dword ptr [rbp-0x18], 0
	cmp	qword ptr [r14+0x48], 0
	jz	$_049
	mov	rcx, qword ptr [r14+0x48]
	call	tstrlen@PLT
	mov	dword ptr [rbp-0x18], eax
$_049:	mov	eax, dword ptr [rbp-0x18]
	add	eax, dword ptr [rbp-0x14]
	add	eax, 33
	add	dword ptr [list_pos+rip], eax
	cmp	dword ptr [rbp-0x14], 0
	jz	$_050
	mov	rcx, qword ptr [r14+0x1F8]
	mov	edx, dword ptr [rbp-0x14]
	mov	esi, 1
	mov	rdi, qword ptr [rbp-0x38]
	call	fwrite@PLT
$_050:	cmp	dword ptr [rbp-0x18], 0
	jz	$_051
	mov	rcx, qword ptr [r14+0x1F8]
	mov	edx, dword ptr [rbp-0x18]
	mov	esi, 1
	mov	rdi, qword ptr [r14+0x48]
	call	fwrite@PLT
$_051:	mov	rcx, qword ptr [r14+0x1F8]
	mov	edx, 1
	mov	esi, 1
	lea	rdi, [DS0004+rip]
	call	fwrite@PLT
	mov	rbx, qword ptr [rbp-0x70]
$_052:	test	rbx, rbx
	jz	$_053
	mov	rcx, qword ptr [r14+0x1F8]
	mov	edx, 32
	mov	esi, 1
	lea	rdi, [rbx+0x8]
	call	fwrite@PLT
	mov	rcx, qword ptr [r14+0x1F8]
	mov	edx, 1
	mov	esi, 1
	lea	rdi, [DS0004+rip]
	call	fwrite@PLT
	add	dword ptr [list_pos+rip], 33
	mov	rbx, qword ptr [rbx]
	jmp	$_052

$_053:
	leave
	pop	rbx
	pop	rdi
	pop	rsi
	ret

LstWriteSrcLine:
	sub	rsp, 40
	xor	r8d, r8d
	xor	edx, edx
	mov	ecx, 5
	call	LstWrite
	add	rsp, 40
	ret

LstPrintf:
	mov	qword ptr [rsp+0x8], rcx
	mov	qword ptr [rsp+0x10], rdx
	mov	qword ptr [rsp+0x18], r8
	mov	qword ptr [rsp+0x20], r9
	push	rbp
	mov	rbp, rsp
	sub	rsp, 32
	cmp	qword ptr [r14+0x1F8], 0
	jz	$_054
	lea	r8, [rbp+0x18]
	mov	rdx, qword ptr [rbp+0x10]
	mov	rcx, qword ptr [r14+0x1F8]
	call	tvfprintf@PLT
	add	dword ptr [list_pos+rip], eax
$_054:	leave
	ret

LstNL:
	push	rsi
	push	rdi
	sub	rsp, 8
	cmp	qword ptr [r14+0x1F8], 0
	jz	$_055
	mov	rcx, qword ptr [r14+0x1F8]
	mov	edx, 1
	mov	esi, 1
	lea	rdi, [DS0004+rip]
	call	fwrite@PLT
	add	dword ptr [list_pos+rip], 1
$_055:	add	rsp, 8
	pop	rdi
	pop	rsi
	ret

LstSetPosition:
	push	rsi
	push	rdi
	sub	rsp, 8
	cmp	qword ptr [r14+0x1F8], 0
	jz	$_056
	cmp	dword ptr [Parse_Pass+rip], 0
	jbe	$_056
	cmp	dword ptr [UseSavedState+rip], 0
	jz	$_056
	cmp	dword ptr [r14+0x60], 0
	jnz	$_056
	mov	rcx, qword ptr [LineStoreCurr+rip]
	mov	eax, dword ptr [rcx+0x1C]
	mov	dword ptr [list_pos+rip], eax
	xor	edx, edx
	mov	esi, dword ptr [list_pos+rip]
	mov	rdi, qword ptr [r14+0x1F8]
	call	fseek@PLT
	or	byte ptr [r14+0x16], 0x02
$_056:	add	rsp, 8
	pop	rdi
	pop	rsi
	ret

$_057:
	mov	qword ptr [rsp+0x18], r8
	push	rbp
	mov	rbp, rsp
	sub	rsp, 48
	add	ecx, dword ptr [rbp+0x20]
	cmp	ecx, 32
	jc	$_058
	xor	eax, eax
	jmp	$_059

$_058:	lea	rax, [dots+rip]
	lea	rax, [rax+rcx+0x1]
$_059:	lea	ecx, [rcx-0x27]
	mov	qword ptr [rsp+0x28], rax
	mov	dword ptr [rsp+0x20], ecx
	mov	r9, rdx
	xor	r8d, r8d
	mov	edx, dword ptr [rbp+0x20]
	lea	rcx, [DS0006+rip]
	call	LstPrintf
	leave
	ret

$_060:
	xor	eax, eax
	jmp	$_070

$_061:	mov	eax, 269
	jmp	$_071

$_062:	mov	eax, 271
	jmp	$_071

$_063:	mov	eax, 274
	jmp	$_071

$_064:	mov	eax, 277
	jmp	$_071

$_065:	mov	eax, 278
	jmp	$_071

$_066:	mov	eax, 281
	jmp	$_071

$_067:	mov	eax, 283
	jmp	$_071

$_068:	mov	eax, 286
	jmp	$_071

$_069:	mov	eax, 288
	jmp	$_071

$_070:	cmp	ecx, 1
	jz	$_061
	cmp	ecx, 2
	jz	$_062
	cmp	ecx, 4
	jz	$_063
	cmp	ecx, 6
	jz	$_064
	cmp	ecx, 8
	jz	$_065
	cmp	ecx, 10
	jz	$_066
	cmp	ecx, 16
	jz	$_067
	cmp	ecx, 32
	jz	$_068
	cmp	ecx, 64
	jz	$_069
$_071:	ret

$_072:
	push	rbp
	mov	rbp, rsp
	sub	rsp, 32
	mov	eax, ecx
	cmp	ecx, 63
	jnz	$_073
	mov	ecx, 64
	jmp	$_074

$_073:	and	ecx, 0x1F
	inc	ecx
$_074:	test	eax, 0x60
	jz	$_075
	cmp	ecx, 16
	jbe	$_076
$_075:	call	$_060
	jmp	$_091

$_076:	test	eax, 0x20
	jz	$_084
	xor	eax, eax
	jmp	$_082

$_077:	mov	eax, 273
	jmp	$_083

$_078:	mov	eax, 276
	jmp	$_083

$_079:	mov	eax, 280
	jmp	$_083

$_080:	mov	eax, 282
	jmp	$_083

$_081:	mov	eax, 285
	jmp	$_083

$_082:	cmp	ecx, 2
	jz	$_077
	cmp	ecx, 4
	jz	$_078
	cmp	ecx, 8
	jz	$_079
	cmp	ecx, 10
	jz	$_080
	cmp	ecx, 16
	jz	$_081
$_083:	jmp	$_091

$_084:	xor	eax, eax
	jmp	$_090

$_085:	mov	eax, 270
	jmp	$_091

$_086:	mov	eax, 272
	jmp	$_091

$_087:	mov	eax, 275
	jmp	$_091

$_088:	mov	eax, 279
	jmp	$_091

$_089:	mov	eax, 284
	jmp	$_091

$_090:	cmp	ecx, 1
	jz	$_085
	cmp	ecx, 2
	jz	$_086
	cmp	ecx, 4
	jz	$_087
	cmp	ecx, 8
	jz	$_088
	cmp	ecx, 16
	jz	$_089
$_091:	leave
	ret

$_092:
	push	rsi
	push	rdi
	push	rbx
	push	rbp
	mov	rbp, rsp
	sub	rsp, 40
	mov	rsi, rcx
	mov	rbx, rdx
	test	byte ptr [rsi+0x1E], 0x80
	jnz	$_093
	movzx	ecx, byte ptr [rsi+0x1E]
	call	$_072
	mov	rdx, rbx
	mov	ecx, eax
	call	GetResWName@PLT
	jmp	$_110

$_093:	movzx	eax, byte ptr [rsi+0x1E]
	cmp	byte ptr [rsi+0x1D], 5
	jnz	$_094
	cmp	byte ptr [rsi+0x49], 0
	jz	$_094
	mov	al, 195
$_094:	lea	rdx, [mtbuf+rip]
	jmp	$_108

$_095:	mov	edi, 290
	cmp	byte ptr [rsi+0x48], 2
	jnc	$_096
	cmp	byte ptr [rsi+0x21], 0
	jz	$_096
	mov	edi, 291
$_096:	test	rbx, rbx
	jz	$_101
	movzx	eax, byte ptr [rsi+0x49]
	mov	dword ptr [rbp-0x4], eax
$_097:	cmp	dword ptr [rbp-0x4], 0
	jz	$_098
	mov	r9d, 335
	mov	r8d, edi
	lea	rdx, [DS0007+rip]
	mov	rcx, rbx
	call	tsprintf@PLT
	add	rbx, rax
	dec	dword ptr [rbp-0x4]
	jmp	$_097

$_098:	cmp	byte ptr [rsi+0x1D], 7
	jnz	$_100
	cmp	word ptr [rsi+0x6E], 3
	jnz	$_100
	cmp	qword ptr [rsi+0x50], 0
	jz	$_099
	mov	rcx, qword ptr [rsi+0x50]
	mov	rdx, qword ptr [rcx+0x8]
	mov	rcx, rbx
	call	tstrcpy@PLT
	jmp	$_100

$_099:	test	byte ptr [rsi+0x4A], 0x80
	jnz	$_100
	movzx	ecx, byte ptr [rsi+0x4A]
	call	$_072
	mov	r8, rax
	lea	rdx, [DS0008+rip]
	mov	rcx, rbx
	call	tsprintf@PLT
$_100:	mov	rax, rbx
	jmp	$_110

$_101:	mov	ecx, edi
	call	GetResWName@PLT
	jmp	$_110

$_102:	mov	rbx, rdx
	mov	r8d, 291
	lea	rdx, [DS0009+rip]
	mov	rcx, rbx
	call	tsprintf@PLT
	mov	rax, rbx
	jmp	$_110

$_103:	mov	rbx, rdx
	mov	r8d, 290
	lea	rdx, [DS0009+rip]
	mov	rcx, rbx
	call	tsprintf@PLT
	mov	rax, rbx
	jmp	$_110

$_104:	mov	rcx, qword ptr [rsi+0x28]
	mov	rax, qword ptr [rcx+0x8]
	cmp	byte ptr [rax], 0
	jz	$_105
	jmp	$_110

$_105:	mov	rcx, qword ptr [rsi+0x28]
	call	$_092
	jmp	$_110

$_106:	lea	rax, [DS000A+rip]
	jmp	$_110

$_107:	lea	rax, [DS000B+rip]
	jmp	$_110

	jmp	$_109

$_108:	cmp	eax, 195
	je	$_095
	cmp	eax, 130
	jz	$_102
	cmp	eax, 129
	jz	$_103
	cmp	eax, 196
	jz	$_104
	cmp	eax, 193
	jz	$_106
	cmp	eax, 192
	jz	$_107
$_109:	lea	rax, [DS000C+rip]
$_110:	leave
	pop	rbx
	pop	rdi
	pop	rsi
	ret

$_111:
	movzx	eax, byte ptr [rcx+0x1F]
	cmp	eax, 0
	jbe	$_112
	cmp	eax, 10
	ja	$_112
	lea	rax, [rax+0x156]
	jmp	$_113

$_112:	xor	eax, eax
$_113:	ret

$_114:
	push	rbx
	push	rbp
	mov	rbp, rsp
	sub	rsp, 40
	mov	rbx, rcx
	xor	r8d, r8d
	mov	rdx, qword ptr [rbx+0x8]
	mov	ecx, dword ptr [rbx+0x14]
	call	$_057
	mov	edx, 605
	test	byte ptr [rbx+0x48], 0x02
	jz	$_115
	mov	edx, 570
$_115:	lea	rcx, [DS0009+0x2+rip]
	call	LstPrintf
	call	LstNL
	leave
	pop	rbx
	ret

$_116:
	mov	qword ptr [rsp+0x18], r8
	push	rsi
	push	rdi
	push	rbx
	push	rbp
	mov	rbp, rsp
	sub	rsp, 40
	mov	rdi, rcx
	mov	rbx, rdx
	mov	rsi, qword ptr [rdi+0x78]
	test	rbx, rbx
	jnz	$_117
	mov	rbx, qword ptr [rdi+0x8]
$_117:	mov	rcx, rbx
	call	tstrlen@PLT
	xor	r8d, r8d
	mov	rdx, rbx
	mov	ecx, eax
	call	$_057
	cmp	byte ptr [rsi+0x10], 1
	jbe	$_118
	movzx	r8d, byte ptr [rsi+0x10]
	mov	edx, dword ptr [rdi+0x60]
	lea	rcx, [DS000D+rip]
	call	LstPrintf
	jmp	$_119

$_118:	mov	edx, dword ptr [rdi+0x60]
	lea	rcx, [DS000E+rip]
	call	LstPrintf
$_119:	call	LstNL
	add	dword ptr [prefix+rip], 2
	mov	rbx, qword ptr [rsi]
$_120:	test	rbx, rbx
	je	$_126
	cmp	byte ptr [rbx+0x1E], 196
	jnz	$_121
	cmp	byte ptr [rbx+0x88], 0
	jnz	$_121
	mov	ecx, dword ptr [rbx+0x30]
	add	ecx, dword ptr [rbp+0x38]
	mov	r8d, ecx
	mov	rdx, qword ptr [rbx+0x8]
	mov	rcx, qword ptr [rbx+0x28]
	call	$_116
	jmp	$_125

$_121:	mov	rcx, qword ptr [rbx+0x8]
	cmp	byte ptr [rcx], 0
	jnz	$_122
	cmp	byte ptr [rbx+0x1E], 196
	jnz	$_125
$_122:	mov	r8d, dword ptr [prefix+rip]
	mov	rdx, qword ptr [rbx+0x8]
	mov	ecx, dword ptr [rbx+0x14]
	call	$_057
	xor	edx, edx
	mov	rcx, rbx
	call	$_092
	mov	ecx, dword ptr [rbx+0x30]
	add	ecx, dword ptr [rdi+0x30]
	add	ecx, dword ptr [rbp+0x38]
	cmp	byte ptr [rbx+0x1E], 193
	jnz	$_123
	movzx	ecx, byte ptr [rbx+0x5A]
$_123:	mov	r8, rax
	mov	edx, ecx
	lea	rcx, [DS000F+rip]
	call	LstPrintf
	test	byte ptr [rbx+0x10], 0x40
	jz	$_124
	mov	edx, dword ptr [rbx+0x68]
	lea	rcx, [DS0010+rip]
	call	LstPrintf
$_124:	call	LstNL
$_125:	mov	rbx, qword ptr [rbx+0x80]
	jmp	$_120

$_126:
	sub	dword ptr [prefix+rip], 2
	leave
	pop	rbx
	pop	rdi
	pop	rsi
	ret

$_127:
	push	rsi
	push	rdi
	push	rbx
	push	rbp
	mov	rbp, rsp
	sub	rsp, 56
	mov	rdi, rcx
	xor	r8d, r8d
	mov	rdx, qword ptr [rdi+0x8]
	mov	ecx, dword ptr [rdi+0x14]
	call	$_057
	mov	rsi, qword ptr [rdi+0x78]
	xor	edx, edx
	mov	rbx, qword ptr [rsi]
$_128:	test	rbx, rbx
	jz	$_129
	mov	rbx, qword ptr [rbx+0x80]
	inc	edx
	jmp	$_128

$_129:
	imul	ecx, dword ptr [rdi+0x60], 8
	mov	r8d, edx
	mov	edx, ecx
	lea	rcx, [DS0011+rip]
	call	LstPrintf
	call	LstNL
	mov	rbx, qword ptr [rsi]
$_130:	test	rbx, rbx
	je	$_134
	mov	r8d, 2
	mov	rdx, qword ptr [rbx+0x8]
	mov	ecx, dword ptr [rbx+0x14]
	call	$_057
	lea	rdx, [rbp-0x8]
	mov	rcx, rbx
	call	SetBitMask@PLT
	lea	rcx, [rbx+0x88]
	cmp	byte ptr [rbx+0x88], 0
	jnz	$_131
	mov	ecx, dword ptr [rdi+0x60]
	call	$_060
	xor	edx, edx
	mov	ecx, eax
	call	GetResWName@PLT
	mov	rcx, rax
$_131:	cmp	dword ptr [rdi+0x60], 4
	jbe	$_132
	mov	qword ptr [rsp+0x20], rcx
	mov	r9, qword ptr [rbp-0x8]
	movzx	r8d, byte ptr [rbx+0x5A]
	movzx	edx, byte ptr [rbx+0x59]
	lea	rcx, [DS0012+rip]
	call	LstPrintf
	jmp	$_133

$_132:	mov	qword ptr [rsp+0x20], rcx
	mov	r9, qword ptr [rbp-0x8]
	movzx	r8d, byte ptr [rbx+0x5A]
	movzx	edx, byte ptr [rbx+0x59]
	lea	rcx, [DS0013+rip]
	call	LstPrintf
$_133:	call	LstNL
	mov	rbx, qword ptr [rbx+0x80]
	jmp	$_130

$_134:
	leave
	pop	rbx
	pop	rdi
	pop	rsi
	ret

$_135:
	push	rsi
	push	rdi
	push	rbx
	push	rbp
	mov	rbp, rsp
	sub	rsp, 40
	mov	rsi, rcx
	xor	r8d, r8d
	mov	rdx, qword ptr [rsi+0x8]
	mov	ecx, dword ptr [rsi+0x14]
	call	$_057
	mov	rdi, qword ptr [r14+0x1E0]
	mov	byte ptr [rdi], 0
	mov	rbx, qword ptr [rsi+0x50]
	cmp	byte ptr [rsi+0x1E], 128
	jnz	$_138
	test	rbx, rbx
	jz	$_138
	mov	r8d, 605
	lea	rdx, [DS0007+0x3+rip]
	mov	rcx, rdi
	call	tsprintf@PLT
	add	rdi, rax
	mov	rcx, qword ptr [rbx+0x8]
	cmp	byte ptr [rcx], 0
	jz	$_136
	mov	r8, rcx
	lea	rdx, [DS0014+rip]
	mov	rcx, rdi
	call	tsprintf@PLT
	add	rdi, rax
$_136:	mov	rcx, rbx
	call	$_111
	mov	ecx, 290
	cmp	byte ptr [rsi+0x48], 2
	jnc	$_137
	cmp	byte ptr [rbx+0x21], 0
	jz	$_137
	mov	ecx, 291
$_137:	mov	r9d, eax
	mov	r8d, ecx
	lea	rdx, [DS0015+rip]
	mov	rcx, rdi
	call	tsprintf@PLT
	jmp	$_139

$_138:	mov	rdx, rdi
	mov	rcx, rsi
	call	$_092
$_139:	mov	r8, qword ptr [r14+0x1E0]
	mov	edx, dword ptr [rsi+0x60]
	lea	rcx, [DS0013+0xA+rip]
	call	LstPrintf
	call	LstNL
	leave
	pop	rbx
	pop	rdi
	pop	rsi
	ret

$_140:
	mov	qword ptr [rsp+0x10], rdx
	push	rsi
	push	rdi
	push	rbx
	push	rbp
	mov	rbp, rsp
	sub	rsp, 72
	mov	rsi, rcx
	mov	rdi, qword ptr [rsi+0x78]
	mov	rax, qword ptr [rbp+0x30]
	cmp	qword ptr [rdi], rax
	jne	$_165
	xor	r8d, r8d
	mov	rdx, qword ptr [rsi+0x8]
	mov	ecx, dword ptr [rsi+0x14]
	call	$_057
	mov	edx, 16
	mov	cl, byte ptr [rdi+0x1D]
	shl	edx, cl
	lea	rcx, [DS0016+rip]
	call	LstPrintf
	mov	edx, dword ptr [rsi+0x60]
	cmp	byte ptr [rdi+0x1D], 1
	jc	$_141
	lea	rcx, [DS0017+rip]
	call	LstPrintf
	jmp	$_142

$_141:	lea	rcx, [DS0018+rip]
	call	LstPrintf
$_142:	xor	ecx, ecx
	xor	edx, edx
	movzx	eax, byte ptr [rdi+0x1F]
	jmp	$_151

$_143:	mov	edx, 269
	jmp	$_152

$_144:	mov	edx, 271
	jmp	$_152

$_145:	mov	edx, 274
	jmp	$_152

$_146:	mov	edx, 278
	jmp	$_152

$_147:	lea	rcx, [DS0019+rip]
	jmp	$_152

$_148:	mov	edx, 388
	jmp	$_152

$_149:	lea	rcx, [DS001A+rip]
	jmp	$_152

$_150:	mov	ecx, eax
	mov	edx, 1
	shl	edx, cl
	mov	r8d, edx
	lea	rdx, [DS0005+rip]
	lea	rcx, [rbp-0x20]
	call	tsprintf@PLT
	lea	rcx, [rbp-0x20]
	xor	edx, edx
	jmp	$_152

$_151:	cmp	eax, 0
	jz	$_143
	cmp	eax, 1
	jz	$_144
	cmp	eax, 2
	jz	$_145
	cmp	eax, 3
	jz	$_146
	cmp	eax, 4
	jz	$_147
	cmp	eax, 8
	jz	$_148
	cmp	eax, 255
	jz	$_149
	jmp	$_150

$_152:	test	edx, edx
	jz	$_153
	lea	rcx, [DS001B+rip]
	call	LstPrintf
	jmp	$_154

$_153:	mov	rdx, rcx
	lea	rcx, [DS001C+rip]
	call	LstPrintf
$_154:	xor	edx, edx
	movzx	eax, byte ptr [rdi+0x5C]
	jmp	$_160

$_155:	lea	rcx, [DS001D+rip]
	jmp	$_161

$_156:	lea	rcx, [DS001E+rip]
	jmp	$_161

$_157:	mov	edx, 603
	jmp	$_161

$_158:	lea	rcx, [DS001F+rip]
	jmp	$_161

$_159:	lea	rcx, [DS000C+rip]
	jmp	$_161

$_160:	cmp	eax, 0
	jz	$_155
	cmp	eax, 5
	jz	$_156
	cmp	eax, 2
	jz	$_157
	cmp	eax, 6
	jz	$_158
	jmp	$_159

$_161:	test	edx, edx
	jz	$_162
	lea	rcx, [DS0020+rip]
	call	LstPrintf
	jmp	$_163

$_162:	mov	rdx, rcx
	lea	rcx, [DS0021+rip]
	call	LstPrintf
$_163:	mov	rcx, qword ptr [rdi+0x50]
	test	rcx, rcx
	jz	$_164
	mov	rcx, qword ptr [rcx+0x8]
$_164:	mov	rdx, rcx
	lea	rcx, [DS0022+rip]
	call	LstPrintf
	call	LstNL
$_165:	leave
	pop	rbx
	pop	rdi
	pop	rsi
	ret

$_166:
	mov	qword ptr [rsp+0x10], rdx
	push	rsi
	push	rdi
	push	rbp
	mov	rbp, rsp
	sub	rsp, 32
	mov	rsi, rcx
	xor	r8d, r8d
	mov	rdx, qword ptr [rsi+0x8]
	mov	ecx, dword ptr [rsi+0x14]
	call	$_057
	mov	edx, 615
	lea	rcx, [DS0015+0x5+rip]
	call	LstPrintf
	call	LstNL
	cmp	rsi, qword ptr [r14+0x40]
	jnz	$_169
	mov	rdi, qword ptr [rbp+0x28]
$_167:	test	rdi, rdi
	jz	$_168
	mov	rdx, rsi
	mov	rcx, rdi
	call	$_140
	mov	rdi, qword ptr [rdi+0x80]
	jmp	$_167

$_168:	jmp	$_171

$_169:	mov	rdi, qword ptr [rsi+0x78]
	mov	rdi, qword ptr [rdi]
$_170:	test	rdi, rdi
	jz	$_171
	mov	rdx, rsi
	mov	rcx, qword ptr [rdi+0x8]
	call	$_140
	mov	rdi, qword ptr [rdi]
	jmp	$_170

$_171:
	leave
	pop	rdi
	pop	rsi
	ret

$_172:
	xor	eax, eax
	cmp	byte ptr [rcx+0x1E], 129
	jnz	$_173
	mov	eax, 290
	jmp	$_174

$_173:	cmp	byte ptr [rcx+0x1E], 130
	jnz	$_174
	mov	eax, 291
$_174:	ret

$_175:
	mov	rax, qword ptr [rax+0x40]
	test	rax, rax
	jz	$_176
	mov	rax, qword ptr [rax+0x8]
	jmp	$_177

$_176:	lea	rax, [DS0023+rip]
$_177:	ret

$_178:
	push	rsi
	push	rdi
	push	rbx
	push	rbp
	mov	rbp, rsp
	sub	rsp, 344
	mov	rsi, rcx
	xor	r8d, r8d
	mov	rdx, qword ptr [rsi+0x8]
	mov	ecx, dword ptr [rsi+0x14]
	call	$_057
	mov	rcx, rsi
	call	GetSymOfssize@PLT
	mov	byte ptr [rbp-0x115], al
	lea	rdi, [DS0024+rip]
	cmp	byte ptr [rbp-0x115], 0
	jz	$_179
	lea	rdi, [DS0025+rip]
$_179:	mov	qword ptr [rbp-0x8], rdi
	mov	rcx, rsi
	call	$_172
	mov	ebx, eax
	mov	rax, rsi
	call	$_175
	mov	r9, rax
	mov	r8d, dword ptr [rsi+0x30]
	mov	edx, ebx
	mov	rcx, rdi
	call	LstPrintf
	mov	ecx, 4
	cmp	byte ptr [rbp-0x115], 0
	jbe	$_180
	mov	ecx, 8
$_180:	xor	edx, edx
	cmp	byte ptr [rsi+0x1D], 1
	jnz	$_181
	mov	edx, dword ptr [rsi+0x60]
$_181:	mov	r8d, edx
	mov	edx, ecx
	lea	rcx, [DS0026+rip]
	call	LstPrintf
	test	byte ptr [rsi+0x10], 0x04
	jnz	$_182
	test	byte ptr [rsi+0x11], 0x02
	jz	$_183
	test	byte ptr [rsi+0x4B], 0x02
	jnz	$_183
$_182:	mov	edx, 603
	lea	rcx, [DS0027+rip]
	call	LstPrintf
	jmp	$_186

$_183:	cmp	byte ptr [rsi+0x1D], 1
	jnz	$_184
	lea	rcx, [DS0028+rip]
	call	LstPrintf
	jmp	$_186

$_184:	lea	rcx, [DS0029+rip]
	mov	edx, 4294967289
	test	byte ptr [rsi+0x4B], 0x02
	jnz	$_185
	inc	rcx
	dec	edx
$_185:	mov	r8d, 600
	call	LstPrintf
	mov	rcx, qword ptr [rsi+0x60]
	test	rcx, rcx
	jz	$_186
	lea	rdx, [rcx+0xC]
	lea	rcx, [DS002A+rip]
	call	LstPrintf
$_186:	mov	rcx, rsi
	call	$_111
	mov	rdx, rax
	lea	rcx, [DS0015+0x5+rip]
	call	LstPrintf
	call	LstNL
	cmp	byte ptr [rsi+0x1D], 2
	jnz	$_187
	cmp	qword ptr [rsi+0x68], 0
	jz	$_187
	mov	rbx, qword ptr [rsi+0x68]
	mov	r8d, 2
	mov	rdx, qword ptr [rbx+0x8]
	mov	ecx, dword ptr [rbx+0x14]
	call	$_057
	mov	rcx, rbx
	call	$_172
	mov	dword ptr [rbp-0x114], eax
	mov	rax, rbx
	call	$_175
	mov	r9, rax
	mov	r8d, dword ptr [rbx+0x30]
	mov	edx, dword ptr [rbp-0x114]
	mov	rcx, rdi
	call	LstPrintf
	call	LstNL
$_187:	cmp	byte ptr [rsi+0x1D], 1
	jz	$_188
	test	byte ptr [rsi+0x11], 0x02
	je	$_215
	test	byte ptr [rsi+0x4B], 0x02
	jne	$_215
$_188:	movzx	eax, byte ptr [rsi+0x1F]
	cmp	eax, 3
	jz	$_189
	cmp	eax, 1
	jz	$_189
	cmp	eax, 2
	jz	$_189
	cmp	eax, 8
	jz	$_189
	cmp	eax, 9
	jz	$_189
	cmp	eax, 10
	jz	$_189
	cmp	eax, 7
	jne	$_199
	cmp	byte ptr [r14+0x4], 0
	je	$_199
$_189:	mov	rcx, qword ptr [rsi+0x78]
	mov	dword ptr [rbp-0x11C], 0
	mov	rcx, qword ptr [rcx+0x18]
$_190:	test	rcx, rcx
	jz	$_191
	inc	dword ptr [rbp-0x11C]
	mov	rcx, qword ptr [rcx+0x88]
	jmp	$_190

$_191:	cmp	dword ptr [rbp-0x11C], 0
	je	$_198
	mov	rdi, qword ptr [rsi+0x78]
	mov	ecx, 1
	mov	rdi, qword ptr [rdi+0x18]
$_192:	cmp	ecx, dword ptr [rbp-0x11C]
	jge	$_193
	mov	rdi, qword ptr [rdi+0x88]
	inc	ecx
	jmp	$_192

$_193:	mov	r8d, 2
	mov	rdx, qword ptr [rdi+0x8]
	mov	ecx, dword ptr [rdi+0x14]
	call	$_057
	test	byte ptr [rdi+0x11], 0x10
	jz	$_195
	xor	edx, edx
	mov	rcx, rdi
	call	$_092
	mov	rdx, rax
	lea	rcx, [DS0025+0xC+rip]
	call	LstPrintf
	cmp	byte ptr [rdi+0x1D], 5
	jnz	$_194
	mov	rcx, qword ptr [rsi+0x78]
	mov	ebx, dword ptr [rcx+0x14]
	mov	r8d, dword ptr [rdi+0x30]
	mov	edx, ebx
	lea	rcx, [DS002B+rip]
	call	LstPrintf
$_194:	movzx	edx, byte ptr [rdi+0x58]
	lea	rcx, [DS0015+0x5+rip]
	call	LstPrintf
	jmp	$_197

$_195:	mov	rcx, qword ptr [rsi+0x78]
	mov	ebx, dword ptr [rcx+0x14]
	xor	edx, edx
	mov	rcx, rdi
	call	$_092
	mov	rcx, rax
	test	byte ptr [rdi+0x4B], 0x04
	jz	$_196
	xor	edx, edx
	mov	ecx, 341
	call	GetResWName@PLT
	mov	rcx, rax
$_196:	mov	r9d, dword ptr [rdi+0x30]
	mov	r8d, ebx
	mov	rdx, rcx
	lea	rcx, [DS002C+rip]
	call	LstPrintf
$_197:	call	LstNL
	dec	dword ptr [rbp-0x11C]
	jmp	$_191

$_198:	jmp	$_201

$_199:	mov	rdi, qword ptr [rsi+0x78]
	mov	rdi, qword ptr [rdi+0x18]
$_200:	test	rdi, rdi
	jz	$_201
	mov	r8d, 2
	mov	rdx, qword ptr [rdi+0x8]
	mov	ecx, dword ptr [rdi+0x14]
	call	$_057
	mov	rcx, qword ptr [rsi+0x78]
	mov	ebx, dword ptr [rcx+0x14]
	xor	edx, edx
	mov	rcx, rdi
	call	$_092
	mov	rdx, rax
	mov	eax, dword ptr [rdi+0x30]
	mov	dword ptr [rsp+0x20], eax
	mov	r9d, 43
	mov	r8d, ebx
	lea	rcx, [DS002D+rip]
	call	LstPrintf
	call	LstNL
	mov	rdi, qword ptr [rdi+0x88]
	jmp	$_200

$_201:	mov	rdi, qword ptr [rsi+0x78]
	mov	rdi, qword ptr [rdi+0x20]
$_202:	test	rdi, rdi
	je	$_206
	mov	r8d, 2
	mov	rdx, qword ptr [rdi+0x8]
	mov	ecx, dword ptr [rdi+0x14]
	call	$_057
	test	byte ptr [rdi+0x10], 0x40
	jz	$_203
	xor	edx, edx
	mov	rcx, rdi
	call	$_092
	mov	r9d, dword ptr [rdi+0x68]
	mov	r8, rax
	lea	rdx, [DS002E+rip]
	lea	rcx, [rbp-0x110]
	call	tsprintf@PLT
	jmp	$_204

$_203:	xor	edx, edx
	mov	rcx, rdi
	call	$_092
	mov	rdx, rax
	lea	rcx, [rbp-0x110]
	call	tstrcpy@PLT
$_204:	mov	rcx, qword ptr [rsi+0x78]
	mov	ebx, dword ptr [rcx+0x14]
	mov	ecx, 43
	mov	edx, dword ptr [rdi+0x30]
	cmp	edx, 0
	jge	$_205
	mov	ecx, 45
	neg	edx
$_205:	mov	dword ptr [rsp+0x20], edx
	mov	r9d, ecx
	mov	r8d, ebx
	lea	rdx, [rbp-0x110]
	lea	rcx, [DS002D+rip]
	call	LstPrintf
	call	LstNL
	mov	rdi, qword ptr [rdi+0x88]
	jmp	$_202

$_206:	mov	rdi, qword ptr [rsi+0x78]
	mov	rdi, qword ptr [rdi+0x28]
$_207:	test	rdi, rdi
	je	$_215
	mov	rbx, rdi
$_208:	test	rbx, rbx
	jz	$_214
	cmp	byte ptr [rbx+0x1D], 5
	jz	$_209
	cmp	byte ptr [rbx+0x1D], 10
	jnz	$_210
$_209:	jmp	$_213

$_210:	mov	r8d, 2
	mov	rdx, qword ptr [rbx+0x8]
	mov	ecx, dword ptr [rbx+0x14]
	call	$_057
	mov	rcx, rbx
	call	$_172
	mov	dword ptr [rbp-0x114], eax
	mov	rax, rbx
	call	$_175
	mov	qword ptr [rbp-0x18], rax
	cmp	byte ptr [rbp-0x115], 0
	jz	$_211
	lea	rcx, [DS002F+rip]
	jmp	$_212

$_211:	lea	rcx, [DS0030+rip]
$_212:	mov	r9, qword ptr [rbp-0x18]
	mov	r8d, dword ptr [rbx+0x30]
	mov	edx, dword ptr [rbp-0x114]
	call	LstPrintf
	call	LstNL
$_213:	mov	rbx, qword ptr [rbx]
	jmp	$_208

$_214:	mov	rdi, qword ptr [rdi+0x78]
	jmp	$_207

$_215:
	leave
	pop	rbx
	pop	rdi
	pop	rsi
	ret

$_216:
	push	rsi
	push	rdi
	push	rbx
	push	rbp
	mov	rbp, rsp
	sub	rsp, 40
	mov	rdi, rcx
	movzx	eax, byte ptr [rdi+0x1D]
	jmp	$_237

$_217:	xor	r8d, r8d
	mov	rdx, qword ptr [rdi+0x8]
	mov	ecx, dword ptr [rdi+0x14]
	call	$_057
	test	byte ptr [rdi+0x10], 0x40
	jz	$_218
	xor	edx, edx
	mov	rcx, rdi
	call	$_092
	mov	r9d, dword ptr [rdi+0x68]
	mov	r8, rax
	lea	rdx, [DS002E+rip]
	mov	rcx, qword ptr [r14+0x1E0]
	call	tsprintf@PLT
	mov	ebx, eax
	mov	rdx, qword ptr [r14+0x1E0]
	lea	rcx, [DS0025+0xC+rip]
	call	LstPrintf
	jmp	$_220

$_218:	cmp	byte ptr [rdi+0x1D], 2
	jnz	$_219
	test	byte ptr [rdi+0x4B], 0x01
	jz	$_219
	mov	edx, 599
	lea	rcx, [DS0027+rip]
	call	LstPrintf
	jmp	$_220

$_219:	xor	edx, edx
	mov	rcx, rdi
	call	$_092
	mov	rdx, rax
	lea	rcx, [DS0025+0xC+rip]
	call	LstPrintf
$_220:	cmp	byte ptr [rdi+0x1D], 2
	jnz	$_221
	test	byte ptr [rdi+0x4B], 0x01
	jz	$_221
	mov	eax, dword ptr [rdi+0x60]
	cdq
	div	dword ptr [rdi+0x68]
	mov	edx, eax
	lea	rcx, [DS0017+rip]
	call	LstPrintf
	jmp	$_226

$_221:	cmp	byte ptr [rdi+0x1E], 192
	jnz	$_225
	cmp	dword ptr [rdi+0x34], 0
	jz	$_222
	cmp	dword ptr [rdi+0x34], -1
	jz	$_222
	mov	r8d, dword ptr [rdi+0x30]
	mov	edx, dword ptr [rdi+0x34]
	lea	rcx, [DS0031+rip]
	call	LstPrintf
	jmp	$_224

$_222:	cmp	dword ptr [rdi+0x34], 0
	jge	$_223
	mov	edx, dword ptr [rdi+0x30]
	lea	rcx, [DS0031+0x4+rip]
	call	LstPrintf
	jmp	$_224

$_223:	mov	edx, dword ptr [rdi+0x30]
	lea	rcx, [DS0031+0x4+rip]
	call	LstPrintf
$_224:	jmp	$_226

$_225:	mov	edx, dword ptr [rdi+0x30]
	lea	rcx, [DS0031+0x4+rip]
	call	LstPrintf
$_226:	cmp	qword ptr [rdi+0x40], 0
	jz	$_227
	mov	rax, rdi
	call	$_175
	mov	rdx, rax
	lea	rcx, [DS0014+rip]
	call	LstPrintf
$_227:	cmp	byte ptr [rdi+0x1D], 2
	jnz	$_228
	test	byte ptr [rdi+0x4B], 0x01
	jz	$_228
	mov	edx, dword ptr [rdi+0x68]
	lea	rcx, [DS0032+rip]
	call	LstPrintf
$_228:	test	byte ptr [rdi+0x10], 0x04
	jnz	$_229
	test	byte ptr [rdi+0x11], 0x02
	jz	$_230
	test	byte ptr [rdi+0x4B], 0x02
	jnz	$_230
$_229:	mov	edx, 603
	lea	rcx, [DS0007+0x3+rip]
	call	LstPrintf
$_230:	cmp	byte ptr [rdi+0x1D], 2
	jnz	$_233
	lea	rcx, [DS0033+rip]
	test	byte ptr [rdi+0x4B], 0x02
	jnz	$_231
	test	byte ptr [rdi+0x12], 0x08
	jnz	$_231
	inc	rcx
$_231:	mov	edx, 600
	call	LstPrintf
	mov	rcx, qword ptr [rdi+0x60]
	test	rcx, rcx
	jz	$_232
	lea	rdx, [rcx+0xC]
	lea	rcx, [DS002A+rip]
	call	LstPrintf
$_232:	jmp	$_234

$_233:	cmp	byte ptr [rdi+0x1D], 0
	jnz	$_234
	mov	edx, 337
	lea	rcx, [DS0034+rip]
	call	LstPrintf
$_234:	mov	rcx, rdi
	call	$_111
	mov	rdx, rax
	lea	rcx, [DS0015+0x5+rip]
	call	LstPrintf
	call	LstNL
	jmp	$_238

$_235:	xor	r8d, r8d
	mov	rdx, qword ptr [rdi+0x8]
	mov	ecx, dword ptr [rdi+0x14]
	call	$_057
	mov	rdx, qword ptr [rdi+0x30]
	lea	rcx, [DS0035+rip]
	call	LstPrintf
	call	LstNL
	jmp	$_238

$_236:	xor	r8d, r8d
	mov	rdx, qword ptr [rdi+0x8]
	mov	ecx, dword ptr [rdi+0x14]
	call	$_057
	mov	rcx, qword ptr [rdi+0x30]
	mov	r8, qword ptr [rcx+0x8]
	mov	edx, 617
	lea	rcx, [DS0036+rip]
	call	LstPrintf
	call	LstNL
	jmp	$_238

$_237:	cmp	eax, 0
	je	$_217
	cmp	eax, 1
	je	$_217
	cmp	eax, 2
	je	$_217
	cmp	eax, 10
	jz	$_235
	cmp	eax, 8
	jz	$_236
$_238:	leave
	pop	rbx
	pop	rdi
	pop	rsi
	ret

$_239:
	mov	qword ptr [rsp+0x8], rcx
	mov	qword ptr [rsp+0x10], rdx
	push	rsi
	push	rbp
	mov	rbp, rsp
	sub	rsp, 40
	mov	esi, dword ptr [rbp+0x20]
$_240:	test	esi, esi
	jz	$_241
	call	LstNL
	dec	esi
	jmp	$_240

$_241:
	mov	rcx, qword ptr [rbp+0x18]
	call	LstPrintf
	call	LstNL
	call	LstNL
	leave
	pop	rsi
	ret

compare_syms:
	push	rbp
	mov	rbp, rsp
	sub	rsp, 32
	mov	rcx, rdi
	mov	rdx, rsi
	mov	rcx, qword ptr [rcx]
	mov	rdx, qword ptr [rdx]
	mov	rdx, qword ptr [rdx+0x8]
	mov	rcx, qword ptr [rcx+0x8]
	call	tstrcmp@PLT
	leave
	ret

LstWriteCRef:
	push	rsi
	push	rdi
	push	rbx
	push	rbp
	mov	rbp, rsp
	sub	rsp, 184
	cmp	qword ptr [r14+0x1F8], 0
	jz	$_242
	test	byte ptr [Options+0x6+rip], 0x01
	jz	$_243
$_242:	jmp	$_280

$_243:	mov	edx, 2
	xor	esi, esi
	mov	rdi, qword ptr [r14+0x1F8]
	call	fseek@PLT
	call	SymGetCount@PLT
	mov	dword ptr [rbp-0x24], eax
	lea	ecx, [rax*8]
	call	MemAlloc@PLT
	mov	qword ptr [rbp-0x8], rax
	mov	rcx, qword ptr [rbp-0x8]
	call	SymGetAll@PLT
	lea	rcx, [compare_syms@PLT+rip]
	mov	edx, 8
	mov	esi, dword ptr [rbp-0x24]
	mov	rdi, qword ptr [rbp-0x8]
	call	qsort@PLT
	mov	r8d, 112
	xor	edx, edx
	lea	rcx, [rbp-0x98]
	call	tmemset@PLT
	xor	ebx, ebx
$_244:	cmp	ebx, dword ptr [rbp-0x24]
	jnc	$_262
	mov	rcx, qword ptr [rbp-0x8]
	mov	rdi, qword ptr [rcx+rbx*8]
	test	byte ptr [rdi+0x12], 0x01
	je	$_261
	movzx	eax, byte ptr [rdi+0x1D]
	jmp	$_257

$_245:	mov	rax, qword ptr [rdi+0x78]
	mov	qword ptr [rbp-0x18], rax
	movzx	eax, word ptr [rdi+0x6E]
	jmp	$_250

$_246:	mov	ecx, 2
	jmp	$_251

$_247:	mov	ecx, 3
	jmp	$_251

$_248:	mov	ecx, 1
	jmp	$_251

$_249:	jmp	$_261

$_250:	cmp	eax, 4
	jz	$_246
	cmp	eax, 3
	jz	$_247
	cmp	eax, 1
	jz	$_248
	cmp	eax, 2
	jz	$_248
	jmp	$_249

$_251:	jmp	$_258

$_252:	mov	ecx, 0
	jmp	$_258

$_253:	mov	ecx, 4
	jmp	$_258

$_254:	mov	ecx, 5
	jmp	$_258

$_255:	test	byte ptr [rdi+0x10], 0x02
	jz	$_256
	mov	ecx, 6
	jmp	$_258

$_256:	jmp	$_261

$_257:	cmp	eax, 7
	jz	$_245
	cmp	eax, 9
	jz	$_252
	cmp	eax, 3
	jz	$_253
	cmp	eax, 4
	jz	$_254
	cmp	eax, 1
	jz	$_255
	cmp	eax, 2
	jz	$_255
	jmp	$_256

$_258:	imul	ecx, ecx, 16
	lea	rax, [rbp-0x98]
	lea	rdx, [rax+rcx]
	cmp	qword ptr [rdx], 0
	jnz	$_259
	mov	qword ptr [rdx], rdi
	jmp	$_260

$_259:	mov	rax, qword ptr [rdx+0x8]
	mov	qword ptr [rax+0x80], rdi
$_260:	mov	qword ptr [rdx+0x8], rdi
	mov	qword ptr [rdi+0x80], 0
$_261:	inc	ebx
	jmp	$_244

$_262:	cmp	qword ptr [rbp-0x98], 0
	jz	$_264
	mov	edx, 2
	lea	rcx, [DS0037+rip]
	call	$_239
	xor	edx, edx
	lea	rcx, [DS0038+rip]
	call	$_239
	mov	rsi, qword ptr [rbp-0x98]
$_263:	test	rsi, rsi
	jz	$_264
	mov	rcx, rsi
	call	$_114
	mov	rsi, qword ptr [rsi+0x80]
	jmp	$_263

$_264:	cmp	qword ptr [rbp-0x88], 0
	jz	$_266
	mov	edx, 2
	lea	rcx, [DS0039+rip]
	call	$_239
	xor	edx, edx
	lea	rcx, [DS003A+rip]
	call	$_239
	mov	rsi, qword ptr [rbp-0x88]
$_265:	test	rsi, rsi
	jz	$_266
	xor	r8d, r8d
	xor	edx, edx
	mov	rcx, rsi
	call	$_116
	mov	rsi, qword ptr [rsi+0x80]
	jmp	$_265

$_266:	cmp	qword ptr [rbp-0x78], 0
	jz	$_268
	mov	edx, 2
	lea	rcx, [DS003B+rip]
	call	$_239
	xor	edx, edx
	lea	rcx, [DS003C+rip]
	call	$_239
	mov	rsi, qword ptr [rbp-0x78]
$_267:	test	rsi, rsi
	jz	$_268
	mov	rcx, rsi
	call	$_127
	mov	rsi, qword ptr [rsi+0x80]
	jmp	$_267

$_268:	cmp	qword ptr [rbp-0x68], 0
	jz	$_270
	mov	edx, 2
	lea	rcx, [DS003D+rip]
	call	$_239
	xor	edx, edx
	lea	rcx, [DS003E+rip]
	call	$_239
	mov	rsi, qword ptr [rbp-0x68]
$_269:	test	rsi, rsi
	jz	$_270
	mov	rcx, rsi
	call	$_135
	mov	rsi, qword ptr [rsi+0x80]
	jmp	$_269

$_270:	cmp	qword ptr [rbp-0x58], 0
	jz	$_272
	mov	edx, 2
	lea	rcx, [DS003F+rip]
	call	$_239
	xor	edx, edx
	lea	rcx, [DS0040+rip]
	call	$_239
	mov	rsi, qword ptr [rbp-0x58]
$_271:	test	rsi, rsi
	jz	$_272
	xor	edx, edx
	mov	rcx, rsi
	call	$_140
	mov	rsi, qword ptr [rsi+0x80]
	jmp	$_271

$_272:	cmp	qword ptr [rbp-0x48], 0
	jz	$_274
	mov	rsi, qword ptr [rbp-0x48]
$_273:	test	rsi, rsi
	jz	$_274
	mov	rdx, qword ptr [rbp-0x58]
	mov	rcx, rsi
	call	$_166
	mov	rsi, qword ptr [rsi+0x80]
	jmp	$_273

$_274:	cmp	qword ptr [rbp-0x38], 0
	jz	$_276
	mov	edx, 2
	lea	rcx, [DS0041+rip]
	call	$_239
	xor	edx, edx
	lea	rcx, [DS0042+rip]
	call	$_239
	mov	rsi, qword ptr [rbp-0x38]
$_275:	test	rsi, rsi
	jz	$_276
	mov	rcx, rsi
	call	$_178
	mov	rsi, qword ptr [rsi+0x80]
	jmp	$_275

$_276:	mov	edx, 2
	lea	rcx, [DS0043+rip]
	call	$_239
	xor	edx, edx
	lea	rcx, [DS0044+rip]
	call	$_239
	xor	ebx, ebx
$_277:	cmp	ebx, dword ptr [rbp-0x24]
	jnc	$_279
	mov	rcx, qword ptr [rbp-0x8]
	mov	rdi, qword ptr [rcx+rbx*8]
	test	byte ptr [rdi+0x12], 0x01
	jz	$_278
	test	byte ptr [rdi+0x10], 0x02
	jnz	$_278
	mov	rcx, rdi
	call	$_216
$_278:	inc	ebx
	jmp	$_277

$_279:	call	LstNL
	mov	rcx, qword ptr [rbp-0x8]
	call	MemFree@PLT
$_280:	leave
	pop	rbx
	pop	rdi
	pop	rsi
	ret

ListingDirective:
	mov	qword ptr [rsp+0x10], rdx
	push	rsi
	push	rbx
	push	rbp
	mov	rbp, rsp
	sub	rsp, 32
	mov	esi, ecx
	imul	ebx, esi, 32
	add	rbx, qword ptr [rbp+0x28]
	mov	eax, dword ptr [rbx+0x4]
	inc	esi
	add	rbx, 32
	jmp	$_291

	cmp	qword ptr [r14+0x1F8], 0
	jz	$_281
	or	byte ptr [r14], 0x08
$_281:	jmp	$_292

	or	byte ptr [r14+0x3], 0x10
	jmp	$_292

	and	byte ptr [r14], 0xF7
	jmp	$_292

	cmp	esi, dword ptr [r14+0x64]
	jnz	$_282
	and	byte ptr [r14+0x3], 0xEF
	jmp	$_292

$_282:	cmp	byte ptr [rbx], 8
	jz	$_283
	mov	rdx, qword ptr [rbx+0x18]
	mov	ecx, 2008
	call	asmerr@PLT
	jmp	$_294

$_283:	mov	rcx, qword ptr [rbx+0x10]
	call	SymLookup@PLT
	and	byte ptr [rax+0x12], 0xFE
	inc	esi
	add	rbx, 32
	cmp	esi, dword ptr [r14+0x64]
	jge	$_285
	cmp	byte ptr [rbx], 44
	jz	$_284
	mov	rdx, qword ptr [rbx+0x18]
	mov	ecx, 2008
	call	asmerr@PLT
	jmp	$_294

$_284:	mov	ecx, dword ptr [r14+0x64]
	dec	ecx
	cmp	esi, ecx
	jnc	$_285
	inc	esi
	add	rbx, 32
$_285:	cmp	esi, dword ptr [r14+0x64]
	jl	$_282
	jmp	$_292

	cmp	qword ptr [r14+0x1F8], 0
	jz	$_286
	or	byte ptr [r14], 0x08
$_286:	or	byte ptr [r14], 0x20
	or	byte ptr [r14], 0x10
	jmp	$_292

	and	byte ptr [r14], 0xEF
	jmp	$_292

	xor	byte ptr [r14], 0x10
	jmp	$_292

LC016D: cmp	byte ptr [rbx], 58
	jz	$_292
	cmp	qword ptr [CurrStruct+rip], 0
	jz	$_287
	mov	ecx, 2037
	call	asmerr@PLT
	jmp	$_294

$_287:	cmp	dword ptr [Parse_Pass+rip], 0
	jnz	$_288
	mov	rdx, qword ptr [rbx-0x10]
	mov	ecx, 7005
	call	asmerr@PLT
$_288:	jmp	$_290

$_289:	inc	esi
	add	rbx, 32
$_290:	cmp	byte ptr [rbx], 0
	jnz	$_289
	jmp	$_292

$_291:	cmp	eax, 376
	jl	LC016D
	cmp	eax, 388
	jg	LC016D
	lea	r11, [LC0172+rip]
	movzx	r10, byte ptr [r11+rax-0x178]
	lea	r11, [LC016D+rip]
	sub	r11, r10
	jmp	r11

$_292:	cmp	byte ptr [rbx], 0
	jz	$_293
	mov	rdx, qword ptr [rbx+0x10]
	mov	ecx, 2008
	call	asmerr@PLT
	jmp	$_294

$_293:	xor	eax, eax
$_294:	leave
	pop	rbx
	pop	rsi
	ret

ListMacroDirective:
	mov	qword ptr [rsp+0x8], rcx
	mov	qword ptr [rsp+0x10], rdx
	push	rbp
	mov	rbp, rsp
	sub	rsp, 32
	imul	ecx, dword ptr [rbp+0x10], 32
	add	rcx, qword ptr [rbp+0x18]
	cmp	byte ptr [rcx+0x20], 0
	jz	$_295
	mov	rdx, qword ptr [rcx+0x30]
	mov	ecx, 2008
	call	asmerr@PLT
	jmp	$_296

$_295:	mov	eax, dword ptr [rcx+0x4]
	add	eax, eax
	mov	eax, dword ptr [r12+rax*8+0x4]
	mov	dword ptr [r14+0x1CC], eax
	xor	eax, eax
$_296:	leave
	ret

LstInit:
	push	rbp
	mov	rbp, rsp
	sub	rsp, 112
	cmp	dword ptr [Parse_Pass+rip], 0
	jnz	$_297
	mov	dword ptr [list_pos+rip], 0
$_297:	test	byte ptr [Options+rip], 0x08
	jz	$_300
	mov	dword ptr [rsp+0x20], 7
	mov	r9d, 39
	mov	r8d, 2
	lea	rdx, [cp_logo+rip]
	lea	rcx, [rbp-0x40]
	call	tsprintf@PLT
	mov	ecx, dword ptr [r14+0x10]
	call	GetFName@PLT
	mov	rdx, rax
	lea	rcx, [DS0045+rip]
	cmp	dword ptr [Parse_Pass+rip], 0
	jnz	$_298
	test	byte ptr [Options+0x6+rip], 0x02
	jz	$_298
	lea	rcx, [DS0046+rip]
	jmp	$_299

$_298:	test	byte ptr [Options+0x6+rip], 0x02
	jz	$_299
	lea	rcx, [DS0047+rip]
$_299:	mov	qword ptr [rsp+0x20], rdx
	lea	r9, [szTime+rip]
	lea	r8, [szDate+rip]
	lea	rdx, [rbp-0x40]
	call	LstPrintf
$_300:	leave
	ret


.SECTION .data
	.ALIGN	16

list_pos:
	.int   0x00000000

dots:
	.byte  0x20, 0x2E, 0x20, 0x2E, 0x20, 0x2E, 0x20, 0x2E
	.byte  0x20, 0x2E, 0x20, 0x2E, 0x20, 0x2E, 0x20, 0x2E
	.byte  0x20, 0x2E, 0x20, 0x2E, 0x20, 0x2E, 0x20, 0x2E
	.byte  0x20, 0x2E, 0x20, 0x2E, 0x20, 0x2E, 0x20, 0x2E
	.byte  0x00

DS0000:
	.byte  0x25, 0x30, 0x38, 0x58, 0x00

DS0001:
	.byte  0x25, 0x30, 0x32, 0x58, 0x00

DS0002:
	.byte  0x25, 0x2D, 0x32, 0x30, 0x6C, 0x58, 0x00

DS0003:
	.byte  0x25, 0x2D, 0x32, 0x30, 0x58, 0x00

DS0004:
	.byte  0x0A, 0x00

DS0005:
	.byte  0x25, 0x75, 0x00

DS0006:
	.byte  0x25, 0x2A, 0x73, 0x25, 0x73, 0x20, 0x25, 0x2A
	.byte  0x73, 0x00

DS0007:
	.byte  0x25, 0x72, 0x20, 0x25, 0x72, 0x20, 0x00

DS0008:
	.byte  0x25, 0x72, 0x00

DS0009:
	.byte  0x4C, 0x20, 0x25, 0x72, 0x00

DS000A:
	.byte  0x62, 0x69, 0x74, 0x73, 0x00

DS000B:
	.byte  0x6E, 0x75, 0x6D, 0x62, 0x65, 0x72, 0x00

DS000C:
	.byte  0x3F, 0x00

prefix: .int   0x00000000

DS000D:
	.byte  0x25, 0x38, 0x58, 0x20, 0x28, 0x25, 0x75, 0x29
	.byte  0x00

DS000E:
	.byte  0x25, 0x38, 0x58, 0x00

DS000F:
	.byte  0x25, 0x38, 0x58, 0x20, 0x20, 0x20, 0x25, 0x73
	.byte  0x00

DS0010:
	.byte  0x5B, 0x25, 0x75, 0x5D, 0x00

DS0011:
	.byte  0x25, 0x36, 0x58, 0x20, 0x20, 0x25, 0x37, 0x58
	.byte  0x00

DS0012:
	.byte  0x25, 0x36, 0x58, 0x20, 0x20, 0x25, 0x37, 0x58
	.byte  0x20, 0x20, 0x25, 0x30, 0x31, 0x36, 0x6C, 0x58
	.byte  0x20, 0x25, 0x73, 0x00

DS0013:
	.byte  0x25, 0x36, 0x58, 0x20, 0x20, 0x25, 0x37, 0x58
	.byte  0x20, 0x20, 0x25, 0x30, 0x38, 0x58, 0x20, 0x25
	.byte  0x73, 0x00

DS0014:
	.byte  0x25, 0x73, 0x20, 0x00

DS0015:
	.byte  0x4C, 0x20, 0x25, 0x72, 0x20, 0x25, 0x72, 0x00

DS0016:
	.byte  0x25, 0x75, 0x20, 0x62, 0x69, 0x74, 0x20, 0x20
	.byte  0x20, 0x00

DS0017:
	.byte  0x25, 0x30, 0x38, 0x58, 0x20, 0x00

DS0018:
	.byte  0x25, 0x30, 0x34, 0x58, 0x20, 0x20, 0x20, 0x20
	.byte  0x20, 0x00

DS0019:
	.byte  0x70, 0x61, 0x72, 0x61, 0x00

DS001A:
	.byte  0x61, 0x62, 0x73, 0x00

DS001B:
	.byte  0x25, 0x2D, 0x37, 0x72, 0x20, 0x00

DS001C:
	.byte  0x25, 0x2D, 0x37, 0x73, 0x20, 0x00

DS001D:
	.byte  0x70, 0x72, 0x69, 0x76, 0x61, 0x74, 0x65, 0x00

DS001E:
	.byte  0x73, 0x74, 0x61, 0x63, 0x6B, 0x00

DS001F:
	.byte  0x63, 0x6F, 0x6D, 0x6D, 0x6F, 0x6E, 0x00

DS0020:
	.byte  0x25, 0x2D, 0x38, 0x72, 0x00

DS0021:
	.byte  0x25, 0x2D, 0x38, 0x73, 0x00

DS0022:
	.byte  0x27, 0x25, 0x73, 0x27, 0x00

DS0023:
	.byte  0x6E, 0x6F, 0x20, 0x73, 0x65, 0x67, 0x00

DS0024:
	.byte  0x50, 0x20, 0x25, 0x2D, 0x36, 0x72, 0x20, 0x25
	.byte  0x30, 0x34, 0x58, 0x20, 0x20, 0x20, 0x20, 0x20
	.byte  0x25, 0x2D, 0x38, 0x73, 0x20, 0x00

DS0025:
	.byte  0x50, 0x20, 0x25, 0x2D, 0x36, 0x72, 0x20, 0x25
	.byte  0x30, 0x38, 0x58, 0x20, 0x25, 0x2D, 0x38, 0x73
	.byte  0x20, 0x00

DS0026:
	.byte  0x25, 0x30, 0x2A, 0x58, 0x20, 0x00

DS0027:
	.byte  0x25, 0x2D, 0x38, 0x72, 0x20, 0x00

DS0028:
	.byte  0x70, 0x72, 0x69, 0x76, 0x61, 0x74, 0x65, 0x20
	.byte  0x20, 0x00

DS0029:
	.byte  0x2A, 0x25, 0x2A, 0x72, 0x20, 0x00

DS002A:
	.byte  0x28, 0x25, 0x2E, 0x38, 0x73, 0x29, 0x20, 0x00

DS002B:
	.byte  0x5B, 0x25, 0x72, 0x2B, 0x25, 0x30, 0x32, 0x58
	.byte  0x5D, 0x20, 0x00

DS002C:
	.byte  0x25, 0x2D, 0x38, 0x73, 0x20, 0x5B, 0x25, 0x72
	.byte  0x2B, 0x25, 0x30, 0x32, 0x58, 0x5D, 0x00

DS002D:
	.byte  0x25, 0x2D, 0x38, 0x73, 0x20, 0x5B, 0x25, 0x72
	.byte  0x25, 0x63, 0x25, 0x30, 0x32, 0x58, 0x5D, 0x00

DS002E:
	.byte  0x25, 0x73, 0x5B, 0x25, 0x75, 0x5D, 0x00

DS002F:
	.byte  0x4C, 0x20, 0x25, 0x2D, 0x36, 0x72, 0x20, 0x25
	.byte  0x30, 0x38, 0x58, 0x20, 0x25, 0x73, 0x00

DS0030:
	.byte  0x4C, 0x20, 0x25, 0x2D, 0x36, 0x72, 0x20, 0x25
	.byte  0x30, 0x34, 0x58, 0x20, 0x25, 0x73, 0x00

DS0031:
	.byte  0x25, 0x30, 0x38, 0x58, 0x25, 0x30, 0x38, 0x58
	.byte  0x20, 0x00

DS0032:
	.byte  0x63, 0x6F, 0x75, 0x6E, 0x74, 0x3D, 0x25, 0x75
	.byte  0x20, 0x00

DS0033:
	.byte  0x2A, 0x25, 0x72, 0x20, 0x00

DS0034:
	.byte  0x75, 0x6E, 0x25, 0x72, 0x20, 0x00

DS0035:
	.byte  0x74, 0x65, 0x78, 0x74, 0x20, 0x20, 0x20, 0x20
	.byte  0x20, 0x25, 0x73, 0x00

DS0036:
	.byte  0x25, 0x72, 0x20, 0x20, 0x25, 0x73, 0x00

DS0037:
	.byte  0x4D, 0x61, 0x63, 0x72, 0x6F, 0x73, 0x3A, 0x00

DS0038:
	.byte  0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20
	.byte  0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20
	.byte  0x4E, 0x20, 0x61, 0x20, 0x6D, 0x20, 0x65, 0x20
	.byte  0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20
	.byte  0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20
	.byte  0x54, 0x79, 0x70, 0x65, 0x00

DS0039:
	.byte  0x53, 0x74, 0x72, 0x75, 0x63, 0x74, 0x75, 0x72
	.byte  0x65, 0x73, 0x20, 0x61, 0x6E, 0x64, 0x20, 0x55
	.byte  0x6E, 0x69, 0x6F, 0x6E, 0x73, 0x3A, 0x00

DS003A:
	.byte  0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20
	.byte  0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20
	.byte  0x4E, 0x20, 0x61, 0x20, 0x6D, 0x20, 0x65, 0x20
	.byte  0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20
	.byte  0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20
	.byte  0x53, 0x69, 0x7A, 0x65, 0x2F, 0x4F, 0x66, 0x73
	.byte  0x20, 0x20, 0x20, 0x54, 0x79, 0x70, 0x65, 0x00

DS003B:
	.byte  0x52, 0x65, 0x63, 0x6F, 0x72, 0x64, 0x73, 0x3A
	.byte  0x00

DS003C:
	.byte  0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20
	.byte  0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20
	.byte  0x4E, 0x20, 0x61, 0x20, 0x6D, 0x20, 0x65, 0x20
	.byte  0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20
	.byte  0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20
	.byte  0x57, 0x69, 0x64, 0x74, 0x68, 0x20, 0x20, 0x20
	.byte  0x23, 0x20, 0x66, 0x69, 0x65, 0x6C, 0x64, 0x73
	.byte  0x0A, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20
	.byte  0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20
	.byte  0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20
	.byte  0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20
	.byte  0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20
	.byte  0x20, 0x53, 0x68, 0x69, 0x66, 0x74, 0x20, 0x20
	.byte  0x20, 0x57, 0x69, 0x64, 0x74, 0x68, 0x20, 0x20
	.byte  0x20, 0x20, 0x4D, 0x61, 0x73, 0x6B, 0x20, 0x20
	.byte  0x20, 0x49, 0x6E, 0x69, 0x74, 0x69, 0x61, 0x6C
	.byte  0x00

DS003D:
	.byte  0x54, 0x79, 0x70, 0x65, 0x73, 0x3A, 0x00

DS003E:
	.byte  0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20
	.byte  0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20
	.byte  0x4E, 0x20, 0x61, 0x20, 0x6D, 0x20, 0x65, 0x20
	.byte  0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20
	.byte  0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20
	.byte  0x53, 0x69, 0x7A, 0x65, 0x20, 0x20, 0x20, 0x20
	.byte  0x20, 0x41, 0x74, 0x74, 0x72, 0x00

DS003F:
	.byte  0x53, 0x65, 0x67, 0x6D, 0x65, 0x6E, 0x74, 0x73
	.byte  0x20, 0x61, 0x6E, 0x64, 0x20, 0x47, 0x72, 0x6F
	.byte  0x75, 0x70, 0x73, 0x3A, 0x00

DS0040:
	.byte  0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20
	.byte  0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20
	.byte  0x4E, 0x20, 0x61, 0x20, 0x6D, 0x20, 0x65, 0x20
	.byte  0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20
	.byte  0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20
	.byte  0x53, 0x69, 0x7A, 0x65, 0x20, 0x20, 0x20, 0x20
	.byte  0x20, 0x4C, 0x65, 0x6E, 0x67, 0x74, 0x68, 0x20
	.byte  0x20, 0x20, 0x41, 0x6C, 0x69, 0x67, 0x6E, 0x20
	.byte  0x20, 0x20, 0x43, 0x6F, 0x6D, 0x62, 0x69, 0x6E
	.byte  0x65, 0x20, 0x43, 0x6C, 0x61, 0x73, 0x73, 0x00

DS0041:
	.byte  0x50, 0x72, 0x6F, 0x63, 0x65, 0x64, 0x75, 0x72
	.byte  0x65, 0x73, 0x2C, 0x20, 0x70, 0x61, 0x72, 0x61
	.byte  0x6D, 0x65, 0x74, 0x65, 0x72, 0x73, 0x20, 0x61
	.byte  0x6E, 0x64, 0x20, 0x6C, 0x6F, 0x63, 0x61, 0x6C
	.byte  0x73, 0x3A, 0x00

DS0042:
	.byte  0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20
	.byte  0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20
	.byte  0x4E, 0x20, 0x61, 0x20, 0x6D, 0x20, 0x65, 0x20
	.byte  0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20
	.byte  0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20
	.byte  0x54, 0x79, 0x70, 0x65, 0x20, 0x20, 0x20, 0x20
	.byte  0x20, 0x56, 0x61, 0x6C, 0x75, 0x65, 0x20, 0x20
	.byte  0x20, 0x20, 0x53, 0x65, 0x67, 0x6D, 0x65, 0x6E
	.byte  0x74, 0x20, 0x20, 0x4C, 0x65, 0x6E, 0x67, 0x74
	.byte  0x68, 0x00

DS0043:
	.byte  0x53, 0x79, 0x6D, 0x62, 0x6F, 0x6C, 0x73, 0x3A
	.byte  0x00

DS0044:
	.byte  0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20
	.byte  0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20
	.byte  0x4E, 0x20, 0x61, 0x20, 0x6D, 0x20, 0x65, 0x20
	.byte  0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20
	.byte  0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20
	.byte  0x54, 0x79, 0x70, 0x65, 0x20, 0x20, 0x20, 0x20
	.byte  0x20, 0x56, 0x61, 0x6C, 0x75, 0x65, 0x20, 0x20
	.byte  0x20, 0x20, 0x20, 0x41, 0x74, 0x74, 0x72, 0x00

LC0172:
	.byte  0xAB, 0x12, 0xBE, 0x24, 0x12, 0x98, 0xA1, 0x0C
	.byte  0x0C, 0x06, 0x98, 0xA1, 0x00

DS0045:
	.byte  0x25, 0x73, 0x20, 0x20, 0x25, 0x73, 0x20, 0x25
	.byte  0x73, 0x0A, 0x25, 0x73, 0x0A, 0x00

DS0046:
	.byte  0x25, 0x73, 0x20, 0x20, 0x25, 0x73, 0x20, 0x25
	.byte  0x73, 0x20, 0x2D, 0x20, 0x46, 0x69, 0x72, 0x73
	.byte  0x74, 0x20, 0x50, 0x61, 0x73, 0x73, 0x0A, 0x25
	.byte  0x73, 0x0A, 0x00

DS0047:
	.byte  0x0A, 0x25, 0x73, 0x20, 0x20, 0x25, 0x73, 0x20
	.byte  0x25, 0x73, 0x0A, 0x25, 0x73, 0x0A, 0x0A, 0x00


.SECTION .bss
	.ALIGN	16

mtbuf:
	.zero	256 * 1


.att_syntax prefix
